#line 1 "ad_aarch64.cpp"
//
// Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2022, Red Hat, Inc. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/macroAssembler.inline.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/markOop.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"

//SourceForm

#line 1447 "src/hotspot/cpu/aarch64/aarch64.ad"


  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  //
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  //
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarVolatile
  //
  // n.b. as an aside, a cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a slightly different
  // node sequence to a normal volatile get because of the
  // introduction of some CPUOrder memory barriers to bracket the
  // Load. However, but the same basic skeleton of a LoadX feeding a
  // MemBarAcquire, possibly thorugh an optional DecodeN, is still
  // present
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarCPUOrder LoadX[mo_acquire]
  //        ||            |
  //        ||       {DecodeN} optional
  //        ||       /
  //     MemBarAcquire
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  //
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode, bool maybe_volatile)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode, bool maybe_volatile)
  {
    switch(opcode) {
      // We handle these
    case Op_CompareAndSwapI:
    case Op_CompareAndSwapL:
    case Op_CompareAndSwapP:
    case Op_CompareAndSwapN:
    case Op_CompareAndSwapB:
    case Op_CompareAndSwapS:
    case Op_GetAndSetI:
    case Op_GetAndSetL:
    case Op_GetAndSetP:
    case Op_GetAndSetN:
    case Op_GetAndAddI:
    case Op_GetAndAddL:
#if INCLUDE_SHENANDOAHGC
    case Op_ShenandoahCompareAndSwapP:
    case Op_ShenandoahCompareAndSwapN:
#endif
      return true;
    case Op_CompareAndExchangeI:
    case Op_CompareAndExchangeN:
    case Op_CompareAndExchangeB:
    case Op_CompareAndExchangeS:
    case Op_CompareAndExchangeL:
    case Op_CompareAndExchangeP:
    case Op_WeakCompareAndSwapB:
    case Op_WeakCompareAndSwapS:
    case Op_WeakCompareAndSwapI:
    case Op_WeakCompareAndSwapL:
    case Op_WeakCompareAndSwapP:
    case Op_WeakCompareAndSwapN:
      return maybe_volatile;
    default:
      return false;
    }
  }

  // helper to determine the maximum number of Phi nodes we may need to
  // traverse when searching from a card mark membar for the merge mem
  // feeding a trailing membar or vice versa

// predicates controlling emit of ldr<x>/ldar<x> and associated dmb

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode(), true);
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  if (UseBarriersForVolatile) {
    // we use a normal load and a dmb
    return false;
  }

  LoadNode *ld = n->as_Load();

  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
	  n->Opcode() == Op_MemBarRelease),
	 "expecting a release membar");

  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode *barrier = n->as_MemBar();
  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode(), true);
    }
  }
  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
  }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x> and associated dmbs

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  if (UseBarriersForVolatile) {
    // we use a normal store and dmb combination
    return false;
  }

  StoreNode *st = n->as_Store();

  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode(), true), "expecting a compare and swap");
  if (UseBarriersForVolatile) {
    return false;
  }

  LoadStoreNode* ldst = n->as_LoadStore();
  if (is_CAS(n->Opcode(), false)) {
    assert(ldst->trailing_membar() != NULL, "expected trailing membar");
  } else {
    return ldst->trailing_membar() != NULL;
  }

  // so we can just return true here
  return true;
}

// predicate controlling translation of StoreCM
//
// returns true if a StoreStore must precede the card write otherwise
// false

bool unnecessary_storestore(const Node *storecm)
{
  assert(storecm->Opcode()  == Op_StoreCM, "expecting a StoreCM");

  // we need to generate a dmb ishst between an object put and the
  // associated card mark when we are using CMS without conditional
  // card marking

  if (UseConcMarkSweepGC && !UseCondCardMark) {
    return false;
  }

  // a storestore is unnecesary in all other cases

  return true;
}


#define __ _masm.

// advance declarations for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  int off = 4;
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // or with far branches
  //   bl(trampoline_stub)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

// Indicate if the safepoint node needs the polling page as an input

// the shared code plants the oop data at the start of the generated
// code for the safepoint node and that needs ot be at the load
// instruction itself. so we cannot plant a mov of the safepoint poll
// address followed by a load. setting this to true means the mov is
// scheduled as a prior instruction. that's better for scheduling
// anyway.

bool SafePointNode::needs_polling_address_input()
{
  return true;
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) {
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->frame_slots() << LogBytesPerInt;

  if (C->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
    if (PreserveFramePointer) st->print("\n\tadd  rfp, sp, #%d", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize));
    if (PreserveFramePointer) st->print("mov  rfp, sp\n\t");
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  const int framesize = C->frame_size_in_bytes();
  assert(framesize%(2*wordSize) == 0, "must preserve 2*wordSize alignment");

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (UseSVE > 0 && C->max_vector_size() >= 16) {
    __ reinitialize_ptrue();
  }

  int bangsize = C->bang_size_in_bytes();
  if (C->need_stack_bang(bangsize) && UseStackBanging)
    __ generate_stack_overflow_check(bangsize);

  __ build_frame(framesize);

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    Compile::ConstantTable& constant_table = C->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# touch polling page\n\t");
    st->print("mov  rscratch1, #0x%lx\n\t", p2i(os::get_polling_page()));
    st->print("ldr zr, [rscratch1]");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);
  int framesize = C->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (StackReservedPages > 0 && C->has_reserved_stack_access()) {
    __ reserved_stack_check();
  }

  if (do_polling() && C->is_method_compilation()) {
    __ read_polling_page(rscratch1, os::get_polling_page(), relocInfo::poll_return_type);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

// This method seems to be obsolete. It is declared in machnode.hpp
// and defined in all *.ad files, but it is never called. Should we
// get rid of it?
int MachEpilogNode::safepoint_offset() const {
  assert(do_polling(), "no return for this epilog node");
  return 4;
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_predicate, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 32 int registers * 2 halves
  int slots_of_int_registers = RegisterImpl::max_slots_per_register * RegisterImpl::number_of_registers;

  if (reg < slots_of_int_registers) {
    return rc_int;
  }

  // we have 32 float register * 8 halves
  int slots_of_float_registers = FloatRegisterImpl::max_slots_per_register * FloatRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers) {
    return rc_float;
  }

  int slots_of_predicate_registers = PRegisterImpl::max_slots_per_register * PRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers + slots_of_predicate_registers) {
    return rc_predicate;
  }

  // Between predicate regs & stack is the flags.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() != NULL) {
    uint ireg = ideal_reg();
    if (ireg == Op_VecA && cbuf) {
      MacroAssembler _masm(cbuf);
      int sve_vector_reg_size_in_bytes = Matcher::scalable_vector_reg_size(T_BYTE);
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        __ spill_copy_sve_vector_stack_to_stack(src_offset, dst_offset,
                                                sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill_sve_vector(as_FloatRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                            sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill_sve_vector(as_FloatRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                              sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ sve_orr(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else {
        ShouldNotReachHere();
      }
    } else if (cbuf) {
      assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
      MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 ireg == Op_VecD ? __ D : __ Q,
                 ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   ireg == Op_VecD ? __ D : __ Q,
               ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
          if (cbuf) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ unspill(rscratch1, is64, src_offset);
        __ spill(rscratch1, is64, dst_offset);
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() != NULL) {
      int vsize = 0;
      switch (ideal_reg()) {
      case Op_VecD:
        vsize = 64;
        break;
      case Op_VecX:
        vsize = 128;
        break;
      case Op_VecA:
        vsize = Matcher::scalable_vector_reg_size(T_BYTE) * 8;
        break;
      default:
        assert(false, "bad register type for spill");
        ShouldNotReachHere();
      }
      st->print("\t# vector spill size = %d", vsize);
    } else {
      st->print("\t# spill size = %d", is64 ? 64 : 32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  // This add will handle any 24-bit signed offset. 24 bits allows an
  // 8 megabyte stack frame.
  __ add(as_Register(reg), sp, offset);
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    return NativeInstruction::instruction_size;
  } else {
    return 2 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (Universe::narrow_klass_shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {

  if (!has_match_rule(opcode)) {
    return false;
  }

  return true;  // Per default match rules are supported.
}

 // Identify extra cases that we might want to provide match rules for vector nodes and
 // other intrinsics guarded with vector length (vlen) and element type (bt).
 const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {
  if (!match_rule_supported(opcode) || !vector_size_supported(bt, vlen)) {
    return false;
  }
  int bit_size = vlen * type2aelembytes(bt) * 8;
  if (UseSVE == 0 && bit_size > 128) {
    return false;
  }
  if (UseSVE > 0) {
    return op_sve_supported(opcode);
  } else { // NEON
    // Special cases
    switch (opcode) {
    case Op_MulVL:
      return false;
    default:
      break;
    }
  }
  return true; // Per default match rules are supported.
}

const bool Matcher::has_predicated_vectors(void) {
  return UseSVE > 0;
}

const int Matcher::float_pressure(int default_pressure_threshold) {
  return default_pressure_threshold;
}

int Matcher::regnum_to_fpu_offset(int regnum)
{
  Unimplemented();
  return 0;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Will one (StoreL ConL) be cheaper than two (StoreI ConI)?.
  // Probably always true, even if a temp register is required.
  return true;
}

// true just means we have fast l2f conversion
const bool Matcher::convL2FSupported(void) {
  return true;
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  // The MaxVectorSize should have been set by detecting SVE max vector register size.
  int size = MIN2((UseSVE > 0) ? 256 : 16, (int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}
const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  if ((UseSVE > 0) && (MaxVectorSize >= 16)) {
    // Currently vector length less than SVE vector register size is not supported.
    return max_size;
  } else {
    //  For the moment limit the vector size to 8 bytes with NEON.
    int size = 8 / type2aelembytes(bt);
    if (size < 2) size = 2;
    return size;
  }
}

const bool Matcher::supports_scalable_vector() {
  return UseSVE > 0;
}

// Actual max scalable vector register length.
const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  if (UseSVE > 0 && 16 <= len && len <= 256) {
    return Op_VecA;
  }
  switch(len) {
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

const uint Matcher::vector_shift_count_ideal_reg(int size) {
  if (UseSVE > 0 && 16 <= size && size <= 256) {
    return Op_VecA;
  }
  switch(size) {
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

// AES support not yet implemented
const bool Matcher::pass_original_key_for_aes() {
  return false;
}

// aarch64 supports misaligned vectors store/load.
const bool Matcher::misaligned_vectors_ok() {
  return true;
}

// false => size gets scaled to BytesPerLong, ok.
const bool Matcher::init_array_count_is_in_bytes = false;

// Use conditional move (CMOVL)
const int Matcher::long_cmove_cost() {
  // long cmoves are no more expensive than int cmoves
  return 0;
}

const int Matcher::float_cmove_cost() {
  // float cmoves are no more expensive than int cmoves
  return 0;
}

// Does the CPU require late expand (see block.cpp for description of late expand)?
const bool Matcher::require_postalloc_expand = false;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
const bool Matcher::need_masked_shift_count = false;

// This affects two different things:
//  - how Decode nodes are matched
//  - how ImplicitNullCheck opportunities are recognized
// If true, the matcher will try to remove all Decodes and match them
// (as operands) into nodes. NullChecks are not prepared to deal with
// Decodes by final_graph_reshaping().
// If false, final_graph_reshaping() forces the decode behind the Cmp
// for a NullCheck. The matcher matches the Decode node into a register.
// Implicit_null_check optimization moves the Decode along with the
// memory operation back up before the NullCheck.
bool Matcher::narrow_oop_use_complex_address() {
  return Universe::narrow_oop_shift() == 0;
}

bool Matcher::narrow_klass_use_complex_address() {
// TODO
// decide whether we need to set this to true
  return false;
}

bool Matcher::const_oop_prefer_decode() {
  // Prefer ConN+DecodeN over ConP in simple compressed oops mode.
  return Universe::narrow_oop_base() == NULL;
}

bool Matcher::const_klass_prefer_decode() {
  // Prefer ConNKlass+DecodeNKlass over ConP in simple compressed klass mode.
  return Universe::narrow_klass_base() == NULL;
}

// Is it better to copy float constants, or load them directly from
// memory?  Intel can load a float constant from a direct address,
// requiring no extra registers.  Most RISCs will have to materialize
// an address into a register first, so they would do better to copy
// the constant from stack.
const bool Matcher::rematerialize_float_constants = false;

// If CPU can load and store mis-aligned doubles directly then no
// fixup is needed.  Else we split the double into 2 integer pieces
// and move it piece-by-piece.  Only happens when passing doubles into
// C code as the Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;

// No-op on amd64
void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {
  Unimplemented();
}

// Advertise here if the CPU requires explicit rounding operations to
// implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = false;

// Are floats converted to double when stored to stack during
// deoptimization?
bool Matcher::float_in_double() { return false; }

// Do ints take an entire long register or just half?
// The relevant question is how the int is callee-saved:
// the whole long is written but de-opt'ing will have to extract
// the relevant 32 bits.
const bool Matcher::int_in_long = true;

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}

bool size_fits_all_mem_uses(AddPNode* addp, int shift) {
  for (DUIterator_Fast imax, i = addp->fast_outs(imax); i < imax; i++) {
    Node* u = addp->fast_out(i);
    if (u->is_LoadStore()) {
      // On AArch64, LoadStoreNodes (i.e. compare and swap
      // instructions) only take register indirect as an operand, so
      // any attempt to use an AddPNode as an input to a LoadStoreNode
      // must fail.
      return false;
    }
    if (u->is_Mem()) {
      int opsize = u->as_Mem()->memory_size();
      assert(opsize > 0, "unexpected memory operand size");
      if (u->as_Mem()->memory_size() != (1<<shift)) {
        return false;
      }
    }
  }
  return true;
}

const bool Matcher::convi2l_type_required = false;

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  if (clone_base_plus_offset_address(m, mstack, address_visited)) {
    return true;
  }

  Node *off = m->in(AddPNode::Offset);
  if (off->Opcode() == Op_LShiftL && off->in(2)->is_Con() &&
      size_fits_all_mem_uses(m, off->in(2)->get_int()) &&
      // Are there other uses besides address expressions?
      !is_visited(off)) {
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(2), Visit);
    Node *conv = off->in(1);
    if (conv->Opcode() == Op_ConvI2L &&
        // Are there other uses besides address expressions?
        !is_visited(conv)) {
      address_visited.set(conv->_idx); // Flag as address_visited
      mstack.push(conv->in(1), Pre_Visit);
    } else {
      mstack.push(conv, Pre_Visit);
    }
    address_visited.test_set(m->_idx); // Flag as address_visited
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  } else if (off->Opcode() == Op_ConvI2L &&
             // Are there other uses besides address expressions?
             !is_visited(off)) {
    address_visited.test_set(m->_idx); // Flag as address_visited
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(1), Pre_Visit);
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  }
  return false;
}

void Compile::reshape_address(AddPNode* addp) {
}


#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)      \
  MacroAssembler _masm(&cbuf);                                          \
  {                                                                     \
    guarantee(INDEX == -1, "mode not permitted for volatile");          \
    guarantee(DISP == 0, "mode not permitted for volatile");            \
    guarantee(SCALE == 0, "mode not permitted for volatile");           \
    __ INSN(REG, as_Register(BASE));                                    \
  }

static Address mem2address(int opcode, Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      return Address(base, disp);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      return Address(base, as_Register(index), scale);
    }
  }

typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_insn2)(Register Rt, Register adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);
  static void loadStore(MacroAssembler masm, mem_insn insn,
                         Register reg, int opcode,
                         Register base, int index, int size, int disp,
                         int size_in_memory)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      Address addr(base, disp);
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      assert_different_registers(rscratch1, reg);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
      (masm.*insn)(reg, addr);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(MacroAssembler masm, mem_insn insn,
                        Register reg, int opcode,
                        Register base, int index, int size, int disp)
  {
    Address addr = mem2address(opcode, base, index, size, disp);
    (masm.*insn)(reg, addr);
  }

  static void loadStore(MacroAssembler masm, mem_float_insn insn,
                        FloatRegister reg, int opcode,
                        Register base, int index, int size, int disp)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

     if (index == -1) {
      (masm.*insn)(reg, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  static void loadStore(MacroAssembler masm, mem_vector_insn insn,
                        FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                        int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1555 "ad_aarch64.cpp"


//SourceForm

#line 67 "src/hotspot/os_cpu/linux_aarch64/linux_aarch64.ad"



#line 1564 "ad_aarch64.cpp"


//SourceForm

#line 31 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"


static void z_load_barrier(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp, bool weak) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, weak);
  __ ldr(tmp, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
  __ andr(tmp, tmp, ref);
  __ cbnz(tmp, *stub->entry());
  __ bind(*stub->continuation());
}

static void z_load_barrier_slow_path(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, false /* weak */);
  __ b(*stub->entry());
  __ bind(*stub->continuation());
}


#line 1587 "ad_aarch64.cpp"


//SourceForm

#line 90 "src/hotspot/cpu/aarch64/aarch64_sve.ad"


  static inline BasicType vector_element_basic_type(const MachNode* n) {
    const TypeVect* vt = n->bottom_type()->is_vect();
    return vt->element_basic_type();
  }

  static inline BasicType vector_element_basic_type(const MachNode* use, const MachOper* opnd) {
    int def_idx = use->operand_index(opnd);
    Node* def = use->in(def_idx);
    const TypeVect* vt = def->bottom_type()->is_vect();
    return vt->element_basic_type();
  }

  typedef void (MacroAssembler::* sve_mem_insn_predicate)(FloatRegister Rt, Assembler::SIMD_RegVariant T,
                                                             PRegister Pg, const Address &adr);

  // Predicated load/store, with optional ptrue to all elements of given predicate register.
  static void loadStoreA_predicate(MacroAssembler masm, bool is_store,
                                   FloatRegister reg, PRegister pg, BasicType bt,
                                   int opcode, Register base, int index, int size, int disp) {
    sve_mem_insn_predicate insn = NULL;
    Assembler::SIMD_RegVariant type = Assembler::B;
    int esize = type2aelembytes(bt);
    if (index == -1) {
      assert(size == 0, "unsupported address mode: scale size = %d", size);
      switch(esize) {
      case 1:
        insn = is_store ? &MacroAssembler::sve_st1b : &MacroAssembler::sve_ld1b;
        type = Assembler::B;
        break;
      case 2:
        insn = is_store ? &MacroAssembler::sve_st1h : &MacroAssembler::sve_ld1h;
        type = Assembler::H;
        break;
      case 4:
        insn = is_store ? &MacroAssembler::sve_st1w : &MacroAssembler::sve_ld1w;
        type = Assembler::S;
        break;
      case 8:
        insn = is_store ? &MacroAssembler::sve_st1d : &MacroAssembler::sve_ld1d;
        type = Assembler::D;
        break;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
      }
      (masm.*insn)(reg, type, pg, Address(base, disp / Matcher::scalable_vector_reg_size(T_BYTE)));
    } else {
      assert(false, "unimplemented");
      ShouldNotReachHere();
    }
  }

  bool op_sve_supported(int opcode) {
    switch (opcode) {
        // No multiply reduction instructions
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
        // Others
      case Op_Extract:
      case Op_ExtractB:
      case Op_ExtractC:
      case Op_ExtractD:
      case Op_ExtractF:
      case Op_ExtractI:
      case Op_ExtractL:
      case Op_ExtractS:
      case Op_ExtractUB:
        return false;
      default:
        return true;
    }
  }


#line 1671 "ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
  assert( SVE_COST == 200, "Expect (200) to equal 200");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R18
  'C', // R18_H
  'N', // R27
  'N', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'N', // R8
  'N', // R8_H
  'N', // R9
  'N', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'C', // R18
  'C', // R18_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'E', // V8
  'E', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'E', // V9
  'E', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'E', // V10
  'E', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'E', // V11
  'E', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'E', // V12
  'E', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'E', // V13
  'E', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'E', // V14
  'E', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'E', // V15
  'E', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  Op_RegVMask,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immIExt_rule,
  /*   13 */  immI_le_4_rule,
  /*   14 */  immI_31_rule,
  /*   15 */  immI_8_rule,
  /*   16 */  immI_16_rule,
  /*   17 */  immI_24_rule,
  /*   18 */  immI_32_rule,
  /*   19 */  immI_48_rule,
  /*   20 */  immI_56_rule,
  /*   21 */  immI_63_rule,
  /*   22 */  immI_64_rule,
  /*   23 */  immI_255_rule,
  /*   24 */  immI_65535_rule,
  /*   25 */  immL_255_rule,
  /*   26 */  immL_65535_rule,
  /*   27 */  immL_4294967295_rule,
  /*   28 */  immL_bitmask_rule,
  /*   29 */  immI_bitmask_rule,
  /*   30 */  immL_positive_bitmaskI_rule,
  /*   31 */  immIScale_rule,
  /*   32 */  immI26_rule,
  /*   33 */  immI19_rule,
  /*   34 */  immIU12_rule,
  /*   35 */  immLU12_rule,
  /*   36 */  immIOffset_rule,
  /*   37 */  immIOffset4_rule,
  /*   38 */  immIOffset8_rule,
  /*   39 */  immIOffset16_rule,
  /*   40 */  immLoffset_rule,
  /*   41 */  immLoffset4_rule,
  /*   42 */  immLoffset8_rule,
  /*   43 */  immLoffset16_rule,
  /*   44 */  immI8_rule,
  /*   45 */  immI8_shift8_rule,
  /*   46 */  immL8_shift8_rule,
  /*   47 */  immIAddSub_rule,
  /*   48 */  immILog_rule,
  /*   49 */  immL_rule,
  /*   50 */  immL0_rule,
  /*   51 */  immL_1_rule,
  /*   52 */  immL_M1_rule,
  /*   53 */  immL_pc_off_rule,
  /*   54 */  immLAddSub_rule,
  /*   55 */  immLLog_rule,
  /*   56 */  immL_32bits_rule,
  /*   57 */  immP_rule,
  /*   58 */  immP0_rule,
  /*   59 */  immP_1_rule,
  /*   60 */  immPollPage_rule,
  /*   61 */  immByteMapBase_rule,
  /*   62 */  immP_M1_rule,
  /*   63 */  immP_M2_rule,
  /*   64 */  immD_rule,
  /*   65 */  immD0_rule,
  /*   66 */  immDPacked_rule,
  /*   67 */  immF_rule,
  /*   68 */  immF0_rule,
  /*   69 */  immFPacked_rule,
  /*   70 */  immI_positive_rule,
  /*   71 */  immN_rule,
  /*   72 */  immN0_rule,
  /*   73 */  immNKlass_rule,
  /*   74 */  iRegI_rule,
  /*   75 */  iRegINoSp_rule,
  /*   76 */  iRegL_rule,
  /*   77 */  iRegLNoSp_rule,
  /*   78 */  iRegP_rule,
  /*   79 */  iRegPNoSp_rule,
  /*   80 */  iRegP_R0_rule,
  /*   81 */  iRegP_R1_rule,
  /*   82 */  iRegP_R2_rule,
  /*   83 */  iRegP_R3_rule,
  /*   84 */  iRegP_R4_rule,
  /*   85 */  iRegP_R5_rule,
  /*   86 */  iRegP_R10_rule,
  /*   87 */  iRegL_R0_rule,
  /*   88 */  iRegL_R2_rule,
  /*   89 */  iRegL_R3_rule,
  /*   90 */  iRegL_R11_rule,
  /*   91 */  iRegP_FP_rule,
  /*   92 */  iRegI_R0_rule,
  /*   93 */  iRegI_R2_rule,
  /*   94 */  iRegI_R3_rule,
  /*   95 */  iRegI_R4_rule,
  /*   96 */  iRegN_rule,
  /*   97 */  iRegN_R0_rule,
  /*   98 */  iRegN_R2_rule,
  /*   99 */  iRegN_R3_rule,
  /*  100 */  iRegNNoSp_rule,
  /*  101 */  iRegIHeapbase_rule,
  /*  102 */  vRegF_rule,
  /*  103 */  vRegD_rule,
  /*  104 */  vReg_rule,
  /*  105 */  vecD_rule,
  /*  106 */  vecX_rule,
  /*  107 */  vRegD_V0_rule,
  /*  108 */  vRegD_V1_rule,
  /*  109 */  vRegD_V2_rule,
  /*  110 */  vRegD_V3_rule,
  /*  111 */  vRegD_V4_rule,
  /*  112 */  vRegD_V5_rule,
  /*  113 */  vRegD_V6_rule,
  /*  114 */  vRegD_V7_rule,
  /*  115 */  vRegD_V8_rule,
  /*  116 */  vRegD_V9_rule,
  /*  117 */  vRegD_V10_rule,
  /*  118 */  vRegD_V11_rule,
  /*  119 */  vRegD_V12_rule,
  /*  120 */  vRegD_V13_rule,
  /*  121 */  vRegD_V14_rule,
  /*  122 */  vRegD_V15_rule,
  /*  123 */  vRegD_V16_rule,
  /*  124 */  vRegD_V17_rule,
  /*  125 */  vRegD_V18_rule,
  /*  126 */  vRegD_V19_rule,
  /*  127 */  vRegD_V20_rule,
  /*  128 */  vRegD_V21_rule,
  /*  129 */  vRegD_V22_rule,
  /*  130 */  vRegD_V23_rule,
  /*  131 */  vRegD_V24_rule,
  /*  132 */  vRegD_V25_rule,
  /*  133 */  vRegD_V26_rule,
  /*  134 */  vRegD_V27_rule,
  /*  135 */  vRegD_V28_rule,
  /*  136 */  vRegD_V29_rule,
  /*  137 */  vRegD_V30_rule,
  /*  138 */  vRegD_V31_rule,
  /*  139 */  pRegGov_rule,
  /*  140 */  rFlagsReg_rule,
  /*  141 */  rFlagsRegU_rule,
  /*  142 */  inline_cache_RegP_rule,
  /*  143 */  interpreter_method_oop_RegP_rule,
  /*  144 */  thread_RegP_rule,
  /*  145 */  lr_RegP_rule,
  /*  146 */  indirect_rule,
  /*  147 */  indIndexScaledI2L_rule,
  /*  148 */  indIndexScaled_rule,
  /*  149 */  indIndexI2L_rule,
  /*  150 */  indIndex_rule,
  /*  151 */  indOffI_rule,
  /*  152 */  indOffI4_rule,
  /*  153 */  indOffI8_rule,
  /*  154 */  indOffI16_rule,
  /*  155 */  indOffL_rule,
  /*  156 */  indOffL4_rule,
  /*  157 */  indOffL8_rule,
  /*  158 */  indOffL16_rule,
  /*  159 */  indirectN_rule,
  /*  160 */  indIndexScaledI2LN_rule,
  /*  161 */  indIndexScaledN_rule,
  /*  162 */  indIndexI2LN_rule,
  /*  163 */  indIndexN_rule,
  /*  164 */  indOffIN_rule,
  /*  165 */  indOffLN_rule,
  /*  166 */  thread_anchor_pc_rule,
  /*  167 */  stackSlotP_rule,
  /*  168 */  stackSlotI_rule,
  /*  169 */  stackSlotF_rule,
  /*  170 */  stackSlotD_rule,
  /*  171 */  stackSlotL_rule,
  /*  172 */  cmpOp_rule,
  /*  173 */  cmpOpU_rule,
  /*  174 */  cmpOpEqNe_rule,
  /*  175 */  cmpOpLtGe_rule,
  /*  176 */  cmpOpUEqNeLtGe_rule,
  /*  177 */  iRegL2I_rule,
  /*  178 */  vmemA_immIOffset4_rule,
  /*  179 */  vmemA_immLOffset4_rule,
  /*  180 */  vmemA_indOffI4_rule,
  /*  181 */  vmemA_indOffL4_rule,
  // last operand
  /*  182 */  vmem4_rule,
  /*  183 */  vmem8_rule,
  /*  184 */  vmem16_rule,
  /*  185 */  memory_rule,
  /*  186 */  iRegIorL2I_rule,
  /*  187 */  vmemA_rule,
  // last operand class
  /*  188 */  _ConvI2L_iRegI__rule,
  /*  189 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  190 */  _LShiftL_iRegL_immIScale_rule,
  /*  191 */  _DecodeN_iRegN__rule,
  /*  192 */  _LoadB_memory__rule,
  /*  193 */  _LoadUB_memory__rule,
  /*  194 */  _LoadS_memory__rule,
  /*  195 */  _LoadUS_memory__rule,
  /*  196 */  _LoadI_memory__rule,
  /*  197 */  _ConvI2L__LoadI_memory___rule,
  /*  198 */  _LoadB_indirect__rule,
  /*  199 */  _LoadUB_indirect__rule,
  /*  200 */  _LoadUS_indirect__rule,
  /*  201 */  _LoadS_indirect__rule,
  /*  202 */  _LoadI_indirect__rule,
  /*  203 */  _ConvI2L__LoadI_indirect___rule,
  /*  204 */  _LoadL_memory__rule,
  /*  205 */  _CastP2X_iRegP__rule,
  /*  206 */  _CastP2X__DecodeN_iRegN___rule,
  /*  207 */  _Binary_iRegP_iRegP_rule,
  /*  208 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  209 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  210 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  211 */  _Binary_iRegI_iRegI_rule,
  /*  212 */  _Binary_iRegL_iRegL_rule,
  /*  213 */  _Binary_iRegN_iRegN_rule,
  /*  214 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  215 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  216 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  217 */  _Binary_immI0_iRegIorL2I_rule,
  /*  218 */  _Binary_iRegIorL2I_immI0_rule,
  /*  219 */  _Binary_immI_1_immI0_rule,
  /*  220 */  _Binary_iRegL_immL0_rule,
  /*  221 */  _Binary_immL0_iRegL_rule,
  /*  222 */  _Binary_iRegP_immP0_rule,
  /*  223 */  _Binary_immP0_iRegP_rule,
  /*  224 */  _Binary_iRegN_immN0_rule,
  /*  225 */  _Binary_immN0_iRegN_rule,
  /*  226 */  _Binary_vRegF_vRegF_rule,
  /*  227 */  _Binary_vRegD_vRegD_rule,
  /*  228 */  _ConvL2I_iRegL__rule,
  /*  229 */  _ConvI2L_iRegIorL2I__rule,
  /*  230 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  231 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  232 */  _MulL_iRegL_iRegL_rule,
  /*  233 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  234 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  235 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  236 */  _XorL_iRegL_immL_M1_rule,
  /*  237 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  238 */  _XorL_iRegL_iRegL_rule,
  /*  239 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  240 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  241 */  _URShiftL_iRegL_immI_rule,
  /*  242 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  243 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  244 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  245 */  _RShiftL_iRegL_immI_rule,
  /*  246 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  247 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  248 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  249 */  _LShiftL_iRegL_immI_rule,
  /*  250 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  251 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  252 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  253 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  254 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  255 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  256 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  257 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  258 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  259 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  260 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  261 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  262 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  263 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  264 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  265 */  _AndL_iRegL_immL_bitmask_rule,
  /*  266 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  267 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  268 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  269 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  270 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  271 */  _AndI_iRegI_immI_bitmask_rule,
  /*  272 */  _LShiftL_iRegL_iRegI_rule,
  /*  273 */  _SubI_immI_64_iRegI_rule,
  /*  274 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  275 */  _SubI_immI0_iRegI_rule,
  /*  276 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  277 */  _LShiftI_iRegI_iRegI_rule,
  /*  278 */  _SubI_immI_32_iRegI_rule,
  /*  279 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  280 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  281 */  _URShiftL_iRegL_iRegI_rule,
  /*  282 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  283 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  284 */  _URShiftI_iRegI_iRegI_rule,
  /*  285 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  286 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  287 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  288 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  289 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  290 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  291 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  292 */  _LShiftL_iRegL_immI_48_rule,
  /*  293 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  294 */  _LShiftL_iRegL_immI_32_rule,
  /*  295 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  296 */  _LShiftL_iRegL_immI_56_rule,
  /*  297 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  298 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  299 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  300 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  301 */  _AndL_iRegL_immL_255_rule,
  /*  302 */  _AndL_iRegL_immL_65535_rule,
  /*  303 */  _AndL_iRegL_immL_4294967295_rule,
  /*  304 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  305 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  306 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  307 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  308 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  309 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  310 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  311 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  312 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  313 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  314 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  315 */  _NegF_vRegF__rule,
  /*  316 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  317 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  318 */  _NegD_vRegD__rule,
  /*  319 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  320 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  321 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  322 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  323 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  324 */  _CmpL_iRegL_immL0_rule,
  /*  325 */  _CmpP_iRegP_immP0_rule,
  /*  326 */  _CmpN_iRegN_immN0_rule,
  /*  327 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  328 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  329 */  _CmpUL_iRegL_immL0_rule,
  /*  330 */  _AndL_iRegL_immL_rule,
  /*  331 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  332 */  _AndI_iRegIorL2I_immI_rule,
  /*  333 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  334 */  _AndL_iRegL_iRegL_rule,
  /*  335 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  336 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  337 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  338 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  339 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  340 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  341 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  342 */  _Binary_iRegP_R3_immI_1_rule,
  /*  343 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  344 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  345 */  _MulVS_vecD_vecD_rule,
  /*  346 */  _MulVS_vecX_vecX_rule,
  /*  347 */  _MulVI_vecD_vecD_rule,
  /*  348 */  _MulVI_vecX_vecX_rule,
  /*  349 */  _Binary_vecD_vecD_rule,
  /*  350 */  _Binary_vecX_vecX_rule,
  /*  351 */  _NegVF_vecD__rule,
  /*  352 */  _Binary__NegVF_vecD__vecD_rule,
  /*  353 */  _Binary_vecD__NegVF_vecD__rule,
  /*  354 */  _NegVF_vecX__rule,
  /*  355 */  _Binary__NegVF_vecX__vecX_rule,
  /*  356 */  _Binary_vecX__NegVF_vecX__rule,
  /*  357 */  _NegVD_vecX__rule,
  /*  358 */  _Binary__NegVD_vecX__vecX_rule,
  /*  359 */  _Binary_vecX__NegVD_vecX__rule,
  /*  360 */  _Binary_vReg_vReg_rule,
  /*  361 */  _NegVF_vReg__rule,
  /*  362 */  _Binary__NegVF_vReg__vReg_rule,
  /*  363 */  _Binary_vReg__NegVF_vReg__rule,
  /*  364 */  _NegVD_vReg__rule,
  /*  365 */  _Binary__NegVD_vReg__vReg_rule,
  /*  366 */  _Binary_vReg__NegVD_vReg__rule,
  /*  367 */  _MulVS_vReg_vReg_rule,
  /*  368 */  _MulVI_vReg_vReg_rule,
  /*  369 */  _MulVL_vReg_vReg_rule,
  // last internally defined operand
  /*  370 */  iRegINoSp_rule,
  /*  371 */  iRegLNoSp_rule,
  /*  372 */  iRegPNoSp_rule,
  /*  373 */  iRegPNoSp_rule,
  /*  374 */  iRegPNoSp_rule,
  /*  375 */  iRegPNoSp_rule,
  /*  376 */  iRegPNoSp_rule,
  /*  377 */  iRegNNoSp_rule,
  /*  378 */  iRegNNoSp_rule,
  /*  379 */  iRegNNoSp_rule,
  /*  380 */  vRegF_rule,
  /*  381 */  vRegF_rule,
  /*  382 */  vRegD_rule,
  /*  383 */  vRegD_rule,
  /*  384 */  iRegINoSp_rule,
  /*  385 */  iRegINoSp_rule,
  /*  386 */  iRegINoSp_rule,
  /*  387 */  iRegINoSp_rule,
  /*  388 */  iRegPNoSp_rule,
  /*  389 */  iRegLNoSp_rule,
  /*  390 */  iRegPNoSp_rule,
  /*  391 */  iRegPNoSp_rule,
  /*  392 */  iRegI_rule,
  /*  393 */  iRegL_rule,
  /*  394 */  rFlagsReg_rule,
  /*  395 */  rFlagsReg_rule,
  /*  396 */  rFlagsReg_rule,
  /*  397 */  vRegF_rule,
  /*  398 */  vRegD_rule,
  /*  399 */  vRegF_rule,
  /*  400 */  vRegD_rule,
  /*  401 */  iRegINoSp_rule,
  /*  402 */  vRegF_rule,
  /*  403 */  iRegLNoSp_rule,
  /*  404 */  vRegD_rule,
  /*  405 */  iRegINoSp_rule,
  /*  406 */  vRegF_rule,
  /*  407 */  iRegLNoSp_rule,
  /*  408 */  vRegD_rule,
  /*  409 */  rFlagsReg_rule,
  /*  410 */  rFlagsReg_rule,
  /*  411 */  rFlagsReg_rule,
  /*  412 */  rFlagsReg_rule,
  /*  413 */  rFlagsReg_rule,
  /*  414 */  rFlagsReg_rule,
  /*  415 */  rFlagsReg_rule,
  /*  416 */  rFlagsReg_rule,
  /*  417 */  rFlagsReg_rule,
  /*  418 */  rFlagsReg_rule,
  /*  419 */  rFlagsReg_rule,
  /*  420 */  rFlagsReg_rule,
  /*  421 */  rFlagsReg_rule,
  /*  422 */  rFlagsReg_rule,
  /*  423 */  rFlagsReg_rule,
  /*  424 */  rFlagsReg_rule,
  /*  425 */  rFlagsRegU_rule,
  /*  426 */  rFlagsRegU_rule,
  /*  427 */  rFlagsRegU_rule,
  /*  428 */  rFlagsRegU_rule,
  /*  429 */  rFlagsReg_rule,
  /*  430 */  rFlagsReg_rule,
  /*  431 */  rFlagsReg_rule,
  /*  432 */  rFlagsReg_rule,
  /*  433 */  rFlagsRegU_rule,
  /*  434 */  rFlagsRegU_rule,
  /*  435 */  rFlagsRegU_rule,
  /*  436 */  rFlagsRegU_rule,
  /*  437 */  rFlagsRegU_rule,
  /*  438 */  rFlagsRegU_rule,
  /*  439 */  rFlagsRegU_rule,
  /*  440 */  rFlagsRegU_rule,
  /*  441 */  rFlagsReg_rule,
  /*  442 */  rFlagsReg_rule,
  /*  443 */  rFlagsReg_rule,
  /*  444 */  rFlagsReg_rule,
  /*  445 */  rFlagsReg_rule,
  /*  446 */  rFlagsReg_rule,
  /*  447 */  rFlagsReg_rule,
  /*  448 */  rFlagsReg_rule,
  /*  449 */  rFlagsReg_rule,
  /*  450 */  rFlagsReg_rule,
  /*  451 */  rFlagsReg_rule,
  /*  452 */  thread_RegP_rule,
  /*  453 */  vecD_rule,
  /*  454 */  vecX_rule,
  /*  455 */  vecX_rule,
  /*  456 */  vecD_rule,
  /*  457 */  vecX_rule,
  /*  458 */  vecD_rule,
  /*  459 */  vecX_rule,
  /*  460 */  vecD_rule,
  /*  461 */  vecX_rule,
  /*  462 */  vecX_rule,
  /*  463 */  vecD_rule,
  /*  464 */  vecX_rule,
  /*  465 */  vecX_rule,
  /*  466 */  vecD_rule,
  /*  467 */  vecX_rule,
  /*  468 */  vecX_rule,
  /*  469 */  vecD_rule,
  /*  470 */  vecD_rule,
  /*  471 */  vecX_rule,
  /*  472 */  vecX_rule,
  /*  473 */  vecX_rule,
  /*  474 */  vecD_rule,
  /*  475 */  vReg_rule,
  /*  476 */  vReg_rule,
  /*  477 */  vReg_rule,
  /*  478 */  vReg_rule,
  /*  479 */  vReg_rule,
  /*  480 */  vReg_rule,
  /*  481 */  vReg_rule,
  /*  482 */  vReg_rule,
  /*  483 */  vReg_rule,
  /*  484 */  vReg_rule,
  /*  485 */  vReg_rule,
  /*  486 */  vReg_rule,
  /*  487 */  vReg_rule,
  /*  488 */  iRegINoSp_rule,
  /*  489 */  iRegLNoSp_rule,
  /*  490 */  iRegINoSp_rule,
  /*  491 */  iRegLNoSp_rule,
  /*  492 */  iRegINoSp_rule,
  /*  493 */  iRegLNoSp_rule,
  /*  494 */  iRegINoSp_rule,
  /*  495 */  iRegLNoSp_rule,
  /*  496 */  iRegINoSp_rule,
  /*  497 */  iRegLNoSp_rule,
  /*  498 */  iRegLNoSp_rule,
  /*  499 */  iRegLNoSp_rule,
  /*  500 */  iRegINoSp_rule,
  /*  501 */  iRegPNoSp_rule,
  /*  502 */  iRegNNoSp_rule,
  /*  503 */  iRegPNoSp_rule,
  /*  504 */  iRegNNoSp_rule,
  /*  505 */  vRegF_rule,
  /*  506 */  vRegD_rule,
  /*  507 */  Universe_rule,
  /*  508 */  Universe_rule,
  /*  509 */  Universe_rule,
  /*  510 */  Universe_rule,
  /*  511 */  Universe_rule,
  /*  512 */  Universe_rule,
  /*  513 */  Universe_rule,
  /*  514 */  Universe_rule,
  /*  515 */  Universe_rule,
  /*  516 */  Universe_rule,
  /*  517 */  Universe_rule,
  /*  518 */  Universe_rule,
  /*  519 */  Universe_rule,
  /*  520 */  Universe_rule,
  /*  521 */  Universe_rule,
  /*  522 */  Universe_rule,
  /*  523 */  Universe_rule,
  /*  524 */  Universe_rule,
  /*  525 */  iRegINoSp_rule,
  /*  526 */  iRegLNoSp_rule,
  /*  527 */  iRegINoSp_rule,
  /*  528 */  iRegLNoSp_rule,
  /*  529 */  iRegINoSp_rule,
  /*  530 */  iRegINoSp_rule,
  /*  531 */  iRegLNoSp_rule,
  /*  532 */  iRegLNoSp_rule,
  /*  533 */  iRegINoSp_rule,
  /*  534 */  iRegLNoSp_rule,
  /*  535 */  iRegLNoSp_rule,
  /*  536 */  iRegPNoSp_rule,
  /*  537 */  iRegNNoSp_rule,
  /*  538 */  vRegF_rule,
  /*  539 */  vRegD_rule,
  /*  540 */  Universe_rule,
  /*  541 */  Universe_rule,
  /*  542 */  Universe_rule,
  /*  543 */  Universe_rule,
  /*  544 */  Universe_rule,
  /*  545 */  Universe_rule,
  /*  546 */  Universe_rule,
  /*  547 */  Universe_rule,
  /*  548 */  iRegINoSp_rule,
  /*  549 */  iRegLNoSp_rule,
  /*  550 */  iRegINoSp_rule,
  /*  551 */  iRegINoSp_rule,
  /*  552 */  iRegINoSp_rule,
  /*  553 */  iRegINoSp_rule,
  /*  554 */  iRegINoSp_rule,
  /*  555 */  iRegINoSp_rule,
  /*  556 */  Universe_rule,
  /*  557 */  Universe_rule,
  /*  558 */  Universe_rule,
  /*  559 */  Universe_rule,
  /*  560 */  Universe_rule,
  /*  561 */  Universe_rule,
  /*  562 */  Universe_rule,
  /*  563 */  Universe_rule,
  /*  564 */  Universe_rule,
  /*  565 */  Universe_rule,
  /*  566 */  Universe_rule,
  /*  567 */  iRegINoSp_rule,
  /*  568 */  iRegINoSp_rule,
  /*  569 */  iRegNNoSp_rule,
  /*  570 */  iRegNNoSp_rule,
  /*  571 */  iRegPNoSp_rule,
  /*  572 */  iRegPNoSp_rule,
  /*  573 */  iRegNNoSp_rule,
  /*  574 */  iRegPNoSp_rule,
  /*  575 */  iRegPNoSp_rule,
  /*  576 */  iRegINoSp_rule,
  /*  577 */  iRegINoSp_rule,
  /*  578 */  iRegINoSp_rule,
  /*  579 */  iRegINoSp_rule,
  /*  580 */  iRegINoSp_rule,
  /*  581 */  iRegINoSp_rule,
  /*  582 */  iRegINoSp_rule,
  /*  583 */  iRegINoSp_rule,
  /*  584 */  iRegINoSp_rule,
  /*  585 */  iRegINoSp_rule,
  /*  586 */  iRegINoSp_rule,
  /*  587 */  iRegINoSp_rule,
  /*  588 */  iRegINoSp_rule,
  /*  589 */  iRegINoSp_rule,
  /*  590 */  iRegINoSp_rule,
  /*  591 */  iRegLNoSp_rule,
  /*  592 */  iRegNNoSp_rule,
  /*  593 */  iRegPNoSp_rule,
  /*  594 */  iRegINoSp_rule,
  /*  595 */  iRegINoSp_rule,
  /*  596 */  iRegINoSp_rule,
  /*  597 */  iRegLNoSp_rule,
  /*  598 */  iRegNNoSp_rule,
  /*  599 */  iRegPNoSp_rule,
  /*  600 */  iRegINoSp_rule,
  /*  601 */  iRegINoSp_rule,
  /*  602 */  iRegINoSp_rule,
  /*  603 */  iRegINoSp_rule,
  /*  604 */  iRegINoSp_rule,
  /*  605 */  iRegINoSp_rule,
  /*  606 */  iRegINoSp_rule,
  /*  607 */  iRegINoSp_rule,
  /*  608 */  iRegINoSp_rule,
  /*  609 */  iRegINoSp_rule,
  /*  610 */  iRegINoSp_rule,
  /*  611 */  iRegINoSp_rule,
  /*  612 */  iRegINoSp_rule,
  /*  613 */  iRegLNoSp_rule,
  /*  614 */  iRegINoSp_rule,
  /*  615 */  iRegPNoSp_rule,
  /*  616 */  iRegINoSp_rule,
  /*  617 */  iRegLNoSp_rule,
  /*  618 */  iRegINoSp_rule,
  /*  619 */  iRegPNoSp_rule,
  /*  620 */  iRegLNoSp_rule,
  /*  621 */  Universe_rule,
  /*  622 */  iRegLNoSp_rule,
  /*  623 */  Universe_rule,
  /*  624 */  iRegINoSp_rule,
  /*  625 */  Universe_rule,
  /*  626 */  iRegINoSp_rule,
  /*  627 */  Universe_rule,
  /*  628 */  iRegLNoSp_rule,
  /*  629 */  Universe_rule,
  /*  630 */  iRegLNoSp_rule,
  /*  631 */  Universe_rule,
  /*  632 */  iRegINoSp_rule,
  /*  633 */  Universe_rule,
  /*  634 */  iRegINoSp_rule,
  /*  635 */  Universe_rule,
  /*  636 */  iRegINoSp_rule,
  /*  637 */  iRegINoSp_rule,
  /*  638 */  iRegINoSp_rule,
  /*  639 */  iRegINoSp_rule,
  /*  640 */  iRegINoSp_rule,
  /*  641 */  iRegINoSp_rule,
  /*  642 */  iRegINoSp_rule,
  /*  643 */  iRegINoSp_rule,
  /*  644 */  iRegINoSp_rule,
  /*  645 */  iRegINoSp_rule,
  /*  646 */  iRegLNoSp_rule,
  /*  647 */  iRegLNoSp_rule,
  /*  648 */  iRegLNoSp_rule,
  /*  649 */  iRegLNoSp_rule,
  /*  650 */  iRegLNoSp_rule,
  /*  651 */  iRegLNoSp_rule,
  /*  652 */  iRegPNoSp_rule,
  /*  653 */  iRegPNoSp_rule,
  /*  654 */  iRegPNoSp_rule,
  /*  655 */  iRegPNoSp_rule,
  /*  656 */  iRegPNoSp_rule,
  /*  657 */  iRegPNoSp_rule,
  /*  658 */  iRegNNoSp_rule,
  /*  659 */  iRegNNoSp_rule,
  /*  660 */  iRegNNoSp_rule,
  /*  661 */  iRegNNoSp_rule,
  /*  662 */  iRegNNoSp_rule,
  /*  663 */  iRegNNoSp_rule,
  /*  664 */  vRegF_rule,
  /*  665 */  vRegF_rule,
  /*  666 */  vRegD_rule,
  /*  667 */  vRegD_rule,
  /*  668 */  iRegINoSp_rule,
  /*  669 */  iRegINoSp_rule,
  /*  670 */  iRegINoSp_rule,
  /*  671 */  iRegPNoSp_rule,
  /*  672 */  iRegPNoSp_rule,
  /*  673 */  iRegPNoSp_rule,
  /*  674 */  iRegPNoSp_rule,
  /*  675 */  iRegLNoSp_rule,
  /*  676 */  iRegPNoSp_rule,
  /*  677 */  iRegLNoSp_rule,
  /*  678 */  iRegLNoSp_rule,
  /*  679 */  iRegINoSp_rule,
  /*  680 */  iRegINoSp_rule,
  /*  681 */  iRegLNoSp_rule,
  /*  682 */  iRegLNoSp_rule,
  /*  683 */  iRegINoSp_rule,
  /*  684 */  iRegLNoSp_rule,
  /*  685 */  iRegINoSp_rule,
  /*  686 */  iRegLNoSp_rule,
  /*  687 */  iRegLNoSp_rule,
  /*  688 */  iRegLNoSp_rule,
  /*  689 */  iRegLNoSp_rule,
  /*  690 */  iRegINoSp_rule,
  /*  691 */  iRegINoSp_rule,
  /*  692 */  iRegINoSp_rule,
  /*  693 */  iRegLNoSp_rule,
  /*  694 */  iRegLNoSp_rule,
  /*  695 */  iRegLNoSp_rule,
  /*  696 */  iRegLNoSp_rule,
  /*  697 */  iRegLNoSp_rule,
  /*  698 */  iRegLNoSp_rule,
  /*  699 */  iRegLNoSp_rule,
  /*  700 */  iRegLNoSp_rule,
  /*  701 */  iRegLNoSp_rule,
  /*  702 */  iRegLNoSp_rule,
  /*  703 */  iRegLNoSp_rule,
  /*  704 */  iRegLNoSp_rule,
  /*  705 */  iRegLNoSp_rule,
  /*  706 */  iRegINoSp_rule,
  /*  707 */  iRegLNoSp_rule,
  /*  708 */  iRegINoSp_rule,
  /*  709 */  iRegLNoSp_rule,
  /*  710 */  iRegINoSp_rule,
  /*  711 */  iRegINoSp_rule,
  /*  712 */  iRegINoSp_rule,
  /*  713 */  iRegINoSp_rule,
  /*  714 */  iRegINoSp_rule,
  /*  715 */  iRegINoSp_rule,
  /*  716 */  iRegLNoSp_rule,
  /*  717 */  iRegLNoSp_rule,
  /*  718 */  iRegLNoSp_rule,
  /*  719 */  iRegLNoSp_rule,
  /*  720 */  iRegLNoSp_rule,
  /*  721 */  iRegLNoSp_rule,
  /*  722 */  iRegLNoSp_rule,
  /*  723 */  iRegLNoSp_rule,
  /*  724 */  iRegINoSp_rule,
  /*  725 */  iRegINoSp_rule,
  /*  726 */  iRegINoSp_rule,
  /*  727 */  iRegLNoSp_rule,
  /*  728 */  iRegLNoSp_rule,
  /*  729 */  iRegINoSp_rule,
  /*  730 */  iRegINoSp_rule,
  /*  731 */  iRegLNoSp_rule,
  /*  732 */  iRegLNoSp_rule,
  /*  733 */  iRegINoSp_rule,
  /*  734 */  iRegINoSp_rule,
  /*  735 */  iRegLNoSp_rule,
  /*  736 */  iRegLNoSp_rule,
  /*  737 */  iRegINoSp_rule,
  /*  738 */  iRegINoSp_rule,
  /*  739 */  iRegLNoSp_rule,
  /*  740 */  iRegLNoSp_rule,
  /*  741 */  iRegINoSp_rule,
  /*  742 */  iRegINoSp_rule,
  /*  743 */  iRegLNoSp_rule,
  /*  744 */  iRegLNoSp_rule,
  /*  745 */  iRegINoSp_rule,
  /*  746 */  iRegINoSp_rule,
  /*  747 */  iRegLNoSp_rule,
  /*  748 */  iRegLNoSp_rule,
  /*  749 */  iRegINoSp_rule,
  /*  750 */  iRegINoSp_rule,
  /*  751 */  iRegINoSp_rule,
  /*  752 */  iRegINoSp_rule,
  /*  753 */  iRegLNoSp_rule,
  /*  754 */  iRegLNoSp_rule,
  /*  755 */  iRegLNoSp_rule,
  /*  756 */  iRegLNoSp_rule,
  /*  757 */  iRegINoSp_rule,
  /*  758 */  iRegINoSp_rule,
  /*  759 */  iRegINoSp_rule,
  /*  760 */  iRegINoSp_rule,
  /*  761 */  iRegLNoSp_rule,
  /*  762 */  iRegLNoSp_rule,
  /*  763 */  iRegLNoSp_rule,
  /*  764 */  iRegLNoSp_rule,
  /*  765 */  iRegINoSp_rule,
  /*  766 */  iRegINoSp_rule,
  /*  767 */  iRegINoSp_rule,
  /*  768 */  iRegINoSp_rule,
  /*  769 */  iRegLNoSp_rule,
  /*  770 */  iRegLNoSp_rule,
  /*  771 */  iRegLNoSp_rule,
  /*  772 */  iRegLNoSp_rule,
  /*  773 */  iRegINoSp_rule,
  /*  774 */  iRegINoSp_rule,
  /*  775 */  iRegLNoSp_rule,
  /*  776 */  iRegLNoSp_rule,
  /*  777 */  iRegINoSp_rule,
  /*  778 */  iRegINoSp_rule,
  /*  779 */  iRegLNoSp_rule,
  /*  780 */  iRegLNoSp_rule,
  /*  781 */  iRegINoSp_rule,
  /*  782 */  iRegINoSp_rule,
  /*  783 */  iRegLNoSp_rule,
  /*  784 */  iRegLNoSp_rule,
  /*  785 */  iRegINoSp_rule,
  /*  786 */  iRegINoSp_rule,
  /*  787 */  iRegLNoSp_rule,
  /*  788 */  iRegLNoSp_rule,
  /*  789 */  iRegINoSp_rule,
  /*  790 */  iRegINoSp_rule,
  /*  791 */  iRegLNoSp_rule,
  /*  792 */  iRegLNoSp_rule,
  /*  793 */  iRegINoSp_rule,
  /*  794 */  iRegINoSp_rule,
  /*  795 */  iRegLNoSp_rule,
  /*  796 */  iRegLNoSp_rule,
  /*  797 */  iRegINoSp_rule,
  /*  798 */  iRegINoSp_rule,
  /*  799 */  iRegLNoSp_rule,
  /*  800 */  iRegLNoSp_rule,
  /*  801 */  iRegINoSp_rule,
  /*  802 */  iRegINoSp_rule,
  /*  803 */  iRegLNoSp_rule,
  /*  804 */  iRegLNoSp_rule,
  /*  805 */  iRegINoSp_rule,
  /*  806 */  iRegINoSp_rule,
  /*  807 */  iRegLNoSp_rule,
  /*  808 */  iRegLNoSp_rule,
  /*  809 */  iRegINoSp_rule,
  /*  810 */  iRegINoSp_rule,
  /*  811 */  iRegLNoSp_rule,
  /*  812 */  iRegLNoSp_rule,
  /*  813 */  iRegINoSp_rule,
  /*  814 */  iRegINoSp_rule,
  /*  815 */  iRegLNoSp_rule,
  /*  816 */  iRegLNoSp_rule,
  /*  817 */  iRegINoSp_rule,
  /*  818 */  iRegINoSp_rule,
  /*  819 */  iRegLNoSp_rule,
  /*  820 */  iRegLNoSp_rule,
  /*  821 */  iRegINoSp_rule,
  /*  822 */  iRegINoSp_rule,
  /*  823 */  iRegLNoSp_rule,
  /*  824 */  iRegLNoSp_rule,
  /*  825 */  iRegINoSp_rule,
  /*  826 */  iRegINoSp_rule,
  /*  827 */  iRegLNoSp_rule,
  /*  828 */  iRegLNoSp_rule,
  /*  829 */  iRegINoSp_rule,
  /*  830 */  iRegINoSp_rule,
  /*  831 */  iRegLNoSp_rule,
  /*  832 */  iRegLNoSp_rule,
  /*  833 */  iRegINoSp_rule,
  /*  834 */  iRegLNoSp_rule,
  /*  835 */  iRegINoSp_rule,
  /*  836 */  iRegLNoSp_rule,
  /*  837 */  iRegINoSp_rule,
  /*  838 */  iRegLNoSp_rule,
  /*  839 */  iRegLNoSp_rule,
  /*  840 */  iRegINoSp_rule,
  /*  841 */  iRegLNoSp_rule,
  /*  842 */  iRegINoSp_rule,
  /*  843 */  iRegINoSp_rule,
  /*  844 */  iRegLNoSp_rule,
  /*  845 */  iRegLNoSp_rule,
  /*  846 */  iRegINoSp_rule,
  /*  847 */  iRegLNoSp_rule,
  /*  848 */  iRegLNoSp_rule,
  /*  849 */  iRegINoSp_rule,
  /*  850 */  iRegLNoSp_rule,
  /*  851 */  iRegINoSp_rule,
  /*  852 */  iRegLNoSp_rule,
  /*  853 */  iRegLNoSp_rule,
  /*  854 */  iRegLNoSp_rule,
  /*  855 */  iRegINoSp_rule,
  /*  856 */  iRegINoSp_rule,
  /*  857 */  iRegLNoSp_rule,
  /*  858 */  iRegLNoSp_rule,
  /*  859 */  iRegINoSp_rule,
  /*  860 */  iRegINoSp_rule,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  iRegLNoSp_rule,
  /*  864 */  iRegLNoSp_rule,
  /*  865 */  iRegLNoSp_rule,
  /*  866 */  iRegLNoSp_rule,
  /*  867 */  iRegINoSp_rule,
  /*  868 */  iRegINoSp_rule,
  /*  869 */  iRegINoSp_rule,
  /*  870 */  iRegINoSp_rule,
  /*  871 */  0,
  /*  872 */  0,
  /*  873 */  iRegLNoSp_rule,
  /*  874 */  iRegLNoSp_rule,
  /*  875 */  iRegLNoSp_rule,
  /*  876 */  iRegLNoSp_rule,
  /*  877 */  iRegINoSp_rule,
  /*  878 */  iRegINoSp_rule,
  /*  879 */  iRegINoSp_rule,
  /*  880 */  iRegINoSp_rule,
  /*  881 */  iRegLNoSp_rule,
  /*  882 */  iRegLNoSp_rule,
  /*  883 */  iRegLNoSp_rule,
  /*  884 */  iRegINoSp_rule,
  /*  885 */  iRegINoSp_rule,
  /*  886 */  iRegINoSp_rule,
  /*  887 */  iRegINoSp_rule,
  /*  888 */  iRegINoSp_rule,
  /*  889 */  iRegINoSp_rule,
  /*  890 */  iRegLNoSp_rule,
  /*  891 */  iRegLNoSp_rule,
  /*  892 */  iRegLNoSp_rule,
  /*  893 */  iRegLNoSp_rule,
  /*  894 */  iRegLNoSp_rule,
  /*  895 */  iRegLNoSp_rule,
  /*  896 */  iRegLNoSp_rule,
  /*  897 */  iRegLNoSp_rule,
  /*  898 */  iRegINoSp_rule,
  /*  899 */  iRegINoSp_rule,
  /*  900 */  iRegINoSp_rule,
  /*  901 */  iRegINoSp_rule,
  /*  902 */  iRegLNoSp_rule,
  /*  903 */  iRegLNoSp_rule,
  /*  904 */  iRegLNoSp_rule,
  /*  905 */  iRegLNoSp_rule,
  /*  906 */  iRegLNoSp_rule,
  /*  907 */  iRegLNoSp_rule,
  /*  908 */  iRegINoSp_rule,
  /*  909 */  iRegINoSp_rule,
  /*  910 */  iRegLNoSp_rule,
  /*  911 */  iRegLNoSp_rule,
  /*  912 */  iRegLNoSp_rule,
  /*  913 */  iRegLNoSp_rule,
  /*  914 */  iRegLNoSp_rule,
  /*  915 */  iRegLNoSp_rule,
  /*  916 */  iRegLNoSp_rule,
  /*  917 */  iRegLNoSp_rule,
  /*  918 */  iRegLNoSp_rule,
  /*  919 */  iRegLNoSp_rule,
  /*  920 */  iRegLNoSp_rule,
  /*  921 */  iRegLNoSp_rule,
  /*  922 */  iRegINoSp_rule,
  /*  923 */  iRegINoSp_rule,
  /*  924 */  iRegINoSp_rule,
  /*  925 */  iRegINoSp_rule,
  /*  926 */  iRegINoSp_rule,
  /*  927 */  iRegINoSp_rule,
  /*  928 */  iRegLNoSp_rule,
  /*  929 */  iRegLNoSp_rule,
  /*  930 */  iRegLNoSp_rule,
  /*  931 */  iRegLNoSp_rule,
  /*  932 */  iRegLNoSp_rule,
  /*  933 */  iRegLNoSp_rule,
  /*  934 */  iRegLNoSp_rule,
  /*  935 */  iRegLNoSp_rule,
  /*  936 */  iRegLNoSp_rule,
  /*  937 */  iRegLNoSp_rule,
  /*  938 */  iRegLNoSp_rule,
  /*  939 */  iRegLNoSp_rule,
  /*  940 */  iRegINoSp_rule,
  /*  941 */  iRegINoSp_rule,
  /*  942 */  iRegINoSp_rule,
  /*  943 */  iRegINoSp_rule,
  /*  944 */  iRegINoSp_rule,
  /*  945 */  iRegINoSp_rule,
  /*  946 */  vRegF_rule,
  /*  947 */  vRegD_rule,
  /*  948 */  vRegF_rule,
  /*  949 */  vRegD_rule,
  /*  950 */  vRegF_rule,
  /*  951 */  vRegD_rule,
  /*  952 */  vRegF_rule,
  /*  953 */  vRegD_rule,
  /*  954 */  vRegF_rule,
  /*  955 */  vRegF_rule,
  /*  956 */  vRegD_rule,
  /*  957 */  vRegD_rule,
  /*  958 */  vRegF_rule,
  /*  959 */  vRegF_rule,
  /*  960 */  vRegD_rule,
  /*  961 */  vRegD_rule,
  /*  962 */  vRegF_rule,
  /*  963 */  vRegD_rule,
  /*  964 */  vRegF_rule,
  /*  965 */  vRegF_rule,
  /*  966 */  vRegD_rule,
  /*  967 */  vRegD_rule,
  /*  968 */  vRegF_rule,
  /*  969 */  vRegD_rule,
  /*  970 */  iRegINoSp_rule,
  /*  971 */  iRegLNoSp_rule,
  /*  972 */  vRegD_rule,
  /*  973 */  vRegF_rule,
  /*  974 */  vRegD_rule,
  /*  975 */  vRegF_rule,
  /*  976 */  vRegD_rule,
  /*  977 */  vRegF_rule,
  /*  978 */  iRegINoSp_rule,
  /*  979 */  iRegINoSp_rule,
  /*  980 */  iRegINoSp_rule,
  /*  981 */  iRegINoSp_rule,
  /*  982 */  iRegINoSp_rule,
  /*  983 */  iRegINoSp_rule,
  /*  984 */  iRegLNoSp_rule,
  /*  985 */  iRegLNoSp_rule,
  /*  986 */  iRegLNoSp_rule,
  /*  987 */  iRegLNoSp_rule,
  /*  988 */  iRegLNoSp_rule,
  /*  989 */  iRegLNoSp_rule,
  /*  990 */  iRegLNoSp_rule,
  /*  991 */  iRegLNoSp_rule,
  /*  992 */  iRegINoSp_rule,
  /*  993 */  iRegINoSp_rule,
  /*  994 */  iRegINoSp_rule,
  /*  995 */  vRegF_rule,
  /*  996 */  vRegD_rule,
  /*  997 */  iRegINoSp_rule,
  /*  998 */  iRegLNoSp_rule,
  /*  999 */  vRegF_rule,
  /* 1000 */  vRegF_rule,
  /* 1001 */  iRegINoSp_rule,
  /* 1002 */  iRegLNoSp_rule,
  /* 1003 */  vRegD_rule,
  /* 1004 */  vRegD_rule,
  /* 1005 */  stackSlotI_rule,
  /* 1006 */  stackSlotF_rule,
  /* 1007 */  stackSlotL_rule,
  /* 1008 */  stackSlotD_rule,
  /* 1009 */  Universe_rule,
  /* 1010 */  Universe_rule,
  /* 1011 */  Universe_rule,
  /* 1012 */  Universe_rule,
  /* 1013 */  iRegINoSp_rule,
  /* 1014 */  iRegINoSp_rule,
  /* 1015 */  iRegINoSp_rule,
  /* 1016 */  iRegINoSp_rule,
  /* 1017 */  iRegINoSp_rule,
  /* 1018 */  iRegINoSp_rule,
  /* 1019 */  0,
  /* 1020 */  iRegINoSp_rule,
  /* 1021 */  0,
  /* 1022 */  iRegINoSp_rule,
  /* 1023 */  Universe_rule,
  /* 1024 */  Universe_rule,
  /* 1025 */  Universe_rule,
  /* 1026 */  Universe_rule,
  /* 1027 */  Universe_rule,
  /* 1028 */  Universe_rule,
  /* 1029 */  Universe_rule,
  /* 1030 */  Universe_rule,
  /* 1031 */  Universe_rule,
  /* 1032 */  Universe_rule,
  /* 1033 */  Universe_rule,
  /* 1034 */  Universe_rule,
  /* 1035 */  Universe_rule,
  /* 1036 */  Universe_rule,
  /* 1037 */  Universe_rule,
  /* 1038 */  Universe_rule,
  /* 1039 */  Universe_rule,
  /* 1040 */  Universe_rule,
  /* 1041 */  Universe_rule,
  /* 1042 */  Universe_rule,
  /* 1043 */  Universe_rule,
  /* 1044 */  Universe_rule,
  /* 1045 */  Universe_rule,
  /* 1046 */  Universe_rule,
  /* 1047 */  Universe_rule,
  /* 1048 */  Universe_rule,
  /* 1049 */  Universe_rule,
  /* 1050 */  Universe_rule,
  /* 1051 */  iRegP_R0_rule,
  /* 1052 */  Universe_rule,
  /* 1053 */  Universe_rule,
  /* 1054 */  Universe_rule,
  /* 1055 */  iRegP_R5_rule,
  /* 1056 */  iRegI_R0_rule,
  /* 1057 */  iRegI_R0_rule,
  /* 1058 */  iRegI_R0_rule,
  /* 1059 */  iRegI_R0_rule,
  /* 1060 */  iRegI_R0_rule,
  /* 1061 */  iRegI_R0_rule,
  /* 1062 */  iRegI_R0_rule,
  /* 1063 */  iRegI_R0_rule,
  /* 1064 */  iRegI_R0_rule,
  /* 1065 */  iRegI_R0_rule,
  /* 1066 */  iRegI_R0_rule,
  /* 1067 */  iRegI_R0_rule,
  /* 1068 */  iRegI_R0_rule,
  /* 1069 */  iRegI_R0_rule,
  /* 1070 */  iRegI_R0_rule,
  /* 1071 */  iRegI_R0_rule,
  /* 1072 */  iRegI_R0_rule,
  /* 1073 */  Universe_rule,
  /* 1074 */  iRegI_R0_rule,
  /* 1075 */  vecD_rule,
  /* 1076 */  vecD_rule,
  /* 1077 */  vecX_rule,
  /* 1078 */  Universe_rule,
  /* 1079 */  Universe_rule,
  /* 1080 */  Universe_rule,
  /* 1081 */  vecD_rule,
  /* 1082 */  vecX_rule,
  /* 1083 */  vecD_rule,
  /* 1084 */  vecX_rule,
  /* 1085 */  vecD_rule,
  /* 1086 */  vecX_rule,
  /* 1087 */  vecD_rule,
  /* 1088 */  vecX_rule,
  /* 1089 */  vecD_rule,
  /* 1090 */  vecX_rule,
  /* 1091 */  vecD_rule,
  /* 1092 */  vecX_rule,
  /* 1093 */  vecX_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecD_rule,
  /* 1096 */  vecX_rule,
  /* 1097 */  vecX_rule,
  /* 1098 */  iRegINoSp_rule,
  /* 1099 */  iRegINoSp_rule,
  /* 1100 */  iRegINoSp_rule,
  /* 1101 */  iRegINoSp_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegF_rule,
  /* 1104 */  vRegF_rule,
  /* 1105 */  vRegF_rule,
  /* 1106 */  vRegD_rule,
  /* 1107 */  vRegD_rule,
  /* 1108 */  vRegF_rule,
  /* 1109 */  vRegF_rule,
  /* 1110 */  vRegD_rule,
  /* 1111 */  vRegF_rule,
  /* 1112 */  vRegF_rule,
  /* 1113 */  vRegD_rule,
  /* 1114 */  vecD_rule,
  /* 1115 */  vecX_rule,
  /* 1116 */  vecD_rule,
  /* 1117 */  vecX_rule,
  /* 1118 */  vecD_rule,
  /* 1119 */  vecX_rule,
  /* 1120 */  vecX_rule,
  /* 1121 */  vecD_rule,
  /* 1122 */  vecX_rule,
  /* 1123 */  vecX_rule,
  /* 1124 */  vecD_rule,
  /* 1125 */  vecX_rule,
  /* 1126 */  vecD_rule,
  /* 1127 */  vecX_rule,
  /* 1128 */  vecD_rule,
  /* 1129 */  vecX_rule,
  /* 1130 */  vecX_rule,
  /* 1131 */  vecD_rule,
  /* 1132 */  vecX_rule,
  /* 1133 */  vecX_rule,
  /* 1134 */  vecD_rule,
  /* 1135 */  vecX_rule,
  /* 1136 */  vecD_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecD_rule,
  /* 1139 */  vecX_rule,
  /* 1140 */  vecD_rule,
  /* 1141 */  vecX_rule,
  /* 1142 */  vecX_rule,
  /* 1143 */  vecD_rule,
  /* 1144 */  vecD_rule,
  /* 1145 */  vecX_rule,
  /* 1146 */  vecX_rule,
  /* 1147 */  vecD_rule,
  /* 1148 */  vecD_rule,
  /* 1149 */  vecX_rule,
  /* 1150 */  vecX_rule,
  /* 1151 */  vecD_rule,
  /* 1152 */  vecX_rule,
  /* 1153 */  vecX_rule,
  /* 1154 */  vecD_rule,
  /* 1155 */  vecX_rule,
  /* 1156 */  vecD_rule,
  /* 1157 */  vecX_rule,
  /* 1158 */  vecD_rule,
  /* 1159 */  vecD_rule,
  /* 1160 */  vecX_rule,
  /* 1161 */  vecX_rule,
  /* 1162 */  vecX_rule,
  /* 1163 */  vecX_rule,
  /* 1164 */  vecD_rule,
  /* 1165 */  vecX_rule,
  /* 1166 */  vecX_rule,
  /* 1167 */  vecD_rule,
  /* 1168 */  vecX_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecX_rule,
  /* 1171 */  vecD_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecD_rule,
  /* 1174 */  vecX_rule,
  /* 1175 */  vecD_rule,
  /* 1176 */  vecX_rule,
  /* 1177 */  vecD_rule,
  /* 1178 */  vecX_rule,
  /* 1179 */  vecD_rule,
  /* 1180 */  vecX_rule,
  /* 1181 */  vecD_rule,
  /* 1182 */  vecX_rule,
  /* 1183 */  vecD_rule,
  /* 1184 */  vecX_rule,
  /* 1185 */  vecD_rule,
  /* 1186 */  vecX_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecX_rule,
  /* 1189 */  vecD_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  vecD_rule,
  /* 1192 */  vecX_rule,
  /* 1193 */  vecD_rule,
  /* 1194 */  vecX_rule,
  /* 1195 */  vecD_rule,
  /* 1196 */  vecX_rule,
  /* 1197 */  vecD_rule,
  /* 1198 */  vecX_rule,
  /* 1199 */  vecD_rule,
  /* 1200 */  vecX_rule,
  /* 1201 */  vecD_rule,
  /* 1202 */  vecX_rule,
  /* 1203 */  vecD_rule,
  /* 1204 */  vecX_rule,
  /* 1205 */  vecD_rule,
  /* 1206 */  vecX_rule,
  /* 1207 */  vecD_rule,
  /* 1208 */  vecX_rule,
  /* 1209 */  vecX_rule,
  /* 1210 */  vecX_rule,
  /* 1211 */  vecX_rule,
  /* 1212 */  vecX_rule,
  /* 1213 */  vecX_rule,
  /* 1214 */  vecX_rule,
  /* 1215 */  vecD_rule,
  /* 1216 */  vecX_rule,
  /* 1217 */  vecX_rule,
  /* 1218 */  vecD_rule,
  /* 1219 */  vecX_rule,
  /* 1220 */  vecX_rule,
  /* 1221 */  iRegPNoSp_rule,
  /* 1222 */  iRegPNoSp_rule,
  /* 1223 */  iRegPNoSp_rule,
  /* 1224 */  iRegINoSp_rule,
  /* 1225 */  iRegINoSp_rule,
  /* 1226 */  iRegINoSp_rule,
  /* 1227 */  iRegINoSp_rule,
  /* 1228 */  iRegPNoSp_rule,
  /* 1229 */  iRegPNoSp_rule,
  /* 1230 */  iRegPNoSp_rule,
  /* 1231 */  iRegPNoSp_rule,
  /* 1232 */  vReg_rule,
  /* 1233 */  Universe_rule,
  /* 1234 */  vReg_rule,
  /* 1235 */  vReg_rule,
  /* 1236 */  vReg_rule,
  /* 1237 */  vReg_rule,
  /* 1238 */  vReg_rule,
  /* 1239 */  vReg_rule,
  /* 1240 */  vReg_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  vReg_rule,
  /* 1246 */  vReg_rule,
  /* 1247 */  vReg_rule,
  /* 1248 */  vReg_rule,
  /* 1249 */  vReg_rule,
  /* 1250 */  vReg_rule,
  /* 1251 */  vReg_rule,
  /* 1252 */  vReg_rule,
  /* 1253 */  vReg_rule,
  /* 1254 */  vReg_rule,
  /* 1255 */  vReg_rule,
  /* 1256 */  vReg_rule,
  /* 1257 */  vReg_rule,
  /* 1258 */  vReg_rule,
  /* 1259 */  vReg_rule,
  /* 1260 */  vReg_rule,
  /* 1261 */  vReg_rule,
  /* 1262 */  vReg_rule,
  /* 1263 */  vReg_rule,
  /* 1264 */  vReg_rule,
  /* 1265 */  vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  vReg_rule,
  /* 1268 */  vReg_rule,
  /* 1269 */  vReg_rule,
  /* 1270 */  vReg_rule,
  /* 1271 */  iRegINoSp_rule,
  /* 1272 */  iRegLNoSp_rule,
  /* 1273 */  vRegF_rule,
  /* 1274 */  vRegD_rule,
  /* 1275 */  vReg_rule,
  /* 1276 */  vReg_rule,
  /* 1277 */  vReg_rule,
  /* 1278 */  vReg_rule,
  /* 1279 */  vReg_rule,
  /* 1280 */  vReg_rule,
  /* 1281 */  vReg_rule,
  /* 1282 */  vReg_rule,
  /* 1283 */  vReg_rule,
  /* 1284 */  vReg_rule,
  /* 1285 */  vReg_rule,
  /* 1286 */  vReg_rule,
  /* 1287 */  vReg_rule,
  /* 1288 */  vReg_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  vReg_rule,
  /* 1294 */  vReg_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  vReg_rule,
  /* 1297 */  vReg_rule,
  /* 1298 */  vReg_rule,
  /* 1299 */  vReg_rule,
  /* 1300 */  vReg_rule,
  /* 1301 */  vReg_rule,
  /* 1302 */  vReg_rule,
  /* 1303 */  vReg_rule,
  /* 1304 */  vReg_rule,
  /* 1305 */  vReg_rule,
  /* 1306 */  vReg_rule,
  /* 1307 */  vReg_rule,
  /* 1308 */  vReg_rule,
  /* 1309 */  vReg_rule,
  /* 1310 */  vReg_rule,
  /* 1311 */  vReg_rule,
  /* 1312 */  vReg_rule,
  /* 1313 */  vReg_rule,
  /* 1314 */  vReg_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  iRegP_rule,
  /*  148 */  iRegP_rule,
  /*  149 */  iRegP_rule,
  /*  150 */  iRegP_rule,
  /*  151 */  iRegP_rule,
  /*  152 */  iRegP_rule,
  /*  153 */  iRegP_rule,
  /*  154 */  iRegP_rule,
  /*  155 */  iRegP_rule,
  /*  156 */  iRegP_rule,
  /*  157 */  iRegP_rule,
  /*  158 */  iRegP_rule,
  /*  159 */  iRegN_rule,
  /*  160 */  _DecodeN_iRegN__rule,
  /*  161 */  _DecodeN_iRegN__rule,
  /*  162 */  _DecodeN_iRegN__rule,
  /*  163 */  _DecodeN_iRegN__rule,
  /*  164 */  _DecodeN_iRegN__rule,
  /*  165 */  _DecodeN_iRegN__rule,
  /*  166 */  thread_RegP_rule,
  /*  167 */  0,
  /*  168 */  0,
  /*  169 */  0,
  /*  170 */  0,
  /*  171 */  0,
  /*  172 */  0,
  /*  173 */  0,
  /*  174 */  0,
  /*  175 */  0,
  /*  176 */  0,
  /*  177 */  iRegL_rule,
  /*  178 */  0,
  /*  179 */  0,
  /*  180 */  iRegP_rule,
  /*  181 */  iRegP_rule,
  // last operand
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  // last operand class
  /*  188 */  iRegI_rule,
  /*  189 */  _ConvI2L_iRegI__rule,
  /*  190 */  iRegL_rule,
  /*  191 */  iRegN_rule,
  /*  192 */  memory_rule,
  /*  193 */  memory_rule,
  /*  194 */  memory_rule,
  /*  195 */  memory_rule,
  /*  196 */  memory_rule,
  /*  197 */  _LoadI_memory__rule,
  /*  198 */  indirect_rule,
  /*  199 */  indirect_rule,
  /*  200 */  indirect_rule,
  /*  201 */  indirect_rule,
  /*  202 */  indirect_rule,
  /*  203 */  _LoadI_indirect__rule,
  /*  204 */  memory_rule,
  /*  205 */  iRegP_rule,
  /*  206 */  _DecodeN_iRegN__rule,
  /*  207 */  iRegP_rule,
  /*  208 */  iRegLNoSp_rule,
  /*  209 */  iRegINoSp_rule,
  /*  210 */  iRegNNoSp_rule,
  /*  211 */  iRegI_rule,
  /*  212 */  iRegL_rule,
  /*  213 */  iRegN_rule,
  /*  214 */  cmpOp_rule,
  /*  215 */  iRegIorL2I_rule,
  /*  216 */  cmpOpU_rule,
  /*  217 */  immI0_rule,
  /*  218 */  iRegIorL2I_rule,
  /*  219 */  immI_1_rule,
  /*  220 */  iRegL_rule,
  /*  221 */  immL0_rule,
  /*  222 */  iRegP_rule,
  /*  223 */  immP0_rule,
  /*  224 */  iRegN_rule,
  /*  225 */  immN0_rule,
  /*  226 */  vRegF_rule,
  /*  227 */  vRegD_rule,
  /*  228 */  iRegL_rule,
  /*  229 */  iRegIorL2I_rule,
  /*  230 */  _ConvI2L_iRegIorL2I__rule,
  /*  231 */  iRegIorL2I_rule,
  /*  232 */  iRegL_rule,
  /*  233 */  _ConvI2L_iRegIorL2I__rule,
  /*  234 */  immL0_rule,
  /*  235 */  iRegIorL2I_rule,
  /*  236 */  iRegL_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  iRegL_rule,
  /*  239 */  iRegIorL2I_rule,
  /*  240 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  241 */  iRegL_rule,
  /*  242 */  _URShiftL_iRegL_immI_rule,
  /*  243 */  iRegIorL2I_rule,
  /*  244 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  245 */  iRegL_rule,
  /*  246 */  _RShiftL_iRegL_immI_rule,
  /*  247 */  iRegIorL2I_rule,
  /*  248 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  249 */  iRegL_rule,
  /*  250 */  _LShiftL_iRegL_immI_rule,
  /*  251 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  252 */  iRegIorL2I_rule,
  /*  253 */  _URShiftL_iRegL_immI_rule,
  /*  254 */  iRegL_rule,
  /*  255 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  256 */  iRegIorL2I_rule,
  /*  257 */  _RShiftL_iRegL_immI_rule,
  /*  258 */  iRegL_rule,
  /*  259 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  260 */  iRegIorL2I_rule,
  /*  261 */  _LShiftL_iRegL_immI_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  264 */  iRegIorL2I_rule,
  /*  265 */  iRegL_rule,
  /*  266 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  267 */  iRegL_rule,
  /*  268 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  269 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  270 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  271 */  iRegI_rule,
  /*  272 */  iRegL_rule,
  /*  273 */  immI_64_rule,
  /*  274 */  iRegL_rule,
  /*  275 */  immI0_rule,
  /*  276 */  iRegL_rule,
  /*  277 */  iRegI_rule,
  /*  278 */  immI_32_rule,
  /*  279 */  iRegI_rule,
  /*  280 */  iRegI_rule,
  /*  281 */  iRegL_rule,
  /*  282 */  iRegL_rule,
  /*  283 */  iRegL_rule,
  /*  284 */  iRegI_rule,
  /*  285 */  iRegI_rule,
  /*  286 */  iRegI_rule,
  /*  287 */  iRegIorL2I_rule,
  /*  288 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  289 */  iRegIorL2I_rule,
  /*  290 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  291 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  292 */  iRegL_rule,
  /*  293 */  _LShiftL_iRegL_immI_48_rule,
  /*  294 */  iRegL_rule,
  /*  295 */  _LShiftL_iRegL_immI_32_rule,
  /*  296 */  iRegL_rule,
  /*  297 */  _LShiftL_iRegL_immI_56_rule,
  /*  298 */  _LShiftL_iRegL_immI_56_rule,
  /*  299 */  iRegIorL2I_rule,
  /*  300 */  iRegIorL2I_rule,
  /*  301 */  iRegL_rule,
  /*  302 */  iRegL_rule,
  /*  303 */  iRegL_rule,
  /*  304 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  305 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  306 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  307 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  308 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  309 */  _ConvI2L_iRegIorL2I__rule,
  /*  310 */  _AndL_iRegL_immL_255_rule,
  /*  311 */  _AndL_iRegL_immL_65535_rule,
  /*  312 */  _AndL_iRegL_immL_4294967295_rule,
  /*  313 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  314 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  315 */  vRegF_rule,
  /*  316 */  _NegF_vRegF__rule,
  /*  317 */  vRegF_rule,
  /*  318 */  vRegD_rule,
  /*  319 */  _NegD_vRegD__rule,
  /*  320 */  vRegD_rule,
  /*  321 */  iRegIorL2I_rule,
  /*  322 */  iRegL_rule,
  /*  323 */  iRegIorL2I_rule,
  /*  324 */  iRegL_rule,
  /*  325 */  iRegP_rule,
  /*  326 */  iRegN_rule,
  /*  327 */  _DecodeN_iRegN__rule,
  /*  328 */  iRegIorL2I_rule,
  /*  329 */  iRegL_rule,
  /*  330 */  iRegL_rule,
  /*  331 */  _AndL_iRegL_immL_rule,
  /*  332 */  iRegIorL2I_rule,
  /*  333 */  _AndI_iRegIorL2I_immI_rule,
  /*  334 */  iRegL_rule,
  /*  335 */  iRegIorL2I_rule,
  /*  336 */  iRegP_R4_rule,
  /*  337 */  iRegP_R1_rule,
  /*  338 */  iRegP_R3_rule,
  /*  339 */  iRegP_R1_rule,
  /*  340 */  iRegP_R3_rule,
  /*  341 */  iRegP_R3_rule,
  /*  342 */  iRegP_R3_rule,
  /*  343 */  iRegP_R1_rule,
  /*  344 */  iRegP_R1_rule,
  /*  345 */  vecD_rule,
  /*  346 */  vecX_rule,
  /*  347 */  vecD_rule,
  /*  348 */  vecX_rule,
  /*  349 */  vecD_rule,
  /*  350 */  vecX_rule,
  /*  351 */  vecD_rule,
  /*  352 */  _NegVF_vecD__rule,
  /*  353 */  vecD_rule,
  /*  354 */  vecX_rule,
  /*  355 */  _NegVF_vecX__rule,
  /*  356 */  vecX_rule,
  /*  357 */  vecX_rule,
  /*  358 */  _NegVD_vecX__rule,
  /*  359 */  vecX_rule,
  /*  360 */  vReg_rule,
  /*  361 */  vReg_rule,
  /*  362 */  _NegVF_vReg__rule,
  /*  363 */  vReg_rule,
  /*  364 */  vReg_rule,
  /*  365 */  _NegVD_vReg__rule,
  /*  366 */  vReg_rule,
  /*  367 */  vReg_rule,
  /*  368 */  vReg_rule,
  /*  369 */  vReg_rule,
  // last internally defined operand
  /*  370 */  immI_rule,
  /*  371 */  immL_rule,
  /*  372 */  immP_rule,
  /*  373 */  immP0_rule,
  /*  374 */  immP_1_rule,
  /*  375 */  immPollPage_rule,
  /*  376 */  immByteMapBase_rule,
  /*  377 */  immN_rule,
  /*  378 */  immN0_rule,
  /*  379 */  immNKlass_rule,
  /*  380 */  immFPacked_rule,
  /*  381 */  immF_rule,
  /*  382 */  immDPacked_rule,
  /*  383 */  immD_rule,
  /*  384 */  iRegIorL2I_rule,
  /*  385 */  iRegL_rule,
  /*  386 */  iRegIorL2I_rule,
  /*  387 */  iRegL_rule,
  /*  388 */  iRegL_rule,
  /*  389 */  iRegP_rule,
  /*  390 */  iRegPNoSp_rule,
  /*  391 */  iRegPNoSp_rule,
  /*  392 */  iRegI_rule,
  /*  393 */  iRegL_rule,
  /*  394 */  memory_rule,
  /*  395 */  indirect_rule,
  /*  396 */  indirect_rule,
  /*  397 */  vRegF_rule,
  /*  398 */  vRegD_rule,
  /*  399 */  vRegF_rule,
  /*  400 */  vRegD_rule,
  /*  401 */  stackSlotF_rule,
  /*  402 */  stackSlotI_rule,
  /*  403 */  stackSlotD_rule,
  /*  404 */  stackSlotL_rule,
  /*  405 */  vRegF_rule,
  /*  406 */  iRegI_rule,
  /*  407 */  vRegD_rule,
  /*  408 */  iRegL_rule,
  /*  409 */  iRegIorL2I_rule,
  /*  410 */  iRegIorL2I_rule,
  /*  411 */  iRegL_rule,
  /*  412 */  iRegL_rule,
  /*  413 */  iRegIorL2I_rule,
  /*  414 */  iRegIorL2I_rule,
  /*  415 */  iRegL_rule,
  /*  416 */  iRegL_rule,
  /*  417 */  immI0_rule,
  /*  418 */  immI0_rule,
  /*  419 */  iRegIorL2I_rule,
  /*  420 */  iRegL_rule,
  /*  421 */  iRegI_rule,
  /*  422 */  iRegI_rule,
  /*  423 */  iRegI_rule,
  /*  424 */  iRegI_rule,
  /*  425 */  iRegI_rule,
  /*  426 */  iRegI_rule,
  /*  427 */  iRegI_rule,
  /*  428 */  iRegI_rule,
  /*  429 */  iRegL_rule,
  /*  430 */  iRegL_rule,
  /*  431 */  iRegL_rule,
  /*  432 */  iRegL_rule,
  /*  433 */  iRegL_rule,
  /*  434 */  iRegL_rule,
  /*  435 */  iRegL_rule,
  /*  436 */  iRegL_rule,
  /*  437 */  iRegP_rule,
  /*  438 */  iRegN_rule,
  /*  439 */  iRegP_rule,
  /*  440 */  iRegN_rule,
  /*  441 */  vRegF_rule,
  /*  442 */  vRegF_rule,
  /*  443 */  vRegD_rule,
  /*  444 */  vRegD_rule,
  /*  445 */  _AndL_iRegL_immL_rule,
  /*  446 */  _AndI_iRegIorL2I_immI_rule,
  /*  447 */  _AndL_iRegL_iRegL_rule,
  /*  448 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  449 */  iRegP_rule,
  /*  450 */  iRegP_rule,
  /*  451 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  452 */  0,
  /*  453 */  vecD_rule,
  /*  454 */  vecX_rule,
  /*  455 */  vecX_rule,
  /*  456 */  vecD_rule,
  /*  457 */  vecX_rule,
  /*  458 */  vecD_rule,
  /*  459 */  vecX_rule,
  /*  460 */  vecD_rule,
  /*  461 */  vecX_rule,
  /*  462 */  vecX_rule,
  /*  463 */  vecD_rule,
  /*  464 */  vecX_rule,
  /*  465 */  vecX_rule,
  /*  466 */  vecD_rule,
  /*  467 */  vecX_rule,
  /*  468 */  vecX_rule,
  /*  469 */  iRegIorL2I_rule,
  /*  470 */  iRegIorL2I_rule,
  /*  471 */  iRegIorL2I_rule,
  /*  472 */  iRegIorL2I_rule,
  /*  473 */  vecX_rule,
  /*  474 */  vecD_rule,
  /*  475 */  vReg_rule,
  /*  476 */  vReg_rule,
  /*  477 */  vReg_rule,
  /*  478 */  iRegIorL2I_rule,
  /*  479 */  iRegIorL2I_rule,
  /*  480 */  iRegIorL2I_rule,
  /*  481 */  iRegIorL2I_rule,
  /*  482 */  iRegIorL2I_rule,
  /*  483 */  iRegIorL2I_rule,
  /*  484 */  iRegIorL2I_rule,
  /*  485 */  iRegIorL2I_rule,
  /*  486 */  vReg_rule,
  /*  487 */  vReg_rule,
  /*  488 */  memory_rule,
  /*  489 */  _LoadB_memory__rule,
  /*  490 */  memory_rule,
  /*  491 */  _LoadUB_memory__rule,
  /*  492 */  memory_rule,
  /*  493 */  _LoadS_memory__rule,
  /*  494 */  memory_rule,
  /*  495 */  _LoadUS_memory__rule,
  /*  496 */  memory_rule,
  /*  497 */  _LoadI_memory__rule,
  /*  498 */  _ConvI2L__LoadI_memory___rule,
  /*  499 */  memory_rule,
  /*  500 */  memory_rule,
  /*  501 */  memory_rule,
  /*  502 */  memory_rule,
  /*  503 */  memory_rule,
  /*  504 */  memory_rule,
  /*  505 */  memory_rule,
  /*  506 */  memory_rule,
  /*  507 */  memory_rule,
  /*  508 */  memory_rule,
  /*  509 */  memory_rule,
  /*  510 */  memory_rule,
  /*  511 */  memory_rule,
  /*  512 */  memory_rule,
  /*  513 */  memory_rule,
  /*  514 */  memory_rule,
  /*  515 */  memory_rule,
  /*  516 */  memory_rule,
  /*  517 */  memory_rule,
  /*  518 */  memory_rule,
  /*  519 */  memory_rule,
  /*  520 */  memory_rule,
  /*  521 */  memory_rule,
  /*  522 */  memory_rule,
  /*  523 */  memory_rule,
  /*  524 */  memory_rule,
  /*  525 */  indirect_rule,
  /*  526 */  _LoadB_indirect__rule,
  /*  527 */  indirect_rule,
  /*  528 */  _LoadUB_indirect__rule,
  /*  529 */  indirect_rule,
  /*  530 */  indirect_rule,
  /*  531 */  _LoadUS_indirect__rule,
  /*  532 */  _LoadS_indirect__rule,
  /*  533 */  indirect_rule,
  /*  534 */  _ConvI2L__LoadI_indirect___rule,
  /*  535 */  indirect_rule,
  /*  536 */  indirect_rule,
  /*  537 */  indirect_rule,
  /*  538 */  indirect_rule,
  /*  539 */  indirect_rule,
  /*  540 */  indirect_rule,
  /*  541 */  indirect_rule,
  /*  542 */  indirect_rule,
  /*  543 */  indirect_rule,
  /*  544 */  indirect_rule,
  /*  545 */  indirect_rule,
  /*  546 */  indirect_rule,
  /*  547 */  indirect_rule,
  /*  548 */  iRegIorL2I_rule,
  /*  549 */  iRegL_rule,
  /*  550 */  iRegIorL2I_rule,
  /*  551 */  iRegIorL2I_rule,
  /*  552 */  iRegIorL2I_rule,
  /*  553 */  _LoadI_memory__rule,
  /*  554 */  iRegL_rule,
  /*  555 */  _LoadL_memory__rule,
  /*  556 */  0,
  /*  557 */  0,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  0,
  /*  561 */  0,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  0,
  /*  566 */  0,
  /*  567 */  _CastP2X_iRegP__rule,
  /*  568 */  _CastP2X__DecodeN_iRegN___rule,
  /*  569 */  iRegP_rule,
  /*  570 */  iRegP_rule,
  /*  571 */  iRegN_rule,
  /*  572 */  iRegN_rule,
  /*  573 */  iRegP_rule,
  /*  574 */  iRegN_rule,
  /*  575 */  indirect_rule,
  /*  576 */  indirect_rule,
  /*  577 */  indirect_rule,
  /*  578 */  indirect_rule,
  /*  579 */  indirect_rule,
  /*  580 */  indirect_rule,
  /*  581 */  indirect_rule,
  /*  582 */  indirect_rule,
  /*  583 */  indirect_rule,
  /*  584 */  indirect_rule,
  /*  585 */  indirect_rule,
  /*  586 */  indirect_rule,
  /*  587 */  indirect_rule,
  /*  588 */  indirect_rule,
  /*  589 */  indirect_rule,
  /*  590 */  indirect_rule,
  /*  591 */  indirect_rule,
  /*  592 */  indirect_rule,
  /*  593 */  indirect_rule,
  /*  594 */  indirect_rule,
  /*  595 */  indirect_rule,
  /*  596 */  indirect_rule,
  /*  597 */  indirect_rule,
  /*  598 */  indirect_rule,
  /*  599 */  indirect_rule,
  /*  600 */  indirect_rule,
  /*  601 */  indirect_rule,
  /*  602 */  indirect_rule,
  /*  603 */  indirect_rule,
  /*  604 */  indirect_rule,
  /*  605 */  indirect_rule,
  /*  606 */  indirect_rule,
  /*  607 */  indirect_rule,
  /*  608 */  indirect_rule,
  /*  609 */  indirect_rule,
  /*  610 */  indirect_rule,
  /*  611 */  indirect_rule,
  /*  612 */  indirect_rule,
  /*  613 */  indirect_rule,
  /*  614 */  indirect_rule,
  /*  615 */  indirect_rule,
  /*  616 */  indirect_rule,
  /*  617 */  indirect_rule,
  /*  618 */  indirect_rule,
  /*  619 */  indirect_rule,
  /*  620 */  indirect_rule,
  /*  621 */  indirect_rule,
  /*  622 */  indirect_rule,
  /*  623 */  indirect_rule,
  /*  624 */  indirect_rule,
  /*  625 */  indirect_rule,
  /*  626 */  indirect_rule,
  /*  627 */  indirect_rule,
  /*  628 */  indirect_rule,
  /*  629 */  indirect_rule,
  /*  630 */  indirect_rule,
  /*  631 */  indirect_rule,
  /*  632 */  indirect_rule,
  /*  633 */  indirect_rule,
  /*  634 */  indirect_rule,
  /*  635 */  indirect_rule,
  /*  636 */  iRegL_rule,
  /*  637 */  iRegL_rule,
  /*  638 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  639 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  640 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  641 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  642 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  643 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  644 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  645 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  646 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  647 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  648 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  649 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  650 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  651 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  652 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  653 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  654 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  655 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  656 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  657 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  658 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  659 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  660 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  661 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  662 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  663 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  664 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  665 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  666 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  667 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  668 */  iRegIorL2I_rule,
  /*  669 */  iRegIorL2I_rule,
  /*  670 */  _ConvL2I_iRegL__rule,
  /*  671 */  iRegP_rule,
  /*  672 */  iRegP_rule,
  /*  673 */  iRegP_rule,
  /*  674 */  iRegP_rule,
  /*  675 */  _ConvI2L_iRegIorL2I__rule,
  /*  676 */  iRegP_rule,
  /*  677 */  iRegL_rule,
  /*  678 */  iRegL_rule,
  /*  679 */  iRegIorL2I_rule,
  /*  680 */  iRegIorL2I_rule,
  /*  681 */  iRegL_rule,
  /*  682 */  iRegL_rule,
  /*  683 */  immI0_rule,
  /*  684 */  immL0_rule,
  /*  685 */  iRegIorL2I_rule,
  /*  686 */  _ConvI2L_iRegIorL2I__rule,
  /*  687 */  _ConvI2L_iRegIorL2I__rule,
  /*  688 */  iRegL_rule,
  /*  689 */  iRegL_rule,
  /*  690 */  iRegIorL2I_rule,
  /*  691 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  692 */  iRegIorL2I_rule,
  /*  693 */  iRegL_rule,
  /*  694 */  _MulL_iRegL_iRegL_rule,
  /*  695 */  iRegL_rule,
  /*  696 */  iRegLNoSp_rule,
  /*  697 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  698 */  iRegLNoSp_rule,
  /*  699 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  700 */  iRegLNoSp_rule,
  /*  701 */  iRegLNoSp_rule,
  /*  702 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  703 */  _ConvI2L_iRegIorL2I__rule,
  /*  704 */  _ConvI2L_iRegIorL2I__rule,
  /*  705 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  706 */  iRegIorL2I_rule,
  /*  707 */  iRegL_rule,
  /*  708 */  iRegIorL2I_rule,
  /*  709 */  iRegL_rule,
  /*  710 */  iRegIorL2I_rule,
  /*  711 */  iRegIorL2I_rule,
  /*  712 */  iRegIorL2I_rule,
  /*  713 */  iRegIorL2I_rule,
  /*  714 */  iRegIorL2I_rule,
  /*  715 */  iRegIorL2I_rule,
  /*  716 */  iRegL_rule,
  /*  717 */  iRegL_rule,
  /*  718 */  iRegL_rule,
  /*  719 */  iRegL_rule,
  /*  720 */  _CastP2X_iRegP__rule,
  /*  721 */  iRegL_rule,
  /*  722 */  iRegL_rule,
  /*  723 */  iRegL_rule,
  /*  724 */  iRegIorL2I_rule,
  /*  725 */  iRegIorL2I_rule,
  /*  726 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  727 */  iRegL_rule,
  /*  728 */  _XorL_iRegL_immL_M1_rule,
  /*  729 */  iRegIorL2I_rule,
  /*  730 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  731 */  iRegL_rule,
  /*  732 */  _XorL_iRegL_immL_M1_rule,
  /*  733 */  immI_M1_rule,
  /*  734 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  735 */  immL_M1_rule,
  /*  736 */  _XorL_iRegL_iRegL_rule,
  /*  737 */  iRegIorL2I_rule,
  /*  738 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  739 */  iRegL_rule,
  /*  740 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  741 */  iRegIorL2I_rule,
  /*  742 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  743 */  iRegL_rule,
  /*  744 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  745 */  iRegIorL2I_rule,
  /*  746 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  747 */  iRegL_rule,
  /*  748 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  749 */  immI_M1_rule,
  /*  750 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  751 */  immI_M1_rule,
  /*  752 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  753 */  immL_M1_rule,
  /*  754 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  755 */  immL_M1_rule,
  /*  756 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  757 */  immI_M1_rule,
  /*  758 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  759 */  immI_M1_rule,
  /*  760 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  761 */  immL_M1_rule,
  /*  762 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  763 */  immL_M1_rule,
  /*  764 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  765 */  immI_M1_rule,
  /*  766 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  767 */  immI_M1_rule,
  /*  768 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  769 */  immL_M1_rule,
  /*  770 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  771 */  immL_M1_rule,
  /*  772 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  773 */  iRegIorL2I_rule,
  /*  774 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  775 */  iRegL_rule,
  /*  776 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  777 */  iRegIorL2I_rule,
  /*  778 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  779 */  iRegL_rule,
  /*  780 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  781 */  iRegIorL2I_rule,
  /*  782 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  783 */  iRegL_rule,
  /*  784 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  785 */  iRegIorL2I_rule,
  /*  786 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  787 */  iRegL_rule,
  /*  788 */  _URShiftL_iRegL_immI_rule,
  /*  789 */  iRegIorL2I_rule,
  /*  790 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  791 */  iRegL_rule,
  /*  792 */  _RShiftL_iRegL_immI_rule,
  /*  793 */  iRegIorL2I_rule,
  /*  794 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  795 */  iRegL_rule,
  /*  796 */  _LShiftL_iRegL_immI_rule,
  /*  797 */  iRegIorL2I_rule,
  /*  798 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  799 */  iRegL_rule,
  /*  800 */  _URShiftL_iRegL_immI_rule,
  /*  801 */  iRegIorL2I_rule,
  /*  802 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  803 */  iRegL_rule,
  /*  804 */  _RShiftL_iRegL_immI_rule,
  /*  805 */  iRegIorL2I_rule,
  /*  806 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  807 */  iRegL_rule,
  /*  808 */  _LShiftL_iRegL_immI_rule,
  /*  809 */  iRegIorL2I_rule,
  /*  810 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  811 */  iRegL_rule,
  /*  812 */  _URShiftL_iRegL_immI_rule,
  /*  813 */  iRegIorL2I_rule,
  /*  814 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  815 */  iRegL_rule,
  /*  816 */  _RShiftL_iRegL_immI_rule,
  /*  817 */  iRegIorL2I_rule,
  /*  818 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  819 */  iRegL_rule,
  /*  820 */  _LShiftL_iRegL_immI_rule,
  /*  821 */  iRegIorL2I_rule,
  /*  822 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  823 */  iRegL_rule,
  /*  824 */  _URShiftL_iRegL_immI_rule,
  /*  825 */  iRegIorL2I_rule,
  /*  826 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  827 */  iRegL_rule,
  /*  828 */  _RShiftL_iRegL_immI_rule,
  /*  829 */  iRegIorL2I_rule,
  /*  830 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  831 */  iRegL_rule,
  /*  832 */  _LShiftL_iRegL_immI_rule,
  /*  833 */  iRegIorL2I_rule,
  /*  834 */  iRegL_rule,
  /*  835 */  iRegIorL2I_rule,
  /*  836 */  iRegL_rule,
  /*  837 */  iRegIorL2I_rule,
  /*  838 */  iRegL_rule,
  /*  839 */  _LShiftL_iRegL_immI_rule,
  /*  840 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  841 */  _LShiftL_iRegL_immI_rule,
  /*  842 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  843 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  844 */  _URShiftL_iRegL_immI_rule,
  /*  845 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  846 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  847 */  _AndL_iRegL_immL_bitmask_rule,
  /*  848 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  849 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  850 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  851 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  852 */  _AndI_iRegI_immI_bitmask_rule,
  /*  853 */  _LShiftL_iRegL_immI_rule,
  /*  854 */  _URShiftL_iRegL_immI_rule,
  /*  855 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  856 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  857 */  _LShiftL_iRegL_immI_rule,
  /*  858 */  _URShiftL_iRegL_immI_rule,
  /*  859 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  860 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  _LShiftL_iRegL_iRegI_rule,
  /*  864 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  865 */  _LShiftL_iRegL_iRegI_rule,
  /*  866 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  867 */  _LShiftI_iRegI_iRegI_rule,
  /*  868 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  869 */  _LShiftI_iRegI_iRegI_rule,
  /*  870 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  871 */  0,
  /*  872 */  0,
  /*  873 */  _URShiftL_iRegL_iRegI_rule,
  /*  874 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  875 */  _URShiftL_iRegL_iRegI_rule,
  /*  876 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  877 */  _URShiftI_iRegI_iRegI_rule,
  /*  878 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  879 */  _URShiftI_iRegI_iRegI_rule,
  /*  880 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  881 */  iRegL_rule,
  /*  882 */  _ConvI2L_iRegIorL2I__rule,
  /*  883 */  iRegL_rule,
  /*  884 */  iRegIorL2I_rule,
  /*  885 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  886 */  iRegIorL2I_rule,
  /*  887 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  888 */  iRegIorL2I_rule,
  /*  889 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  890 */  iRegL_rule,
  /*  891 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  892 */  iRegL_rule,
  /*  893 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  894 */  iRegL_rule,
  /*  895 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  896 */  iRegL_rule,
  /*  897 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  898 */  iRegIorL2I_rule,
  /*  899 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  900 */  iRegIorL2I_rule,
  /*  901 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  902 */  iRegL_rule,
  /*  903 */  _AndL_iRegL_immL_255_rule,
  /*  904 */  iRegL_rule,
  /*  905 */  _AndL_iRegL_immL_65535_rule,
  /*  906 */  iRegL_rule,
  /*  907 */  _AndL_iRegL_immL_4294967295_rule,
  /*  908 */  iRegIorL2I_rule,
  /*  909 */  iRegIorL2I_rule,
  /*  910 */  iRegL_rule,
  /*  911 */  iRegL_rule,
  /*  912 */  iRegL_rule,
  /*  913 */  iRegL_rule,
  /*  914 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  915 */  iRegL_rule,
  /*  916 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  917 */  iRegL_rule,
  /*  918 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  919 */  iRegL_rule,
  /*  920 */  iRegL_rule,
  /*  921 */  iRegL_rule,
  /*  922 */  iRegIorL2I_rule,
  /*  923 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  924 */  iRegIorL2I_rule,
  /*  925 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  926 */  iRegIorL2I_rule,
  /*  927 */  iRegIorL2I_rule,
  /*  928 */  iRegL_rule,
  /*  929 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  930 */  iRegL_rule,
  /*  931 */  iRegL_rule,
  /*  932 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  933 */  iRegL_rule,
  /*  934 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  935 */  iRegL_rule,
  /*  936 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  937 */  iRegL_rule,
  /*  938 */  iRegL_rule,
  /*  939 */  iRegL_rule,
  /*  940 */  iRegIorL2I_rule,
  /*  941 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  942 */  iRegIorL2I_rule,
  /*  943 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  944 */  iRegIorL2I_rule,
  /*  945 */  iRegIorL2I_rule,
  /*  946 */  vRegF_rule,
  /*  947 */  vRegD_rule,
  /*  948 */  vRegF_rule,
  /*  949 */  vRegD_rule,
  /*  950 */  vRegF_rule,
  /*  951 */  vRegD_rule,
  /*  952 */  vRegF_rule,
  /*  953 */  vRegD_rule,
  /*  954 */  vRegF_rule,
  /*  955 */  vRegF_rule,
  /*  956 */  vRegD_rule,
  /*  957 */  vRegD_rule,
  /*  958 */  _NegF_vRegF__rule,
  /*  959 */  _NegF_vRegF__rule,
  /*  960 */  _NegD_vRegD__rule,
  /*  961 */  _NegD_vRegD__rule,
  /*  962 */  _NegF_vRegF__rule,
  /*  963 */  _NegD_vRegD__rule,
  /*  964 */  vRegF_rule,
  /*  965 */  vRegF_rule,
  /*  966 */  vRegD_rule,
  /*  967 */  vRegD_rule,
  /*  968 */  vRegF_rule,
  /*  969 */  vRegD_rule,
  /*  970 */  iRegIorL2I_rule,
  /*  971 */  iRegL_rule,
  /*  972 */  vRegD_rule,
  /*  973 */  vRegF_rule,
  /*  974 */  vRegD_rule,
  /*  975 */  vRegF_rule,
  /*  976 */  vRegD_rule,
  /*  977 */  vRegF_rule,
  /*  978 */  iRegIorL2I_rule,
  /*  979 */  iRegIorL2I_rule,
  /*  980 */  iRegIorL2I_rule,
  /*  981 */  iRegIorL2I_rule,
  /*  982 */  iRegIorL2I_rule,
  /*  983 */  iRegIorL2I_rule,
  /*  984 */  iRegL_rule,
  /*  985 */  iRegL_rule,
  /*  986 */  iRegL_rule,
  /*  987 */  iRegL_rule,
  /*  988 */  iRegL_rule,
  /*  989 */  iRegL_rule,
  /*  990 */  iRegIorL2I_rule,
  /*  991 */  _ConvI2L_iRegIorL2I__rule,
  /*  992 */  iRegL_rule,
  /*  993 */  iRegIorL2I_rule,
  /*  994 */  iRegP_rule,
  /*  995 */  vRegD_rule,
  /*  996 */  vRegF_rule,
  /*  997 */  vRegF_rule,
  /*  998 */  vRegF_rule,
  /*  999 */  iRegIorL2I_rule,
  /* 1000 */  iRegL_rule,
  /* 1001 */  vRegD_rule,
  /* 1002 */  vRegD_rule,
  /* 1003 */  iRegIorL2I_rule,
  /* 1004 */  iRegL_rule,
  /* 1005 */  vRegF_rule,
  /* 1006 */  iRegI_rule,
  /* 1007 */  vRegD_rule,
  /* 1008 */  iRegL_rule,
  /* 1009 */  iRegL_R11_rule,
  /* 1010 */  immL_rule,
  /* 1011 */  cmpOp_rule,
  /* 1012 */  cmpOp_rule,
  /* 1013 */  vRegF_rule,
  /* 1014 */  vRegD_rule,
  /* 1015 */  vRegF_rule,
  /* 1016 */  vRegD_rule,
  /* 1017 */  iRegIorL2I_rule,
  /* 1018 */  iRegIorL2I_rule,
  /* 1019 */  0,
  /* 1020 */  iRegI_rule,
  /* 1021 */  0,
  /* 1022 */  iRegI_rule,
  /* 1023 */  0,
  /* 1024 */  cmpOp_rule,
  /* 1025 */  cmpOpU_rule,
  /* 1026 */  cmpOpEqNe_rule,
  /* 1027 */  cmpOpEqNe_rule,
  /* 1028 */  cmpOpEqNe_rule,
  /* 1029 */  cmpOpEqNe_rule,
  /* 1030 */  cmpOpEqNe_rule,
  /* 1031 */  cmpOpUEqNeLtGe_rule,
  /* 1032 */  cmpOpUEqNeLtGe_rule,
  /* 1033 */  cmpOpLtGe_rule,
  /* 1034 */  cmpOpLtGe_rule,
  /* 1035 */  cmpOpEqNe_rule,
  /* 1036 */  cmpOpEqNe_rule,
  /* 1037 */  cmpOpLtGe_rule,
  /* 1038 */  cmpOpLtGe_rule,
  /* 1039 */  cmpOpEqNe_rule,
  /* 1040 */  cmpOpEqNe_rule,
  /* 1041 */  cmpOp_rule,
  /* 1042 */  cmpOpU_rule,
  /* 1043 */  iRegP_rule,
  /* 1044 */  0,
  /* 1045 */  0,
  /* 1046 */  0,
  /* 1047 */  0,
  /* 1048 */  0,
  /* 1049 */  iRegPNoSp_rule,
  /* 1050 */  iRegPNoSp_rule,
  /* 1051 */  0,
  /* 1052 */  0,
  /* 1053 */  0,
  /* 1054 */  0,
  /* 1055 */  iRegP_R4_rule,
  /* 1056 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1057 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1058 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1059 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1060 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1061 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1062 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1063 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1064 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1065 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1066 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1067 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1068 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1069 */  iRegP_R1_rule,
  /* 1070 */  iRegP_R1_rule,
  /* 1071 */  iRegP_R1_rule,
  /* 1072 */  iRegP_R2_rule,
  /* 1073 */  iRegP_R0_rule,
  /* 1074 */  iRegP_R2_rule,
  /* 1075 */  vmem4_rule,
  /* 1076 */  vmem8_rule,
  /* 1077 */  vmem16_rule,
  /* 1078 */  vmem4_rule,
  /* 1079 */  vmem8_rule,
  /* 1080 */  vmem16_rule,
  /* 1081 */  iRegIorL2I_rule,
  /* 1082 */  iRegIorL2I_rule,
  /* 1083 */  immI_rule,
  /* 1084 */  immI_rule,
  /* 1085 */  iRegIorL2I_rule,
  /* 1086 */  iRegIorL2I_rule,
  /* 1087 */  immI_rule,
  /* 1088 */  immI_rule,
  /* 1089 */  iRegIorL2I_rule,
  /* 1090 */  iRegIorL2I_rule,
  /* 1091 */  immI_rule,
  /* 1092 */  immI_rule,
  /* 1093 */  iRegL_rule,
  /* 1094 */  immI0_rule,
  /* 1095 */  vRegF_rule,
  /* 1096 */  vRegF_rule,
  /* 1097 */  vRegD_rule,
  /* 1098 */  iRegIorL2I_rule,
  /* 1099 */  iRegIorL2I_rule,
  /* 1100 */  iRegIorL2I_rule,
  /* 1101 */  iRegIorL2I_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegF_rule,
  /* 1104 */  vRegF_rule,
  /* 1105 */  vRegF_rule,
  /* 1106 */  vRegD_rule,
  /* 1107 */  vRegD_rule,
  /* 1108 */  vRegF_rule,
  /* 1109 */  vRegF_rule,
  /* 1110 */  vRegD_rule,
  /* 1111 */  vRegF_rule,
  /* 1112 */  vRegF_rule,
  /* 1113 */  vRegD_rule,
  /* 1114 */  vecD_rule,
  /* 1115 */  vecX_rule,
  /* 1116 */  vecD_rule,
  /* 1117 */  vecX_rule,
  /* 1118 */  vecD_rule,
  /* 1119 */  vecX_rule,
  /* 1120 */  vecX_rule,
  /* 1121 */  vecD_rule,
  /* 1122 */  vecX_rule,
  /* 1123 */  vecX_rule,
  /* 1124 */  vecD_rule,
  /* 1125 */  vecX_rule,
  /* 1126 */  vecD_rule,
  /* 1127 */  vecX_rule,
  /* 1128 */  vecD_rule,
  /* 1129 */  vecX_rule,
  /* 1130 */  vecX_rule,
  /* 1131 */  vecD_rule,
  /* 1132 */  vecX_rule,
  /* 1133 */  vecX_rule,
  /* 1134 */  vecD_rule,
  /* 1135 */  vecX_rule,
  /* 1136 */  vecD_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecD_rule,
  /* 1139 */  vecX_rule,
  /* 1140 */  vecD_rule,
  /* 1141 */  vecX_rule,
  /* 1142 */  vecX_rule,
  /* 1143 */  vecD_rule,
  /* 1144 */  _MulVS_vecD_vecD_rule,
  /* 1145 */  vecX_rule,
  /* 1146 */  _MulVS_vecX_vecX_rule,
  /* 1147 */  vecD_rule,
  /* 1148 */  _MulVI_vecD_vecD_rule,
  /* 1149 */  vecX_rule,
  /* 1150 */  _MulVI_vecX_vecX_rule,
  /* 1151 */  vecD_rule,
  /* 1152 */  vecX_rule,
  /* 1153 */  vecX_rule,
  /* 1154 */  vecD_rule,
  /* 1155 */  vecX_rule,
  /* 1156 */  vecD_rule,
  /* 1157 */  vecX_rule,
  /* 1158 */  vecD_rule,
  /* 1159 */  vecD_rule,
  /* 1160 */  vecX_rule,
  /* 1161 */  vecX_rule,
  /* 1162 */  vecX_rule,
  /* 1163 */  vecX_rule,
  /* 1164 */  vecD_rule,
  /* 1165 */  vecX_rule,
  /* 1166 */  vecX_rule,
  /* 1167 */  vecD_rule,
  /* 1168 */  vecX_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecX_rule,
  /* 1171 */  vecD_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecD_rule,
  /* 1174 */  vecX_rule,
  /* 1175 */  vecD_rule,
  /* 1176 */  vecX_rule,
  /* 1177 */  vecD_rule,
  /* 1178 */  vecX_rule,
  /* 1179 */  vecD_rule,
  /* 1180 */  vecX_rule,
  /* 1181 */  vecD_rule,
  /* 1182 */  vecX_rule,
  /* 1183 */  vecD_rule,
  /* 1184 */  vecX_rule,
  /* 1185 */  vecD_rule,
  /* 1186 */  vecX_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecX_rule,
  /* 1189 */  vecD_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  vecD_rule,
  /* 1192 */  vecX_rule,
  /* 1193 */  vecD_rule,
  /* 1194 */  vecX_rule,
  /* 1195 */  vecD_rule,
  /* 1196 */  vecX_rule,
  /* 1197 */  vecD_rule,
  /* 1198 */  vecX_rule,
  /* 1199 */  vecD_rule,
  /* 1200 */  vecX_rule,
  /* 1201 */  vecD_rule,
  /* 1202 */  vecX_rule,
  /* 1203 */  vecD_rule,
  /* 1204 */  vecX_rule,
  /* 1205 */  vecD_rule,
  /* 1206 */  vecX_rule,
  /* 1207 */  vecD_rule,
  /* 1208 */  vecX_rule,
  /* 1209 */  vecX_rule,
  /* 1210 */  vecX_rule,
  /* 1211 */  vecX_rule,
  /* 1212 */  vecX_rule,
  /* 1213 */  vecX_rule,
  /* 1214 */  vecX_rule,
  /* 1215 */  vecD_rule,
  /* 1216 */  vecX_rule,
  /* 1217 */  vecX_rule,
  /* 1218 */  vecD_rule,
  /* 1219 */  vecX_rule,
  /* 1220 */  vecX_rule,
  /* 1221 */  memory_rule,
  /* 1222 */  memory_rule,
  /* 1223 */  indirect_rule,
  /* 1224 */  indirect_rule,
  /* 1225 */  indirect_rule,
  /* 1226 */  indirect_rule,
  /* 1227 */  indirect_rule,
  /* 1228 */  indirect_rule,
  /* 1229 */  indirect_rule,
  /* 1230 */  indirect_rule,
  /* 1231 */  indirect_rule,
  /* 1232 */  vmemA_rule,
  /* 1233 */  vmemA_rule,
  /* 1234 */  vReg_rule,
  /* 1235 */  vReg_rule,
  /* 1236 */  vReg_rule,
  /* 1237 */  vReg_rule,
  /* 1238 */  vReg_rule,
  /* 1239 */  vReg_rule,
  /* 1240 */  vReg_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  vReg_rule,
  /* 1246 */  vReg_rule,
  /* 1247 */  vReg_rule,
  /* 1248 */  vReg_rule,
  /* 1249 */  vReg_rule,
  /* 1250 */  vReg_rule,
  /* 1251 */  _NegVF_vReg__rule,
  /* 1252 */  _NegVF_vReg__rule,
  /* 1253 */  _NegVD_vReg__rule,
  /* 1254 */  _NegVD_vReg__rule,
  /* 1255 */  _NegVF_vReg__rule,
  /* 1256 */  _NegVD_vReg__rule,
  /* 1257 */  vReg_rule,
  /* 1258 */  _MulVS_vReg_vReg_rule,
  /* 1259 */  vReg_rule,
  /* 1260 */  _MulVI_vReg_vReg_rule,
  /* 1261 */  vReg_rule,
  /* 1262 */  _MulVL_vReg_vReg_rule,
  /* 1263 */  vReg_rule,
  /* 1264 */  vReg_rule,
  /* 1265 */  vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  vReg_rule,
  /* 1268 */  vReg_rule,
  /* 1269 */  vReg_rule,
  /* 1270 */  vReg_rule,
  /* 1271 */  iRegIorL2I_rule,
  /* 1272 */  iRegL_rule,
  /* 1273 */  vRegF_rule,
  /* 1274 */  vRegD_rule,
  /* 1275 */  iRegIorL2I_rule,
  /* 1276 */  iRegIorL2I_rule,
  /* 1277 */  iRegIorL2I_rule,
  /* 1278 */  iRegL_rule,
  /* 1279 */  immI8_rule,
  /* 1280 */  immI8_shift8_rule,
  /* 1281 */  immI8_shift8_rule,
  /* 1282 */  immL8_shift8_rule,
  /* 1283 */  vRegF_rule,
  /* 1284 */  vRegD_rule,
  /* 1285 */  vReg_rule,
  /* 1286 */  vReg_rule,
  /* 1287 */  vReg_rule,
  /* 1288 */  vReg_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  vReg_rule,
  /* 1294 */  vReg_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  vReg_rule,
  /* 1297 */  vReg_rule,
  /* 1298 */  vReg_rule,
  /* 1299 */  vReg_rule,
  /* 1300 */  vReg_rule,
  /* 1301 */  vReg_rule,
  /* 1302 */  vReg_rule,
  /* 1303 */  vReg_rule,
  /* 1304 */  vReg_rule,
  /* 1305 */  vReg_rule,
  /* 1306 */  vReg_rule,
  /* 1307 */  vReg_rule,
  /* 1308 */  vReg_rule,
  /* 1309 */  vReg_rule,
  /* 1310 */  vReg_rule,
  /* 1311 */  vReg_rule,
  /* 1312 */  vReg_rule,
  /* 1313 */  vReg_rule,
  /* 1314 */  vReg_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  148 */  _LShiftL_iRegL_immIScale_rule,
  /*  149 */  _ConvI2L_iRegI__rule,
  /*  150 */  iRegL_rule,
  /*  151 */  immIOffset_rule,
  /*  152 */  immIOffset4_rule,
  /*  153 */  immIOffset8_rule,
  /*  154 */  immIOffset16_rule,
  /*  155 */  immLoffset_rule,
  /*  156 */  immLoffset4_rule,
  /*  157 */  immLoffset8_rule,
  /*  158 */  immLoffset16_rule,
  /*  159 */  0,
  /*  160 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  161 */  _LShiftL_iRegL_immIScale_rule,
  /*  162 */  _ConvI2L_iRegI__rule,
  /*  163 */  iRegL_rule,
  /*  164 */  immIOffset_rule,
  /*  165 */  immLoffset_rule,
  /*  166 */  immL_pc_off_rule,
  /*  167 */  0,
  /*  168 */  0,
  /*  169 */  0,
  /*  170 */  0,
  /*  171 */  0,
  /*  172 */  0,
  /*  173 */  0,
  /*  174 */  0,
  /*  175 */  0,
  /*  176 */  0,
  /*  177 */  0,
  /*  178 */  0,
  /*  179 */  0,
  /*  180 */  vmemA_immIOffset4_rule,
  /*  181 */  vmemA_immLOffset4_rule,
  // last operand
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  // last operand class
  /*  188 */  0,
  /*  189 */  immIScale_rule,
  /*  190 */  immIScale_rule,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  0,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  /*  207 */  iRegP_rule,
  /*  208 */  iRegLNoSp_rule,
  /*  209 */  iRegINoSp_rule,
  /*  210 */  iRegNNoSp_rule,
  /*  211 */  iRegI_rule,
  /*  212 */  iRegL_rule,
  /*  213 */  iRegN_rule,
  /*  214 */  rFlagsReg_rule,
  /*  215 */  iRegIorL2I_rule,
  /*  216 */  rFlagsRegU_rule,
  /*  217 */  iRegIorL2I_rule,
  /*  218 */  immI0_rule,
  /*  219 */  immI0_rule,
  /*  220 */  immL0_rule,
  /*  221 */  iRegL_rule,
  /*  222 */  immP0_rule,
  /*  223 */  iRegP_rule,
  /*  224 */  immN0_rule,
  /*  225 */  iRegN_rule,
  /*  226 */  vRegF_rule,
  /*  227 */  vRegD_rule,
  /*  228 */  0,
  /*  229 */  0,
  /*  230 */  immIScale_rule,
  /*  231 */  iRegIorL2I_rule,
  /*  232 */  iRegL_rule,
  /*  233 */  _ConvI2L_iRegIorL2I__rule,
  /*  234 */  _ConvI2L_iRegIorL2I__rule,
  /*  235 */  immI_M1_rule,
  /*  236 */  immL_M1_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  iRegL_rule,
  /*  239 */  immI_rule,
  /*  240 */  immI_M1_rule,
  /*  241 */  immI_rule,
  /*  242 */  immL_M1_rule,
  /*  243 */  immI_rule,
  /*  244 */  immI_M1_rule,
  /*  245 */  immI_rule,
  /*  246 */  immL_M1_rule,
  /*  247 */  immI_rule,
  /*  248 */  immI_M1_rule,
  /*  249 */  immI_rule,
  /*  250 */  immL_M1_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  253 */  iRegL_rule,
  /*  254 */  _URShiftL_iRegL_immI_rule,
  /*  255 */  iRegIorL2I_rule,
  /*  256 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  257 */  iRegL_rule,
  /*  258 */  _RShiftL_iRegL_immI_rule,
  /*  259 */  iRegIorL2I_rule,
  /*  260 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  261 */  iRegL_rule,
  /*  262 */  _LShiftL_iRegL_immI_rule,
  /*  263 */  immI_bitmask_rule,
  /*  264 */  immI_bitmask_rule,
  /*  265 */  immL_bitmask_rule,
  /*  266 */  immI_rule,
  /*  267 */  immL_positive_bitmaskI_rule,
  /*  268 */  immI_rule,
  /*  269 */  0,
  /*  270 */  0,
  /*  271 */  immI_bitmask_rule,
  /*  272 */  iRegI_rule,
  /*  273 */  iRegI_rule,
  /*  274 */  _SubI_immI_64_iRegI_rule,
  /*  275 */  iRegI_rule,
  /*  276 */  _SubI_immI0_iRegI_rule,
  /*  277 */  iRegI_rule,
  /*  278 */  iRegI_rule,
  /*  279 */  _SubI_immI_32_iRegI_rule,
  /*  280 */  _SubI_immI0_iRegI_rule,
  /*  281 */  iRegI_rule,
  /*  282 */  _SubI_immI_64_iRegI_rule,
  /*  283 */  _SubI_immI0_iRegI_rule,
  /*  284 */  iRegI_rule,
  /*  285 */  _SubI_immI_32_iRegI_rule,
  /*  286 */  _SubI_immI0_iRegI_rule,
  /*  287 */  immI_16_rule,
  /*  288 */  immI_16_rule,
  /*  289 */  immI_24_rule,
  /*  290 */  immI_24_rule,
  /*  291 */  immI_24_rule,
  /*  292 */  immI_48_rule,
  /*  293 */  immI_48_rule,
  /*  294 */  immI_32_rule,
  /*  295 */  immI_32_rule,
  /*  296 */  immI_56_rule,
  /*  297 */  immI_56_rule,
  /*  298 */  immI_56_rule,
  /*  299 */  immI_255_rule,
  /*  300 */  immI_65535_rule,
  /*  301 */  immL_255_rule,
  /*  302 */  immL_65535_rule,
  /*  303 */  immL_4294967295_rule,
  /*  304 */  immIExt_rule,
  /*  305 */  immIExt_rule,
  /*  306 */  immIExt_rule,
  /*  307 */  immIExt_rule,
  /*  308 */  immIExt_rule,
  /*  309 */  immIExt_rule,
  /*  310 */  immIExt_rule,
  /*  311 */  immIExt_rule,
  /*  312 */  immIExt_rule,
  /*  313 */  immIExt_rule,
  /*  314 */  immIExt_rule,
  /*  315 */  0,
  /*  316 */  vRegF_rule,
  /*  317 */  _NegF_vRegF__rule,
  /*  318 */  0,
  /*  319 */  vRegD_rule,
  /*  320 */  _NegD_vRegD__rule,
  /*  321 */  iRegIorL2I_rule,
  /*  322 */  iRegL_rule,
  /*  323 */  immI0_rule,
  /*  324 */  immL0_rule,
  /*  325 */  immP0_rule,
  /*  326 */  immN0_rule,
  /*  327 */  immP0_rule,
  /*  328 */  immI0_rule,
  /*  329 */  immL0_rule,
  /*  330 */  immL_rule,
  /*  331 */  immL0_rule,
  /*  332 */  immI_rule,
  /*  333 */  immI0_rule,
  /*  334 */  iRegL_rule,
  /*  335 */  iRegIorL2I_rule,
  /*  336 */  iRegP_R0_rule,
  /*  337 */  iRegI_R2_rule,
  /*  338 */  iRegI_R4_rule,
  /*  339 */  iRegI_R4_rule,
  /*  340 */  iRegI_R2_rule,
  /*  341 */  immI_le_4_rule,
  /*  342 */  immI_1_rule,
  /*  343 */  iRegP_R3_rule,
  /*  344 */  iRegI_R3_rule,
  /*  345 */  vecD_rule,
  /*  346 */  vecX_rule,
  /*  347 */  vecD_rule,
  /*  348 */  vecX_rule,
  /*  349 */  vecD_rule,
  /*  350 */  vecX_rule,
  /*  351 */  0,
  /*  352 */  vecD_rule,
  /*  353 */  _NegVF_vecD__rule,
  /*  354 */  0,
  /*  355 */  vecX_rule,
  /*  356 */  _NegVF_vecX__rule,
  /*  357 */  0,
  /*  358 */  vecX_rule,
  /*  359 */  _NegVD_vecX__rule,
  /*  360 */  vReg_rule,
  /*  361 */  0,
  /*  362 */  vReg_rule,
  /*  363 */  _NegVF_vReg__rule,
  /*  364 */  0,
  /*  365 */  vReg_rule,
  /*  366 */  _NegVD_vReg__rule,
  /*  367 */  vReg_rule,
  /*  368 */  vReg_rule,
  /*  369 */  vReg_rule,
  // last internally defined operand
  /*  370 */  0,
  /*  371 */  0,
  /*  372 */  0,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  0,
  /*  376 */  0,
  /*  377 */  0,
  /*  378 */  0,
  /*  379 */  0,
  /*  380 */  0,
  /*  381 */  0,
  /*  382 */  0,
  /*  383 */  0,
  /*  384 */  0,
  /*  385 */  0,
  /*  386 */  0,
  /*  387 */  0,
  /*  388 */  0,
  /*  389 */  0,
  /*  390 */  0,
  /*  391 */  0,
  /*  392 */  0,
  /*  393 */  0,
  /*  394 */  _Binary_iRegP_iRegP_rule,
  /*  395 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  396 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  397 */  0,
  /*  398 */  0,
  /*  399 */  0,
  /*  400 */  0,
  /*  401 */  0,
  /*  402 */  0,
  /*  403 */  0,
  /*  404 */  0,
  /*  405 */  0,
  /*  406 */  0,
  /*  407 */  0,
  /*  408 */  0,
  /*  409 */  iRegIorL2I_rule,
  /*  410 */  immIAddSub_rule,
  /*  411 */  iRegL_rule,
  /*  412 */  immLAddSub_rule,
  /*  413 */  iRegIorL2I_rule,
  /*  414 */  immIAddSub_rule,
  /*  415 */  iRegL_rule,
  /*  416 */  immLAddSub_rule,
  /*  417 */  iRegIorL2I_rule,
  /*  418 */  iRegL_rule,
  /*  419 */  iRegIorL2I_rule,
  /*  420 */  iRegL_rule,
  /*  421 */  iRegI_rule,
  /*  422 */  immI0_rule,
  /*  423 */  immIAddSub_rule,
  /*  424 */  immI_rule,
  /*  425 */  iRegI_rule,
  /*  426 */  immI0_rule,
  /*  427 */  immIAddSub_rule,
  /*  428 */  immI_rule,
  /*  429 */  iRegL_rule,
  /*  430 */  immL0_rule,
  /*  431 */  immLAddSub_rule,
  /*  432 */  immL_rule,
  /*  433 */  iRegL_rule,
  /*  434 */  immL0_rule,
  /*  435 */  immLAddSub_rule,
  /*  436 */  immL_rule,
  /*  437 */  iRegP_rule,
  /*  438 */  iRegN_rule,
  /*  439 */  immP0_rule,
  /*  440 */  immN0_rule,
  /*  441 */  vRegF_rule,
  /*  442 */  immF0_rule,
  /*  443 */  vRegD_rule,
  /*  444 */  immD0_rule,
  /*  445 */  immL0_rule,
  /*  446 */  immI0_rule,
  /*  447 */  immL0_rule,
  /*  448 */  immI0_rule,
  /*  449 */  iRegP_rule,
  /*  450 */  iRegP_rule,
  /*  451 */  immP0_rule,
  /*  452 */  0,
  /*  453 */  0,
  /*  454 */  0,
  /*  455 */  0,
  /*  456 */  0,
  /*  457 */  0,
  /*  458 */  0,
  /*  459 */  0,
  /*  460 */  0,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  0,
  /*  465 */  0,
  /*  466 */  0,
  /*  467 */  0,
  /*  468 */  0,
  /*  469 */  0,
  /*  470 */  0,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  0,
  /*  475 */  0,
  /*  476 */  0,
  /*  477 */  0,
  /*  478 */  0,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  0,
  /*  483 */  0,
  /*  484 */  0,
  /*  485 */  0,
  /*  486 */  0,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  0,
  /*  491 */  0,
  /*  492 */  0,
  /*  493 */  0,
  /*  494 */  0,
  /*  495 */  0,
  /*  496 */  0,
  /*  497 */  0,
  /*  498 */  immL_32bits_rule,
  /*  499 */  0,
  /*  500 */  0,
  /*  501 */  0,
  /*  502 */  0,
  /*  503 */  0,
  /*  504 */  0,
  /*  505 */  0,
  /*  506 */  0,
  /*  507 */  immI0_rule,
  /*  508 */  immI0_rule,
  /*  509 */  iRegIorL2I_rule,
  /*  510 */  immI0_rule,
  /*  511 */  iRegIorL2I_rule,
  /*  512 */  immI0_rule,
  /*  513 */  iRegIorL2I_rule,
  /*  514 */  immI0_rule,
  /*  515 */  iRegL_rule,
  /*  516 */  immL0_rule,
  /*  517 */  iRegP_rule,
  /*  518 */  immP0_rule,
  /*  519 */  iRegN_rule,
  /*  520 */  immN0_rule,
  /*  521 */  vRegF_rule,
  /*  522 */  vRegD_rule,
  /*  523 */  iRegN_rule,
  /*  524 */  0,
  /*  525 */  0,
  /*  526 */  0,
  /*  527 */  0,
  /*  528 */  0,
  /*  529 */  0,
  /*  530 */  0,
  /*  531 */  0,
  /*  532 */  0,
  /*  533 */  0,
  /*  534 */  immL_32bits_rule,
  /*  535 */  0,
  /*  536 */  0,
  /*  537 */  0,
  /*  538 */  0,
  /*  539 */  0,
  /*  540 */  iRegIorL2I_rule,
  /*  541 */  iRegIorL2I_rule,
  /*  542 */  iRegIorL2I_rule,
  /*  543 */  iRegL_rule,
  /*  544 */  iRegP_rule,
  /*  545 */  iRegN_rule,
  /*  546 */  vRegF_rule,
  /*  547 */  vRegD_rule,
  /*  548 */  0,
  /*  549 */  0,
  /*  550 */  0,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  0,
  /*  555 */  0,
  /*  556 */  0,
  /*  557 */  0,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  0,
  /*  561 */  0,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  0,
  /*  566 */  0,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  0,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  577 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  578 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  579 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  580 */  _Binary_iRegP_iRegP_rule,
  /*  581 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  582 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  583 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  584 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  585 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  586 */  _Binary_iRegP_iRegP_rule,
  /*  587 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  588 */  _Binary_iRegI_iRegI_rule,
  /*  589 */  _Binary_iRegI_iRegI_rule,
  /*  590 */  _Binary_iRegI_iRegI_rule,
  /*  591 */  _Binary_iRegL_iRegL_rule,
  /*  592 */  _Binary_iRegN_iRegN_rule,
  /*  593 */  _Binary_iRegP_iRegP_rule,
  /*  594 */  _Binary_iRegI_iRegI_rule,
  /*  595 */  _Binary_iRegI_iRegI_rule,
  /*  596 */  _Binary_iRegI_iRegI_rule,
  /*  597 */  _Binary_iRegL_iRegL_rule,
  /*  598 */  _Binary_iRegN_iRegN_rule,
  /*  599 */  _Binary_iRegP_iRegP_rule,
  /*  600 */  _Binary_iRegI_iRegI_rule,
  /*  601 */  _Binary_iRegI_iRegI_rule,
  /*  602 */  _Binary_iRegI_iRegI_rule,
  /*  603 */  _Binary_iRegL_iRegL_rule,
  /*  604 */  _Binary_iRegN_iRegN_rule,
  /*  605 */  _Binary_iRegP_iRegP_rule,
  /*  606 */  _Binary_iRegI_iRegI_rule,
  /*  607 */  _Binary_iRegI_iRegI_rule,
  /*  608 */  _Binary_iRegI_iRegI_rule,
  /*  609 */  _Binary_iRegL_iRegL_rule,
  /*  610 */  _Binary_iRegN_iRegN_rule,
  /*  611 */  _Binary_iRegP_iRegP_rule,
  /*  612 */  iRegI_rule,
  /*  613 */  iRegL_rule,
  /*  614 */  iRegN_rule,
  /*  615 */  iRegP_rule,
  /*  616 */  iRegI_rule,
  /*  617 */  iRegL_rule,
  /*  618 */  iRegN_rule,
  /*  619 */  iRegP_rule,
  /*  620 */  iRegL_rule,
  /*  621 */  iRegL_rule,
  /*  622 */  immLAddSub_rule,
  /*  623 */  immLAddSub_rule,
  /*  624 */  iRegIorL2I_rule,
  /*  625 */  iRegIorL2I_rule,
  /*  626 */  immIAddSub_rule,
  /*  627 */  immIAddSub_rule,
  /*  628 */  iRegL_rule,
  /*  629 */  iRegL_rule,
  /*  630 */  immLAddSub_rule,
  /*  631 */  immLAddSub_rule,
  /*  632 */  iRegIorL2I_rule,
  /*  633 */  iRegIorL2I_rule,
  /*  634 */  immIAddSub_rule,
  /*  635 */  immIAddSub_rule,
  /*  636 */  iRegL_rule,
  /*  637 */  immLAddSub_rule,
  /*  638 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  639 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  640 */  _Binary_immI0_iRegIorL2I_rule,
  /*  641 */  _Binary_immI0_iRegIorL2I_rule,
  /*  642 */  _Binary_iRegIorL2I_immI0_rule,
  /*  643 */  _Binary_iRegIorL2I_immI0_rule,
  /*  644 */  _Binary_immI_1_immI0_rule,
  /*  645 */  _Binary_immI_1_immI0_rule,
  /*  646 */  _Binary_iRegL_iRegL_rule,
  /*  647 */  _Binary_iRegL_iRegL_rule,
  /*  648 */  _Binary_iRegL_immL0_rule,
  /*  649 */  _Binary_iRegL_immL0_rule,
  /*  650 */  _Binary_immL0_iRegL_rule,
  /*  651 */  _Binary_immL0_iRegL_rule,
  /*  652 */  _Binary_iRegP_iRegP_rule,
  /*  653 */  _Binary_iRegP_iRegP_rule,
  /*  654 */  _Binary_iRegP_immP0_rule,
  /*  655 */  _Binary_iRegP_immP0_rule,
  /*  656 */  _Binary_immP0_iRegP_rule,
  /*  657 */  _Binary_immP0_iRegP_rule,
  /*  658 */  _Binary_iRegN_iRegN_rule,
  /*  659 */  _Binary_iRegN_iRegN_rule,
  /*  660 */  _Binary_iRegN_immN0_rule,
  /*  661 */  _Binary_iRegN_immN0_rule,
  /*  662 */  _Binary_immN0_iRegN_rule,
  /*  663 */  _Binary_immN0_iRegN_rule,
  /*  664 */  _Binary_vRegF_vRegF_rule,
  /*  665 */  _Binary_vRegF_vRegF_rule,
  /*  666 */  _Binary_vRegD_vRegD_rule,
  /*  667 */  _Binary_vRegD_vRegD_rule,
  /*  668 */  iRegIorL2I_rule,
  /*  669 */  immIAddSub_rule,
  /*  670 */  immIAddSub_rule,
  /*  671 */  iRegL_rule,
  /*  672 */  _ConvI2L_iRegIorL2I__rule,
  /*  673 */  _LShiftL_iRegL_immIScale_rule,
  /*  674 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  675 */  immI_rule,
  /*  676 */  immLAddSub_rule,
  /*  677 */  iRegL_rule,
  /*  678 */  immLAddSub_rule,
  /*  679 */  iRegIorL2I_rule,
  /*  680 */  immIAddSub_rule,
  /*  681 */  iRegL_rule,
  /*  682 */  immLAddSub_rule,
  /*  683 */  iRegIorL2I_rule,
  /*  684 */  iRegL_rule,
  /*  685 */  iRegIorL2I_rule,
  /*  686 */  _ConvI2L_iRegIorL2I__rule,
  /*  687 */  _ConvI2L_iRegIorL2I__rule,
  /*  688 */  iRegL_rule,
  /*  689 */  iRegL_rule,
  /*  690 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  691 */  iRegIorL2I_rule,
  /*  692 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  693 */  _MulL_iRegL_iRegL_rule,
  /*  694 */  iRegL_rule,
  /*  695 */  _MulL_iRegL_iRegL_rule,
  /*  696 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  697 */  iRegLNoSp_rule,
  /*  698 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  699 */  iRegLNoSp_rule,
  /*  700 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  701 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  702 */  _ConvI2L_iRegIorL2I__rule,
  /*  703 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  704 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  705 */  _ConvI2L_iRegIorL2I__rule,
  /*  706 */  iRegIorL2I_rule,
  /*  707 */  iRegL_rule,
  /*  708 */  iRegIorL2I_rule,
  /*  709 */  iRegL_rule,
  /*  710 */  iRegIorL2I_rule,
  /*  711 */  immI_rule,
  /*  712 */  iRegIorL2I_rule,
  /*  713 */  immI_rule,
  /*  714 */  iRegIorL2I_rule,
  /*  715 */  immI_rule,
  /*  716 */  iRegIorL2I_rule,
  /*  717 */  immI_rule,
  /*  718 */  iRegIorL2I_rule,
  /*  719 */  immI_rule,
  /*  720 */  immI_rule,
  /*  721 */  iRegIorL2I_rule,
  /*  722 */  immI_rule,
  /*  723 */  immL_M1_rule,
  /*  724 */  immI_M1_rule,
  /*  725 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  726 */  iRegIorL2I_rule,
  /*  727 */  _XorL_iRegL_immL_M1_rule,
  /*  728 */  iRegL_rule,
  /*  729 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  730 */  iRegIorL2I_rule,
  /*  731 */  _XorL_iRegL_immL_M1_rule,
  /*  732 */  iRegL_rule,
  /*  733 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  734 */  immI_M1_rule,
  /*  735 */  _XorL_iRegL_iRegL_rule,
  /*  736 */  immL_M1_rule,
  /*  737 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  738 */  iRegIorL2I_rule,
  /*  739 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  740 */  iRegL_rule,
  /*  741 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  742 */  iRegIorL2I_rule,
  /*  743 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  744 */  iRegL_rule,
  /*  745 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  746 */  iRegIorL2I_rule,
  /*  747 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  748 */  iRegL_rule,
  /*  749 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  750 */  immI_M1_rule,
  /*  751 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  752 */  immI_M1_rule,
  /*  753 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  754 */  immL_M1_rule,
  /*  755 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  756 */  immL_M1_rule,
  /*  757 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  758 */  immI_M1_rule,
  /*  759 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  760 */  immI_M1_rule,
  /*  761 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  762 */  immL_M1_rule,
  /*  763 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  764 */  immL_M1_rule,
  /*  765 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  766 */  immI_M1_rule,
  /*  767 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  768 */  immI_M1_rule,
  /*  769 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  770 */  immL_M1_rule,
  /*  771 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  772 */  immL_M1_rule,
  /*  773 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  774 */  iRegIorL2I_rule,
  /*  775 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  776 */  iRegL_rule,
  /*  777 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  778 */  iRegIorL2I_rule,
  /*  779 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  780 */  iRegL_rule,
  /*  781 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  782 */  iRegIorL2I_rule,
  /*  783 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  784 */  iRegL_rule,
  /*  785 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  786 */  iRegIorL2I_rule,
  /*  787 */  _URShiftL_iRegL_immI_rule,
  /*  788 */  iRegL_rule,
  /*  789 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  790 */  iRegIorL2I_rule,
  /*  791 */  _RShiftL_iRegL_immI_rule,
  /*  792 */  iRegL_rule,
  /*  793 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  794 */  iRegIorL2I_rule,
  /*  795 */  _LShiftL_iRegL_immI_rule,
  /*  796 */  iRegL_rule,
  /*  797 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  798 */  iRegIorL2I_rule,
  /*  799 */  _URShiftL_iRegL_immI_rule,
  /*  800 */  iRegL_rule,
  /*  801 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  802 */  iRegIorL2I_rule,
  /*  803 */  _RShiftL_iRegL_immI_rule,
  /*  804 */  iRegL_rule,
  /*  805 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  806 */  iRegIorL2I_rule,
  /*  807 */  _LShiftL_iRegL_immI_rule,
  /*  808 */  iRegL_rule,
  /*  809 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  810 */  iRegIorL2I_rule,
  /*  811 */  _URShiftL_iRegL_immI_rule,
  /*  812 */  iRegL_rule,
  /*  813 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  814 */  iRegIorL2I_rule,
  /*  815 */  _RShiftL_iRegL_immI_rule,
  /*  816 */  iRegL_rule,
  /*  817 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  818 */  iRegIorL2I_rule,
  /*  819 */  _LShiftL_iRegL_immI_rule,
  /*  820 */  iRegL_rule,
  /*  821 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  822 */  iRegIorL2I_rule,
  /*  823 */  _URShiftL_iRegL_immI_rule,
  /*  824 */  iRegL_rule,
  /*  825 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  826 */  iRegIorL2I_rule,
  /*  827 */  _RShiftL_iRegL_immI_rule,
  /*  828 */  iRegL_rule,
  /*  829 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  830 */  iRegIorL2I_rule,
  /*  831 */  _LShiftL_iRegL_immI_rule,
  /*  832 */  iRegL_rule,
  /*  833 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  834 */  _URShiftL_iRegL_immI_rule,
  /*  835 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  836 */  _RShiftL_iRegL_immI_rule,
  /*  837 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  838 */  _LShiftL_iRegL_immI_rule,
  /*  839 */  immI_rule,
  /*  840 */  immI_rule,
  /*  841 */  immI_rule,
  /*  842 */  immI_rule,
  /*  843 */  immI_bitmask_rule,
  /*  844 */  immL_bitmask_rule,
  /*  845 */  0,
  /*  846 */  immI_rule,
  /*  847 */  immI_rule,
  /*  848 */  0,
  /*  849 */  0,
  /*  850 */  immI_rule,
  /*  851 */  immI_rule,
  /*  852 */  0,
  /*  853 */  _URShiftL_iRegL_immI_rule,
  /*  854 */  _LShiftL_iRegL_immI_rule,
  /*  855 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  856 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  857 */  _URShiftL_iRegL_immI_rule,
  /*  858 */  _LShiftL_iRegL_immI_rule,
  /*  859 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  860 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  864 */  _LShiftL_iRegL_iRegI_rule,
  /*  865 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  866 */  _LShiftL_iRegL_iRegI_rule,
  /*  867 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  868 */  _LShiftI_iRegI_iRegI_rule,
  /*  869 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  870 */  _LShiftI_iRegI_iRegI_rule,
  /*  871 */  0,
  /*  872 */  0,
  /*  873 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  874 */  _URShiftL_iRegL_iRegI_rule,
  /*  875 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  876 */  _URShiftL_iRegL_iRegI_rule,
  /*  877 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  878 */  _URShiftI_iRegI_iRegI_rule,
  /*  879 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  880 */  _URShiftI_iRegI_iRegI_rule,
  /*  881 */  _ConvI2L_iRegIorL2I__rule,
  /*  882 */  iRegL_rule,
  /*  883 */  _ConvI2L_iRegIorL2I__rule,
  /*  884 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  885 */  iRegIorL2I_rule,
  /*  886 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  887 */  iRegIorL2I_rule,
  /*  888 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  889 */  iRegIorL2I_rule,
  /*  890 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  891 */  iRegL_rule,
  /*  892 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  893 */  iRegL_rule,
  /*  894 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  895 */  iRegL_rule,
  /*  896 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  897 */  iRegL_rule,
  /*  898 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  899 */  iRegIorL2I_rule,
  /*  900 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  901 */  iRegIorL2I_rule,
  /*  902 */  _AndL_iRegL_immL_255_rule,
  /*  903 */  iRegL_rule,
  /*  904 */  _AndL_iRegL_immL_65535_rule,
  /*  905 */  iRegL_rule,
  /*  906 */  _AndL_iRegL_immL_4294967295_rule,
  /*  907 */  iRegL_rule,
  /*  908 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  909 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  910 */  _AndL_iRegL_immL_255_rule,
  /*  911 */  _AndL_iRegL_immL_65535_rule,
  /*  912 */  _AndL_iRegL_immL_4294967295_rule,
  /*  913 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  914 */  iRegL_rule,
  /*  915 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  916 */  iRegL_rule,
  /*  917 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  918 */  iRegL_rule,
  /*  919 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  920 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  921 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  922 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  923 */  iRegIorL2I_rule,
  /*  924 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  925 */  iRegIorL2I_rule,
  /*  926 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  927 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  928 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  929 */  iRegL_rule,
  /*  930 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  931 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  932 */  iRegL_rule,
  /*  933 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  934 */  iRegL_rule,
  /*  935 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  936 */  iRegL_rule,
  /*  937 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  938 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  939 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  940 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  941 */  iRegIorL2I_rule,
  /*  942 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  943 */  iRegIorL2I_rule,
  /*  944 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  945 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  946 */  vRegF_rule,
  /*  947 */  vRegD_rule,
  /*  948 */  vRegF_rule,
  /*  949 */  vRegD_rule,
  /*  950 */  vRegF_rule,
  /*  951 */  vRegD_rule,
  /*  952 */  _Binary_vRegF_vRegF_rule,
  /*  953 */  _Binary_vRegD_vRegD_rule,
  /*  954 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  955 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  956 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  957 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  958 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  959 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  960 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  961 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  962 */  _Binary_vRegF_vRegF_rule,
  /*  963 */  _Binary_vRegD_vRegD_rule,
  /*  964 */  vRegF_rule,
  /*  965 */  vRegF_rule,
  /*  966 */  vRegD_rule,
  /*  967 */  vRegD_rule,
  /*  968 */  vRegF_rule,
  /*  969 */  vRegD_rule,
  /*  970 */  0,
  /*  971 */  0,
  /*  972 */  0,
  /*  973 */  0,
  /*  974 */  _Binary_vRegD_vRegD_rule,
  /*  975 */  vRegF_rule,
  /*  976 */  _Binary_vRegD_vRegD_rule,
  /*  977 */  _Binary_vRegF_vRegF_rule,
  /*  978 */  iRegIorL2I_rule,
  /*  979 */  immILog_rule,
  /*  980 */  iRegIorL2I_rule,
  /*  981 */  immILog_rule,
  /*  982 */  iRegIorL2I_rule,
  /*  983 */  immILog_rule,
  /*  984 */  iRegL_rule,
  /*  985 */  immLLog_rule,
  /*  986 */  iRegL_rule,
  /*  987 */  immLLog_rule,
  /*  988 */  iRegL_rule,
  /*  989 */  immLLog_rule,
  /*  990 */  0,
  /*  991 */  immL_32bits_rule,
  /*  992 */  0,
  /*  993 */  0,
  /*  994 */  0,
  /*  995 */  0,
  /*  996 */  0,
  /*  997 */  0,
  /*  998 */  0,
  /*  999 */  0,
  /* 1000 */  0,
  /* 1001 */  0,
  /* 1002 */  0,
  /* 1003 */  0,
  /* 1004 */  0,
  /* 1005 */  0,
  /* 1006 */  0,
  /* 1007 */  0,
  /* 1008 */  0,
  /* 1009 */  iRegP_R10_rule,
  /* 1010 */  iRegP_R10_rule,
  /* 1011 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /* 1012 */  _OverflowMulL_iRegL_iRegL_rule,
  /* 1013 */  vRegF_rule,
  /* 1014 */  vRegD_rule,
  /* 1015 */  immF0_rule,
  /* 1016 */  immD0_rule,
  /* 1017 */  iRegIorL2I_rule,
  /* 1018 */  immI0_rule,
  /* 1019 */  0,
  /* 1020 */  iRegI_rule,
  /* 1021 */  0,
  /* 1022 */  iRegI_rule,
  /* 1023 */  0,
  /* 1024 */  rFlagsReg_rule,
  /* 1025 */  rFlagsRegU_rule,
  /* 1026 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1027 */  _CmpL_iRegL_immL0_rule,
  /* 1028 */  _CmpP_iRegP_immP0_rule,
  /* 1029 */  _CmpN_iRegN_immN0_rule,
  /* 1030 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /* 1031 */  _CmpU_iRegIorL2I_immI0_rule,
  /* 1032 */  _CmpUL_iRegL_immL0_rule,
  /* 1033 */  _CmpL_iRegL_immL0_rule,
  /* 1034 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1035 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1036 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1037 */  _CmpL_iRegL_immL0_rule,
  /* 1038 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1039 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1040 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1041 */  rFlagsReg_rule,
  /* 1042 */  rFlagsRegU_rule,
  /* 1043 */  0,
  /* 1044 */  0,
  /* 1045 */  0,
  /* 1046 */  0,
  /* 1047 */  0,
  /* 1048 */  0,
  /* 1049 */  inline_cache_RegP_rule,
  /* 1050 */  iRegP_R0_rule,
  /* 1051 */  0,
  /* 1052 */  0,
  /* 1053 */  0,
  /* 1054 */  0,
  /* 1055 */  iRegP_R0_rule,
  /* 1056 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1057 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1058 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1059 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1060 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1061 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1062 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1063 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1064 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1065 */  _Binary_iRegP_R3_immI_1_rule,
  /* 1066 */  iRegI_R3_rule,
  /* 1067 */  iRegI_R4_rule,
  /* 1068 */  iRegI_R4_rule,
  /* 1069 */  iRegP_R2_rule,
  /* 1070 */  iRegP_R2_rule,
  /* 1071 */  iRegI_R2_rule,
  /* 1072 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1073 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1074 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1075 */  0,
  /* 1076 */  0,
  /* 1077 */  0,
  /* 1078 */  vecD_rule,
  /* 1079 */  vecD_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  0,
  /* 1082 */  0,
  /* 1083 */  0,
  /* 1084 */  0,
  /* 1085 */  0,
  /* 1086 */  0,
  /* 1087 */  0,
  /* 1088 */  0,
  /* 1089 */  0,
  /* 1090 */  0,
  /* 1091 */  0,
  /* 1092 */  0,
  /* 1093 */  0,
  /* 1094 */  0,
  /* 1095 */  0,
  /* 1096 */  0,
  /* 1097 */  0,
  /* 1098 */  vecD_rule,
  /* 1099 */  vecX_rule,
  /* 1100 */  vecD_rule,
  /* 1101 */  vecX_rule,
  /* 1102 */  vecD_rule,
  /* 1103 */  vecX_rule,
  /* 1104 */  vecD_rule,
  /* 1105 */  vecX_rule,
  /* 1106 */  vecX_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  vecD_rule,
  /* 1109 */  vecX_rule,
  /* 1110 */  vecX_rule,
  /* 1111 */  vecD_rule,
  /* 1112 */  vecX_rule,
  /* 1113 */  vecX_rule,
  /* 1114 */  vecD_rule,
  /* 1115 */  vecX_rule,
  /* 1116 */  vecD_rule,
  /* 1117 */  vecX_rule,
  /* 1118 */  vecD_rule,
  /* 1119 */  vecX_rule,
  /* 1120 */  vecX_rule,
  /* 1121 */  vecD_rule,
  /* 1122 */  vecX_rule,
  /* 1123 */  vecX_rule,
  /* 1124 */  vecD_rule,
  /* 1125 */  vecX_rule,
  /* 1126 */  vecD_rule,
  /* 1127 */  vecX_rule,
  /* 1128 */  vecD_rule,
  /* 1129 */  vecX_rule,
  /* 1130 */  vecX_rule,
  /* 1131 */  vecD_rule,
  /* 1132 */  vecX_rule,
  /* 1133 */  vecX_rule,
  /* 1134 */  vecD_rule,
  /* 1135 */  vecX_rule,
  /* 1136 */  vecD_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecD_rule,
  /* 1139 */  vecX_rule,
  /* 1140 */  vecD_rule,
  /* 1141 */  vecX_rule,
  /* 1142 */  vecX_rule,
  /* 1143 */  _MulVS_vecD_vecD_rule,
  /* 1144 */  vecD_rule,
  /* 1145 */  _MulVS_vecX_vecX_rule,
  /* 1146 */  vecX_rule,
  /* 1147 */  _MulVI_vecD_vecD_rule,
  /* 1148 */  vecD_rule,
  /* 1149 */  _MulVI_vecX_vecX_rule,
  /* 1150 */  vecX_rule,
  /* 1151 */  _Binary_vecD_vecD_rule,
  /* 1152 */  _Binary_vecX_vecX_rule,
  /* 1153 */  _Binary_vecX_vecX_rule,
  /* 1154 */  _MulVS_vecD_vecD_rule,
  /* 1155 */  _MulVS_vecX_vecX_rule,
  /* 1156 */  _MulVI_vecD_vecD_rule,
  /* 1157 */  _MulVI_vecX_vecX_rule,
  /* 1158 */  _Binary__NegVF_vecD__vecD_rule,
  /* 1159 */  _Binary_vecD__NegVF_vecD__rule,
  /* 1160 */  _Binary__NegVF_vecX__vecX_rule,
  /* 1161 */  _Binary_vecX__NegVF_vecX__rule,
  /* 1162 */  _Binary__NegVD_vecX__vecX_rule,
  /* 1163 */  _Binary_vecX__NegVD_vecX__rule,
  /* 1164 */  vecD_rule,
  /* 1165 */  vecX_rule,
  /* 1166 */  vecX_rule,
  /* 1167 */  vecD_rule,
  /* 1168 */  vecX_rule,
  /* 1169 */  vecD_rule,
  /* 1170 */  vecX_rule,
  /* 1171 */  vecD_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecD_rule,
  /* 1174 */  vecX_rule,
  /* 1175 */  vecD_rule,
  /* 1176 */  vecX_rule,
  /* 1177 */  vecD_rule,
  /* 1178 */  vecX_rule,
  /* 1179 */  immI_rule,
  /* 1180 */  immI_rule,
  /* 1181 */  immI_positive_rule,
  /* 1182 */  immI_positive_rule,
  /* 1183 */  immI_positive_rule,
  /* 1184 */  immI_positive_rule,
  /* 1185 */  vecD_rule,
  /* 1186 */  vecX_rule,
  /* 1187 */  vecD_rule,
  /* 1188 */  vecX_rule,
  /* 1189 */  vecD_rule,
  /* 1190 */  vecX_rule,
  /* 1191 */  immI_rule,
  /* 1192 */  immI_rule,
  /* 1193 */  immI_positive_rule,
  /* 1194 */  immI_positive_rule,
  /* 1195 */  immI_positive_rule,
  /* 1196 */  immI_positive_rule,
  /* 1197 */  vecD_rule,
  /* 1198 */  vecX_rule,
  /* 1199 */  vecD_rule,
  /* 1200 */  vecX_rule,
  /* 1201 */  vecD_rule,
  /* 1202 */  vecX_rule,
  /* 1203 */  immI_rule,
  /* 1204 */  immI_rule,
  /* 1205 */  immI_positive_rule,
  /* 1206 */  immI_positive_rule,
  /* 1207 */  immI_positive_rule,
  /* 1208 */  immI_positive_rule,
  /* 1209 */  vecX_rule,
  /* 1210 */  vecX_rule,
  /* 1211 */  vecX_rule,
  /* 1212 */  immI_rule,
  /* 1213 */  immI_positive_rule,
  /* 1214 */  immI_positive_rule,
  /* 1215 */  vecD_rule,
  /* 1216 */  vecX_rule,
  /* 1217 */  vecX_rule,
  /* 1218 */  vecD_rule,
  /* 1219 */  vecX_rule,
  /* 1220 */  vecX_rule,
  /* 1221 */  0,
  /* 1222 */  0,
  /* 1223 */  0,
  /* 1224 */  _Binary_iRegP_iRegP_rule,
  /* 1225 */  _Binary_iRegP_iRegP_rule,
  /* 1226 */  _Binary_iRegP_iRegP_rule,
  /* 1227 */  _Binary_iRegP_iRegP_rule,
  /* 1228 */  _Binary_iRegP_iRegP_rule,
  /* 1229 */  _Binary_iRegP_iRegP_rule,
  /* 1230 */  iRegP_rule,
  /* 1231 */  iRegP_rule,
  /* 1232 */  0,
  /* 1233 */  vReg_rule,
  /* 1234 */  vReg_rule,
  /* 1235 */  vReg_rule,
  /* 1236 */  vReg_rule,
  /* 1237 */  vReg_rule,
  /* 1238 */  vReg_rule,
  /* 1239 */  vReg_rule,
  /* 1240 */  vReg_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  _Binary_vReg_vReg_rule,
  /* 1246 */  _Binary_vReg_vReg_rule,
  /* 1247 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1248 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1249 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1250 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1251 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1252 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1253 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1254 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1255 */  _Binary_vReg_vReg_rule,
  /* 1256 */  _Binary_vReg_vReg_rule,
  /* 1257 */  _MulVS_vReg_vReg_rule,
  /* 1258 */  vReg_rule,
  /* 1259 */  _MulVI_vReg_vReg_rule,
  /* 1260 */  vReg_rule,
  /* 1261 */  _MulVL_vReg_vReg_rule,
  /* 1262 */  vReg_rule,
  /* 1263 */  _MulVS_vReg_vReg_rule,
  /* 1264 */  _MulVI_vReg_vReg_rule,
  /* 1265 */  _MulVL_vReg_vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  vReg_rule,
  /* 1268 */  vReg_rule,
  /* 1269 */  vReg_rule,
  /* 1270 */  vReg_rule,
  /* 1271 */  vReg_rule,
  /* 1272 */  vReg_rule,
  /* 1273 */  vReg_rule,
  /* 1274 */  vReg_rule,
  /* 1275 */  0,
  /* 1276 */  0,
  /* 1277 */  0,
  /* 1278 */  0,
  /* 1279 */  0,
  /* 1280 */  0,
  /* 1281 */  0,
  /* 1282 */  0,
  /* 1283 */  0,
  /* 1284 */  0,
  /* 1285 */  vReg_rule,
  /* 1286 */  vReg_rule,
  /* 1287 */  vReg_rule,
  /* 1288 */  vReg_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  vReg_rule,
  /* 1294 */  vReg_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  vReg_rule,
  /* 1297 */  immI_rule,
  /* 1298 */  immI_rule,
  /* 1299 */  immI_rule,
  /* 1300 */  immI_rule,
  /* 1301 */  immI_rule,
  /* 1302 */  immI_rule,
  /* 1303 */  immI_rule,
  /* 1304 */  immI_rule,
  /* 1305 */  immI_rule,
  /* 1306 */  immI_rule,
  /* 1307 */  immI_rule,
  /* 1308 */  immI_rule,
  /* 1309 */  vReg_rule,
  /* 1310 */  vReg_rule,
  /* 1311 */  vReg_rule,
  /* 1312 */  vReg_rule,
  /* 1313 */  vReg_rule,
  /* 1314 */  vReg_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMIEXT",
  /*   13 */  "IMMI_LE_4",
  /*   14 */  "IMMI_31",
  /*   15 */  "IMMI_8",
  /*   16 */  "IMMI_16",
  /*   17 */  "IMMI_24",
  /*   18 */  "IMMI_32",
  /*   19 */  "IMMI_48",
  /*   20 */  "IMMI_56",
  /*   21 */  "IMMI_63",
  /*   22 */  "IMMI_64",
  /*   23 */  "IMMI_255",
  /*   24 */  "IMMI_65535",
  /*   25 */  "IMML_255",
  /*   26 */  "IMML_65535",
  /*   27 */  "IMML_4294967295",
  /*   28 */  "IMML_BITMASK",
  /*   29 */  "IMMI_BITMASK",
  /*   30 */  "IMML_POSITIVE_BITMASKI",
  /*   31 */  "IMMISCALE",
  /*   32 */  "IMMI26",
  /*   33 */  "IMMI19",
  /*   34 */  "IMMIU12",
  /*   35 */  "IMMLU12",
  /*   36 */  "IMMIOFFSET",
  /*   37 */  "IMMIOFFSET4",
  /*   38 */  "IMMIOFFSET8",
  /*   39 */  "IMMIOFFSET16",
  /*   40 */  "IMMLOFFSET",
  /*   41 */  "IMMLOFFSET4",
  /*   42 */  "IMMLOFFSET8",
  /*   43 */  "IMMLOFFSET16",
  /*   44 */  "IMMI8",
  /*   45 */  "IMMI8_SHIFT8",
  /*   46 */  "IMML8_SHIFT8",
  /*   47 */  "IMMIADDSUB",
  /*   48 */  "IMMILOG",
  /*   49 */  "IMML",
  /*   50 */  "IMML0",
  /*   51 */  "IMML_1",
  /*   52 */  "IMML_M1",
  /*   53 */  "IMML_PC_OFF",
  /*   54 */  "IMMLADDSUB",
  /*   55 */  "IMMLLOG",
  /*   56 */  "IMML_32BITS",
  /*   57 */  "IMMP",
  /*   58 */  "IMMP0",
  /*   59 */  "IMMP_1",
  /*   60 */  "IMMPOLLPAGE",
  /*   61 */  "IMMBYTEMAPBASE",
  /*   62 */  "IMMP_M1",
  /*   63 */  "IMMP_M2",
  /*   64 */  "IMMD",
  /*   65 */  "IMMD0",
  /*   66 */  "IMMDPACKED",
  /*   67 */  "IMMF",
  /*   68 */  "IMMF0",
  /*   69 */  "IMMFPACKED",
  /*   70 */  "IMMI_POSITIVE",
  /*   71 */  "IMMN",
  /*   72 */  "IMMN0",
  /*   73 */  "IMMNKLASS",
  /*   74 */  "IREGI",
  /*   75 */  "IREGINOSP",
  /*   76 */  "IREGL",
  /*   77 */  "IREGLNOSP",
  /*   78 */  "IREGP",
  /*   79 */  "IREGPNOSP",
  /*   80 */  "IREGP_R0",
  /*   81 */  "IREGP_R1",
  /*   82 */  "IREGP_R2",
  /*   83 */  "IREGP_R3",
  /*   84 */  "IREGP_R4",
  /*   85 */  "IREGP_R5",
  /*   86 */  "IREGP_R10",
  /*   87 */  "IREGL_R0",
  /*   88 */  "IREGL_R2",
  /*   89 */  "IREGL_R3",
  /*   90 */  "IREGL_R11",
  /*   91 */  "IREGP_FP",
  /*   92 */  "IREGI_R0",
  /*   93 */  "IREGI_R2",
  /*   94 */  "IREGI_R3",
  /*   95 */  "IREGI_R4",
  /*   96 */  "IREGN",
  /*   97 */  "IREGN_R0",
  /*   98 */  "IREGN_R2",
  /*   99 */  "IREGN_R3",
  /*  100 */  "IREGNNOSP",
  /*  101 */  "IREGIHEAPBASE",
  /*  102 */  "VREGF",
  /*  103 */  "VREGD",
  /*  104 */  "VREG",
  /*  105 */  "VECD",
  /*  106 */  "VECX",
  /*  107 */  "VREGD_V0",
  /*  108 */  "VREGD_V1",
  /*  109 */  "VREGD_V2",
  /*  110 */  "VREGD_V3",
  /*  111 */  "VREGD_V4",
  /*  112 */  "VREGD_V5",
  /*  113 */  "VREGD_V6",
  /*  114 */  "VREGD_V7",
  /*  115 */  "VREGD_V8",
  /*  116 */  "VREGD_V9",
  /*  117 */  "VREGD_V10",
  /*  118 */  "VREGD_V11",
  /*  119 */  "VREGD_V12",
  /*  120 */  "VREGD_V13",
  /*  121 */  "VREGD_V14",
  /*  122 */  "VREGD_V15",
  /*  123 */  "VREGD_V16",
  /*  124 */  "VREGD_V17",
  /*  125 */  "VREGD_V18",
  /*  126 */  "VREGD_V19",
  /*  127 */  "VREGD_V20",
  /*  128 */  "VREGD_V21",
  /*  129 */  "VREGD_V22",
  /*  130 */  "VREGD_V23",
  /*  131 */  "VREGD_V24",
  /*  132 */  "VREGD_V25",
  /*  133 */  "VREGD_V26",
  /*  134 */  "VREGD_V27",
  /*  135 */  "VREGD_V28",
  /*  136 */  "VREGD_V29",
  /*  137 */  "VREGD_V30",
  /*  138 */  "VREGD_V31",
  /*  139 */  "PREGGOV",
  /*  140 */  "RFLAGSREG",
  /*  141 */  "RFLAGSREGU",
  /*  142 */  "INLINE_CACHE_REGP",
  /*  143 */  "INTERPRETER_METHOD_OOP_REGP",
  /*  144 */  "THREAD_REGP",
  /*  145 */  "LR_REGP",
  /*  146 */  "INDIRECT",
  /*  147 */  "INDINDEXSCALEDI2L",
  /*  148 */  "INDINDEXSCALED",
  /*  149 */  "INDINDEXI2L",
  /*  150 */  "INDINDEX",
  /*  151 */  "INDOFFI",
  /*  152 */  "INDOFFI4",
  /*  153 */  "INDOFFI8",
  /*  154 */  "INDOFFI16",
  /*  155 */  "INDOFFL",
  /*  156 */  "INDOFFL4",
  /*  157 */  "INDOFFL8",
  /*  158 */  "INDOFFL16",
  /*  159 */  "INDIRECTN",
  /*  160 */  "INDINDEXSCALEDI2LN",
  /*  161 */  "INDINDEXSCALEDN",
  /*  162 */  "INDINDEXI2LN",
  /*  163 */  "INDINDEXN",
  /*  164 */  "INDOFFIN",
  /*  165 */  "INDOFFLN",
  /*  166 */  "THREAD_ANCHOR_PC",
  /*  167 */  "STACKSLOTP",
  /*  168 */  "STACKSLOTI",
  /*  169 */  "STACKSLOTF",
  /*  170 */  "STACKSLOTD",
  /*  171 */  "STACKSLOTL",
  /*  172 */  "CMPOP",
  /*  173 */  "CMPOPU",
  /*  174 */  "CMPOPEQNE",
  /*  175 */  "CMPOPLTGE",
  /*  176 */  "CMPOPUEQNELTGE",
  /*  177 */  "IREGL2I",
  /*  178 */  "VMEMA_IMMIOFFSET4",
  /*  179 */  "VMEMA_IMMLOFFSET4",
  /*  180 */  "VMEMA_INDOFFI4",
  /*  181 */  "VMEMA_INDOFFL4",
  // last operand
  /*  182 */  "VMEM4",
  /*  183 */  "VMEM8",
  /*  184 */  "VMEM16",
  /*  185 */  "MEMORY",
  /*  186 */  "IREGIORL2I",
  /*  187 */  "VMEMA",
  // last operand class
  /*  188 */  "_ConvI2L_iRegI_",
  /*  189 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  190 */  "_LShiftL_iRegL_immIScale",
  /*  191 */  "_DecodeN_iRegN_",
  /*  192 */  "_LoadB_memory_",
  /*  193 */  "_LoadUB_memory_",
  /*  194 */  "_LoadS_memory_",
  /*  195 */  "_LoadUS_memory_",
  /*  196 */  "_LoadI_memory_",
  /*  197 */  "_ConvI2L__LoadI_memory__",
  /*  198 */  "_LoadB_indirect_",
  /*  199 */  "_LoadUB_indirect_",
  /*  200 */  "_LoadUS_indirect_",
  /*  201 */  "_LoadS_indirect_",
  /*  202 */  "_LoadI_indirect_",
  /*  203 */  "_ConvI2L__LoadI_indirect__",
  /*  204 */  "_LoadL_memory_",
  /*  205 */  "_CastP2X_iRegP_",
  /*  206 */  "_CastP2X__DecodeN_iRegN__",
  /*  207 */  "_Binary_iRegP_iRegP",
  /*  208 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  209 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  210 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  211 */  "_Binary_iRegI_iRegI",
  /*  212 */  "_Binary_iRegL_iRegL",
  /*  213 */  "_Binary_iRegN_iRegN",
  /*  214 */  "_Binary_cmpOp_rFlagsReg",
  /*  215 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  216 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  217 */  "_Binary_immI0_iRegIorL2I",
  /*  218 */  "_Binary_iRegIorL2I_immI0",
  /*  219 */  "_Binary_immI_1_immI0",
  /*  220 */  "_Binary_iRegL_immL0",
  /*  221 */  "_Binary_immL0_iRegL",
  /*  222 */  "_Binary_iRegP_immP0",
  /*  223 */  "_Binary_immP0_iRegP",
  /*  224 */  "_Binary_iRegN_immN0",
  /*  225 */  "_Binary_immN0_iRegN",
  /*  226 */  "_Binary_vRegF_vRegF",
  /*  227 */  "_Binary_vRegD_vRegD",
  /*  228 */  "_ConvL2I_iRegL_",
  /*  229 */  "_ConvI2L_iRegIorL2I_",
  /*  230 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  231 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  232 */  "_MulL_iRegL_iRegL",
  /*  233 */  "_MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I_",
  /*  234 */  "_SubL_immL0__ConvI2L_iRegIorL2I_",
  /*  235 */  "_XorI_iRegIorL2I_immI_M1",
  /*  236 */  "_XorL_iRegL_immL_M1",
  /*  237 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  238 */  "_XorL_iRegL_iRegL",
  /*  239 */  "_URShiftI_iRegIorL2I_immI",
  /*  240 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  241 */  "_URShiftL_iRegL_immI",
  /*  242 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  243 */  "_RShiftI_iRegIorL2I_immI",
  /*  244 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  245 */  "_RShiftL_iRegL_immI",
  /*  246 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  247 */  "_LShiftI_iRegIorL2I_immI",
  /*  248 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  249 */  "_LShiftL_iRegL_immI",
  /*  250 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  251 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  252 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  253 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  254 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  255 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  256 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  257 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  258 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  259 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  260 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  261 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  262 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  263 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  264 */  "_AndI_iRegIorL2I_immI_bitmask",
  /*  265 */  "_AndL_iRegL_immL_bitmask",
  /*  266 */  "_LShiftI__AndI_iRegIorL2I_immI_bitmask_immI",
  /*  267 */  "_AndL_iRegL_immL_positive_bitmaskI",
  /*  268 */  "_LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI",
  /*  269 */  "_ConvI2L__AndI_iRegIorL2I_immI_bitmask_",
  /*  270 */  "_ConvL2I__AndL_iRegL_immL_positive_bitmaskI_",
  /*  271 */  "_AndI_iRegI_immI_bitmask",
  /*  272 */  "_LShiftL_iRegL_iRegI",
  /*  273 */  "_SubI_immI_64_iRegI",
  /*  274 */  "_URShiftL_iRegL__SubI_immI_64_iRegI",
  /*  275 */  "_SubI_immI0_iRegI",
  /*  276 */  "_URShiftL_iRegL__SubI_immI0_iRegI",
  /*  277 */  "_LShiftI_iRegI_iRegI",
  /*  278 */  "_SubI_immI_32_iRegI",
  /*  279 */  "_URShiftI_iRegI__SubI_immI_32_iRegI",
  /*  280 */  "_URShiftI_iRegI__SubI_immI0_iRegI",
  /*  281 */  "_URShiftL_iRegL_iRegI",
  /*  282 */  "_LShiftL_iRegL__SubI_immI_64_iRegI",
  /*  283 */  "_LShiftL_iRegL__SubI_immI0_iRegI",
  /*  284 */  "_URShiftI_iRegI_iRegI",
  /*  285 */  "_LShiftI_iRegI__SubI_immI_32_iRegI",
  /*  286 */  "_LShiftI_iRegI__SubI_immI0_iRegI",
  /*  287 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  288 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  289 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  290 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  291 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  292 */  "_LShiftL_iRegL_immI_48",
  /*  293 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  294 */  "_LShiftL_iRegL_immI_32",
  /*  295 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  296 */  "_LShiftL_iRegL_immI_56",
  /*  297 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  298 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  299 */  "_AndI_iRegIorL2I_immI_255",
  /*  300 */  "_AndI_iRegIorL2I_immI_65535",
  /*  301 */  "_AndL_iRegL_immL_255",
  /*  302 */  "_AndL_iRegL_immL_65535",
  /*  303 */  "_AndL_iRegL_immL_4294967295",
  /*  304 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt",
  /*  305 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt",
  /*  306 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt",
  /*  307 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt",
  /*  308 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt",
  /*  309 */  "_LShiftL__ConvI2L_iRegIorL2I__immIExt",
  /*  310 */  "_LShiftL__AndL_iRegL_immL_255_immIExt",
  /*  311 */  "_LShiftL__AndL_iRegL_immL_65535_immIExt",
  /*  312 */  "_LShiftL__AndL_iRegL_immL_4294967295_immIExt",
  /*  313 */  "_LShiftI__AndI_iRegIorL2I_immI_255_immIExt",
  /*  314 */  "_LShiftI__AndI_iRegIorL2I_immI_65535_immIExt",
  /*  315 */  "_NegF_vRegF_",
  /*  316 */  "_Binary__NegF_vRegF__vRegF",
  /*  317 */  "_Binary_vRegF__NegF_vRegF_",
  /*  318 */  "_NegD_vRegD_",
  /*  319 */  "_Binary__NegD_vRegD__vRegD",
  /*  320 */  "_Binary_vRegD__NegD_vRegD_",
  /*  321 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  322 */  "_OverflowMulL_iRegL_iRegL",
  /*  323 */  "_CmpI_iRegIorL2I_immI0",
  /*  324 */  "_CmpL_iRegL_immL0",
  /*  325 */  "_CmpP_iRegP_immP0",
  /*  326 */  "_CmpN_iRegN_immN0",
  /*  327 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  328 */  "_CmpU_iRegIorL2I_immI0",
  /*  329 */  "_CmpUL_iRegL_immL0",
  /*  330 */  "_AndL_iRegL_immL",
  /*  331 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  332 */  "_AndI_iRegIorL2I_immI",
  /*  333 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  334 */  "_AndL_iRegL_iRegL",
  /*  335 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  336 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  337 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  338 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  339 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  340 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  341 */  "_Binary_iRegP_R3_immI_le_4",
  /*  342 */  "_Binary_iRegP_R3_immI_1",
  /*  343 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  344 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  345 */  "_MulVS_vecD_vecD",
  /*  346 */  "_MulVS_vecX_vecX",
  /*  347 */  "_MulVI_vecD_vecD",
  /*  348 */  "_MulVI_vecX_vecX",
  /*  349 */  "_Binary_vecD_vecD",
  /*  350 */  "_Binary_vecX_vecX",
  /*  351 */  "_NegVF_vecD_",
  /*  352 */  "_Binary__NegVF_vecD__vecD",
  /*  353 */  "_Binary_vecD__NegVF_vecD_",
  /*  354 */  "_NegVF_vecX_",
  /*  355 */  "_Binary__NegVF_vecX__vecX",
  /*  356 */  "_Binary_vecX__NegVF_vecX_",
  /*  357 */  "_NegVD_vecX_",
  /*  358 */  "_Binary__NegVD_vecX__vecX",
  /*  359 */  "_Binary_vecX__NegVD_vecX_",
  /*  360 */  "_Binary_vReg_vReg",
  /*  361 */  "_NegVF_vReg_",
  /*  362 */  "_Binary__NegVF_vReg__vReg",
  /*  363 */  "_Binary_vReg__NegVF_vReg_",
  /*  364 */  "_NegVD_vReg_",
  /*  365 */  "_Binary__NegVD_vReg__vReg",
  /*  366 */  "_Binary_vReg__NegVD_vReg_",
  /*  367 */  "_MulVS_vReg_vReg",
  /*  368 */  "_MulVI_vReg_vReg",
  /*  369 */  "_MulVL_vReg_vReg",
  // last internally defined operand
  /*  370 */  "loadConI",
  /*  371 */  "loadConL",
  /*  372 */  "loadConP",
  /*  373 */  "loadConP0",
  /*  374 */  "loadConP1",
  /*  375 */  "loadConPollPage",
  /*  376 */  "loadByteMapBase",
  /*  377 */  "loadConN",
  /*  378 */  "loadConN0",
  /*  379 */  "loadConNKlass",
  /*  380 */  "loadConF_packed",
  /*  381 */  "loadConF",
  /*  382 */  "loadConD_packed",
  /*  383 */  "loadConD",
  /*  384 */  "countLeadingZerosI",
  /*  385 */  "countLeadingZerosL",
  /*  386 */  "countTrailingZerosI",
  /*  387 */  "countTrailingZerosL",
  /*  388 */  "castX2P",
  /*  389 */  "castP2X",
  /*  390 */  "checkCastPP",
  /*  391 */  "castPP",
  /*  392 */  "castII",
  /*  393 */  "castLL",
  /*  394 */  "storePConditional",
  /*  395 */  "storeLConditional",
  /*  396 */  "storeIConditional",
  /*  397 */  "negF_reg_reg",
  /*  398 */  "negD_reg_reg",
  /*  399 */  "absF_reg",
  /*  400 */  "absD_reg",
  /*  401 */  "MoveF2I_stack_reg",
  /*  402 */  "MoveI2F_stack_reg",
  /*  403 */  "MoveD2L_stack_reg",
  /*  404 */  "MoveL2D_stack_reg",
  /*  405 */  "MoveF2I_reg_reg",
  /*  406 */  "MoveI2F_reg_reg",
  /*  407 */  "MoveD2L_reg_reg",
  /*  408 */  "MoveL2D_reg_reg",
  /*  409 */  "overflowAddI_reg_reg",
  /*  410 */  "overflowAddI_reg_imm",
  /*  411 */  "overflowAddL_reg_reg",
  /*  412 */  "overflowAddL_reg_imm",
  /*  413 */  "overflowSubI_reg_reg",
  /*  414 */  "overflowSubI_reg_imm",
  /*  415 */  "overflowSubL_reg_reg",
  /*  416 */  "overflowSubL_reg_imm",
  /*  417 */  "overflowNegI_reg",
  /*  418 */  "overflowNegL_reg",
  /*  419 */  "overflowMulI_reg",
  /*  420 */  "overflowMulL_reg",
  /*  421 */  "compI_reg_reg",
  /*  422 */  "compI_reg_immI0",
  /*  423 */  "compI_reg_immIAddSub",
  /*  424 */  "compI_reg_immI",
  /*  425 */  "compU_reg_reg",
  /*  426 */  "compU_reg_immI0",
  /*  427 */  "compU_reg_immIAddSub",
  /*  428 */  "compU_reg_immI",
  /*  429 */  "compL_reg_reg",
  /*  430 */  "compL_reg_immL0",
  /*  431 */  "compL_reg_immLAddSub",
  /*  432 */  "compL_reg_immL",
  /*  433 */  "compUL_reg_reg",
  /*  434 */  "compUL_reg_immL0",
  /*  435 */  "compUL_reg_immLAddSub",
  /*  436 */  "compUL_reg_immL",
  /*  437 */  "compP_reg_reg",
  /*  438 */  "compN_reg_reg",
  /*  439 */  "testP_reg",
  /*  440 */  "testN_reg",
  /*  441 */  "compF_reg_reg",
  /*  442 */  "compF_reg_zero",
  /*  443 */  "compD_reg_reg",
  /*  444 */  "compD_reg_zero",
  /*  445 */  "cmpL_and",
  /*  446 */  "cmpI_and",
  /*  447 */  "cmpL_and_reg",
  /*  448 */  "cmpI_and_reg",
  /*  449 */  "cmpFastLock",
  /*  450 */  "cmpFastUnlock",
  /*  451 */  "partialSubtypeCheckVsZero",
  /*  452 */  "tlsLoadP",
  /*  453 */  "vsqrt2F",
  /*  454 */  "vsqrt4F",
  /*  455 */  "vsqrt2D",
  /*  456 */  "vabs8B",
  /*  457 */  "vabs16B",
  /*  458 */  "vabs4S",
  /*  459 */  "vabs8S",
  /*  460 */  "vabs2I",
  /*  461 */  "vabs4I",
  /*  462 */  "vabs2L",
  /*  463 */  "vabs2F",
  /*  464 */  "vabs4F",
  /*  465 */  "vabs2D",
  /*  466 */  "vneg2F",
  /*  467 */  "vneg4F",
  /*  468 */  "vneg2D",
  /*  469 */  "vshiftcnt8B",
  /*  470 */  "vshiftcnt8B_0",
  /*  471 */  "vshiftcnt16B",
  /*  472 */  "vshiftcnt16B_0",
  /*  473 */  "vpopcount4I",
  /*  474 */  "vpopcount2I",
  /*  475 */  "vnegF",
  /*  476 */  "vnegD",
  /*  477 */  "vpopcountI",
  /*  478 */  "vshiftcntB",
  /*  479 */  "vshiftcntB_0",
  /*  480 */  "vshiftcntS",
  /*  481 */  "vshiftcntS_0",
  /*  482 */  "vshiftcntI",
  /*  483 */  "vshiftcntI_0",
  /*  484 */  "vshiftcntL",
  /*  485 */  "vshiftcntL_0",
  /*  486 */  "vsqrtF",
  /*  487 */  "vsqrtD",
  /*  488 */  "loadB",
  /*  489 */  "loadB2L",
  /*  490 */  "loadUB",
  /*  491 */  "loadUB2L",
  /*  492 */  "loadS",
  /*  493 */  "loadS2L",
  /*  494 */  "loadUS",
  /*  495 */  "loadUS2L",
  /*  496 */  "loadI",
  /*  497 */  "loadI2L",
  /*  498 */  "loadUI2L",
  /*  499 */  "loadL",
  /*  500 */  "loadRange",
  /*  501 */  "loadP",
  /*  502 */  "loadN",
  /*  503 */  "loadKlass",
  /*  504 */  "loadNKlass",
  /*  505 */  "loadF",
  /*  506 */  "loadD",
  /*  507 */  "storeimmCM0",
  /*  508 */  "storeimmCM0_ordered",
  /*  509 */  "storeB",
  /*  510 */  "storeimmB0",
  /*  511 */  "storeC",
  /*  512 */  "storeimmC0",
  /*  513 */  "storeI",
  /*  514 */  "storeimmI0",
  /*  515 */  "storeL",
  /*  516 */  "storeimmL0",
  /*  517 */  "storeP",
  /*  518 */  "storeimmP0",
  /*  519 */  "storeN",
  /*  520 */  "storeImmN0",
  /*  521 */  "storeF",
  /*  522 */  "storeD",
  /*  523 */  "storeNKlass",
  /*  524 */  "prefetchalloc",
  /*  525 */  "loadB_volatile",
  /*  526 */  "loadB2L_volatile",
  /*  527 */  "loadUB_volatile",
  /*  528 */  "loadUB2L_volatile",
  /*  529 */  "loadS_volatile",
  /*  530 */  "loadUS_volatile",
  /*  531 */  "loadUS2L_volatile",
  /*  532 */  "loadS2L_volatile",
  /*  533 */  "loadI_volatile",
  /*  534 */  "loadUI2L_volatile",
  /*  535 */  "loadL_volatile",
  /*  536 */  "loadP_volatile",
  /*  537 */  "loadN_volatile",
  /*  538 */  "loadF_volatile",
  /*  539 */  "loadD_volatile",
  /*  540 */  "storeB_volatile",
  /*  541 */  "storeC_volatile",
  /*  542 */  "storeI_volatile",
  /*  543 */  "storeL_volatile",
  /*  544 */  "storeP_volatile",
  /*  545 */  "storeN_volatile",
  /*  546 */  "storeF_volatile",
  /*  547 */  "storeD_volatile",
  /*  548 */  "bytes_reverse_int",
  /*  549 */  "bytes_reverse_long",
  /*  550 */  "bytes_reverse_unsigned_short",
  /*  551 */  "bytes_reverse_short",
  /*  552 */  "popCountI",
  /*  553 */  "popCountI_mem",
  /*  554 */  "popCountL",
  /*  555 */  "popCountL_mem",
  /*  556 */  "load_fence",
  /*  557 */  "unnecessary_membar_acquire",
  /*  558 */  "membar_acquire",
  /*  559 */  "membar_acquire_lock",
  /*  560 */  "store_fence",
  /*  561 */  "unnecessary_membar_release",
  /*  562 */  "membar_release",
  /*  563 */  "membar_storestore",
  /*  564 */  "membar_release_lock",
  /*  565 */  "unnecessary_membar_volatile",
  /*  566 */  "membar_volatile",
  /*  567 */  "convP2I",
  /*  568 */  "convN2I",
  /*  569 */  "encodeHeapOop",
  /*  570 */  "encodeHeapOop_not_null",
  /*  571 */  "decodeHeapOop",
  /*  572 */  "decodeHeapOop_not_null",
  /*  573 */  "encodeKlass_not_null",
  /*  574 */  "decodeKlass_not_null",
  /*  575 */  "loadPLocked",
  /*  576 */  "compareAndSwapB",
  /*  577 */  "compareAndSwapS",
  /*  578 */  "compareAndSwapI",
  /*  579 */  "compareAndSwapL",
  /*  580 */  "compareAndSwapP",
  /*  581 */  "compareAndSwapN",
  /*  582 */  "compareAndSwapBAcq",
  /*  583 */  "compareAndSwapSAcq",
  /*  584 */  "compareAndSwapIAcq",
  /*  585 */  "compareAndSwapLAcq",
  /*  586 */  "compareAndSwapPAcq",
  /*  587 */  "compareAndSwapNAcq",
  /*  588 */  "compareAndExchangeB",
  /*  589 */  "compareAndExchangeS",
  /*  590 */  "compareAndExchangeI",
  /*  591 */  "compareAndExchangeL",
  /*  592 */  "compareAndExchangeN",
  /*  593 */  "compareAndExchangeP",
  /*  594 */  "compareAndExchangeBAcq",
  /*  595 */  "compareAndExchangeSAcq",
  /*  596 */  "compareAndExchangeIAcq",
  /*  597 */  "compareAndExchangeLAcq",
  /*  598 */  "compareAndExchangeNAcq",
  /*  599 */  "compareAndExchangePAcq",
  /*  600 */  "weakCompareAndSwapB",
  /*  601 */  "weakCompareAndSwapS",
  /*  602 */  "weakCompareAndSwapI",
  /*  603 */  "weakCompareAndSwapL",
  /*  604 */  "weakCompareAndSwapN",
  /*  605 */  "weakCompareAndSwapP",
  /*  606 */  "weakCompareAndSwapBAcq",
  /*  607 */  "weakCompareAndSwapSAcq",
  /*  608 */  "weakCompareAndSwapIAcq",
  /*  609 */  "weakCompareAndSwapLAcq",
  /*  610 */  "weakCompareAndSwapNAcq",
  /*  611 */  "weakCompareAndSwapPAcq",
  /*  612 */  "get_and_setI",
  /*  613 */  "get_and_setL",
  /*  614 */  "get_and_setN",
  /*  615 */  "get_and_setP",
  /*  616 */  "get_and_setIAcq",
  /*  617 */  "get_and_setLAcq",
  /*  618 */  "get_and_setNAcq",
  /*  619 */  "get_and_setPAcq",
  /*  620 */  "get_and_addL",
  /*  621 */  "get_and_addL_no_res",
  /*  622 */  "get_and_addLi",
  /*  623 */  "get_and_addLi_no_res",
  /*  624 */  "get_and_addI",
  /*  625 */  "get_and_addI_no_res",
  /*  626 */  "get_and_addIi",
  /*  627 */  "get_and_addIi_no_res",
  /*  628 */  "get_and_addLAcq",
  /*  629 */  "get_and_addL_no_resAcq",
  /*  630 */  "get_and_addLiAcq",
  /*  631 */  "get_and_addLi_no_resAcq",
  /*  632 */  "get_and_addIAcq",
  /*  633 */  "get_and_addI_no_resAcq",
  /*  634 */  "get_and_addIiAcq",
  /*  635 */  "get_and_addIi_no_resAcq",
  /*  636 */  "cmpL3_reg_reg",
  /*  637 */  "cmpL3_reg_imm",
  /*  638 */  "cmovI_reg_reg",
  /*  639 */  "cmovUI_reg_reg",
  /*  640 */  "cmovI_zero_reg",
  /*  641 */  "cmovUI_zero_reg",
  /*  642 */  "cmovI_reg_zero",
  /*  643 */  "cmovUI_reg_zero",
  /*  644 */  "cmovI_reg_zero_one",
  /*  645 */  "cmovUI_reg_zero_one",
  /*  646 */  "cmovL_reg_reg",
  /*  647 */  "cmovUL_reg_reg",
  /*  648 */  "cmovL_reg_zero",
  /*  649 */  "cmovUL_reg_zero",
  /*  650 */  "cmovL_zero_reg",
  /*  651 */  "cmovUL_zero_reg",
  /*  652 */  "cmovP_reg_reg",
  /*  653 */  "cmovUP_reg_reg",
  /*  654 */  "cmovP_reg_zero",
  /*  655 */  "cmovUP_reg_zero",
  /*  656 */  "cmovP_zero_reg",
  /*  657 */  "cmovUP_zero_reg",
  /*  658 */  "cmovN_reg_reg",
  /*  659 */  "cmovUN_reg_reg",
  /*  660 */  "cmovN_reg_zero",
  /*  661 */  "cmovUN_reg_zero",
  /*  662 */  "cmovN_zero_reg",
  /*  663 */  "cmovUN_zero_reg",
  /*  664 */  "cmovF_reg",
  /*  665 */  "cmovUF_reg",
  /*  666 */  "cmovD_reg",
  /*  667 */  "cmovUD_reg",
  /*  668 */  "addI_reg_reg",
  /*  669 */  "addI_reg_imm",
  /*  670 */  "addI_reg_imm_i2l",
  /*  671 */  "addP_reg_reg",
  /*  672 */  "addP_reg_reg_ext",
  /*  673 */  "addP_reg_reg_lsl",
  /*  674 */  "addP_reg_reg_ext_shift",
  /*  675 */  "lshift_ext",
  /*  676 */  "addP_reg_imm",
  /*  677 */  "addL_reg_reg",
  /*  678 */  "addL_reg_imm",
  /*  679 */  "subI_reg_reg",
  /*  680 */  "subI_reg_imm",
  /*  681 */  "subL_reg_reg",
  /*  682 */  "subL_reg_imm",
  /*  683 */  "negI_reg",
  /*  684 */  "negL_reg",
  /*  685 */  "mulI",
  /*  686 */  "smulI",
  /*  687 */  "smulI_0",
  /*  688 */  "mulL",
  /*  689 */  "mulHiL_rReg",
  /*  690 */  "maddI",
  /*  691 */  "maddI_0",
  /*  692 */  "msubI",
  /*  693 */  "maddL",
  /*  694 */  "maddL_0",
  /*  695 */  "msubL",
  /*  696 */  "smaddL",
  /*  697 */  "smaddL_1",
  /*  698 */  "smaddL_0",
  /*  699 */  "smaddL_2",
  /*  700 */  "smsubL",
  /*  701 */  "smsubL_0",
  /*  702 */  "smnegL",
  /*  703 */  "smnegL_0",
  /*  704 */  "smnegL_1",
  /*  705 */  "smnegL_2",
  /*  706 */  "divI",
  /*  707 */  "divL",
  /*  708 */  "modI",
  /*  709 */  "modL",
  /*  710 */  "lShiftI_reg_reg",
  /*  711 */  "lShiftI_reg_imm",
  /*  712 */  "urShiftI_reg_reg",
  /*  713 */  "urShiftI_reg_imm",
  /*  714 */  "rShiftI_reg_reg",
  /*  715 */  "rShiftI_reg_imm",
  /*  716 */  "lShiftL_reg_reg",
  /*  717 */  "lShiftL_reg_imm",
  /*  718 */  "urShiftL_reg_reg",
  /*  719 */  "urShiftL_reg_imm",
  /*  720 */  "urShiftP_reg_imm",
  /*  721 */  "rShiftL_reg_reg",
  /*  722 */  "rShiftL_reg_imm",
  /*  723 */  "regL_not_reg",
  /*  724 */  "regI_not_reg",
  /*  725 */  "AndI_reg_not_reg",
  /*  726 */  "AndI_reg_not_reg_0",
  /*  727 */  "AndL_reg_not_reg",
  /*  728 */  "AndL_reg_not_reg_0",
  /*  729 */  "OrI_reg_not_reg",
  /*  730 */  "OrI_reg_not_reg_0",
  /*  731 */  "OrL_reg_not_reg",
  /*  732 */  "OrL_reg_not_reg_0",
  /*  733 */  "XorI_reg_not_reg",
  /*  734 */  "XorI_reg_not_reg_0",
  /*  735 */  "XorL_reg_not_reg",
  /*  736 */  "XorL_reg_not_reg_0",
  /*  737 */  "AndI_reg_URShift_not_reg",
  /*  738 */  "AndI_reg_URShift_not_reg_0",
  /*  739 */  "AndL_reg_URShift_not_reg",
  /*  740 */  "AndL_reg_URShift_not_reg_0",
  /*  741 */  "AndI_reg_RShift_not_reg",
  /*  742 */  "AndI_reg_RShift_not_reg_0",
  /*  743 */  "AndL_reg_RShift_not_reg",
  /*  744 */  "AndL_reg_RShift_not_reg_0",
  /*  745 */  "AndI_reg_LShift_not_reg",
  /*  746 */  "AndI_reg_LShift_not_reg_0",
  /*  747 */  "AndL_reg_LShift_not_reg",
  /*  748 */  "AndL_reg_LShift_not_reg_0",
  /*  749 */  "XorI_reg_URShift_not_reg",
  /*  750 */  "XorI_reg_URShift_not_reg_1",
  /*  751 */  "XorI_reg_URShift_not_reg_0",
  /*  752 */  "XorI_reg_URShift_not_reg_2",
  /*  753 */  "XorL_reg_URShift_not_reg",
  /*  754 */  "XorL_reg_URShift_not_reg_1",
  /*  755 */  "XorL_reg_URShift_not_reg_0",
  /*  756 */  "XorL_reg_URShift_not_reg_2",
  /*  757 */  "XorI_reg_RShift_not_reg",
  /*  758 */  "XorI_reg_RShift_not_reg_1",
  /*  759 */  "XorI_reg_RShift_not_reg_0",
  /*  760 */  "XorI_reg_RShift_not_reg_2",
  /*  761 */  "XorL_reg_RShift_not_reg",
  /*  762 */  "XorL_reg_RShift_not_reg_1",
  /*  763 */  "XorL_reg_RShift_not_reg_0",
  /*  764 */  "XorL_reg_RShift_not_reg_2",
  /*  765 */  "XorI_reg_LShift_not_reg",
  /*  766 */  "XorI_reg_LShift_not_reg_1",
  /*  767 */  "XorI_reg_LShift_not_reg_0",
  /*  768 */  "XorI_reg_LShift_not_reg_2",
  /*  769 */  "XorL_reg_LShift_not_reg",
  /*  770 */  "XorL_reg_LShift_not_reg_1",
  /*  771 */  "XorL_reg_LShift_not_reg_0",
  /*  772 */  "XorL_reg_LShift_not_reg_2",
  /*  773 */  "OrI_reg_URShift_not_reg",
  /*  774 */  "OrI_reg_URShift_not_reg_0",
  /*  775 */  "OrL_reg_URShift_not_reg",
  /*  776 */  "OrL_reg_URShift_not_reg_0",
  /*  777 */  "OrI_reg_RShift_not_reg",
  /*  778 */  "OrI_reg_RShift_not_reg_0",
  /*  779 */  "OrL_reg_RShift_not_reg",
  /*  780 */  "OrL_reg_RShift_not_reg_0",
  /*  781 */  "OrI_reg_LShift_not_reg",
  /*  782 */  "OrI_reg_LShift_not_reg_0",
  /*  783 */  "OrL_reg_LShift_not_reg",
  /*  784 */  "OrL_reg_LShift_not_reg_0",
  /*  785 */  "AndI_reg_URShift_reg",
  /*  786 */  "AndI_reg_URShift_reg_0",
  /*  787 */  "AndL_reg_URShift_reg",
  /*  788 */  "AndL_reg_URShift_reg_0",
  /*  789 */  "AndI_reg_RShift_reg",
  /*  790 */  "AndI_reg_RShift_reg_0",
  /*  791 */  "AndL_reg_RShift_reg",
  /*  792 */  "AndL_reg_RShift_reg_0",
  /*  793 */  "AndI_reg_LShift_reg",
  /*  794 */  "AndI_reg_LShift_reg_0",
  /*  795 */  "AndL_reg_LShift_reg",
  /*  796 */  "AndL_reg_LShift_reg_0",
  /*  797 */  "XorI_reg_URShift_reg",
  /*  798 */  "XorI_reg_URShift_reg_0",
  /*  799 */  "XorL_reg_URShift_reg",
  /*  800 */  "XorL_reg_URShift_reg_0",
  /*  801 */  "XorI_reg_RShift_reg",
  /*  802 */  "XorI_reg_RShift_reg_0",
  /*  803 */  "XorL_reg_RShift_reg",
  /*  804 */  "XorL_reg_RShift_reg_0",
  /*  805 */  "XorI_reg_LShift_reg",
  /*  806 */  "XorI_reg_LShift_reg_0",
  /*  807 */  "XorL_reg_LShift_reg",
  /*  808 */  "XorL_reg_LShift_reg_0",
  /*  809 */  "OrI_reg_URShift_reg",
  /*  810 */  "OrI_reg_URShift_reg_0",
  /*  811 */  "OrL_reg_URShift_reg",
  /*  812 */  "OrL_reg_URShift_reg_0",
  /*  813 */  "OrI_reg_RShift_reg",
  /*  814 */  "OrI_reg_RShift_reg_0",
  /*  815 */  "OrL_reg_RShift_reg",
  /*  816 */  "OrL_reg_RShift_reg_0",
  /*  817 */  "OrI_reg_LShift_reg",
  /*  818 */  "OrI_reg_LShift_reg_0",
  /*  819 */  "OrL_reg_LShift_reg",
  /*  820 */  "OrL_reg_LShift_reg_0",
  /*  821 */  "AddI_reg_URShift_reg",
  /*  822 */  "AddI_reg_URShift_reg_0",
  /*  823 */  "AddL_reg_URShift_reg",
  /*  824 */  "AddL_reg_URShift_reg_0",
  /*  825 */  "AddI_reg_RShift_reg",
  /*  826 */  "AddI_reg_RShift_reg_0",
  /*  827 */  "AddL_reg_RShift_reg",
  /*  828 */  "AddL_reg_RShift_reg_0",
  /*  829 */  "AddI_reg_LShift_reg",
  /*  830 */  "AddI_reg_LShift_reg_0",
  /*  831 */  "AddL_reg_LShift_reg",
  /*  832 */  "AddL_reg_LShift_reg_0",
  /*  833 */  "SubI_reg_URShift_reg",
  /*  834 */  "SubL_reg_URShift_reg",
  /*  835 */  "SubI_reg_RShift_reg",
  /*  836 */  "SubL_reg_RShift_reg",
  /*  837 */  "SubI_reg_LShift_reg",
  /*  838 */  "SubL_reg_LShift_reg",
  /*  839 */  "sbfmL",
  /*  840 */  "sbfmwI",
  /*  841 */  "ubfmL",
  /*  842 */  "ubfmwI",
  /*  843 */  "ubfxwI",
  /*  844 */  "ubfxL",
  /*  845 */  "ubfxIConvI2L",
  /*  846 */  "ubfizwI",
  /*  847 */  "ubfizL",
  /*  848 */  "ubfizwIConvI2L",
  /*  849 */  "ubfizLConvL2I",
  /*  850 */  "ubfizIConvI2L",
  /*  851 */  "ubfizLConvL2Ix",
  /*  852 */  "ubfizIConvI2LAndI",
  /*  853 */  "extrOrL",
  /*  854 */  "extrOrL_0",
  /*  855 */  "extrOrI",
  /*  856 */  "extrOrI_0",
  /*  857 */  "extrAddL",
  /*  858 */  "extrAddL_0",
  /*  859 */  "extrAddI",
  /*  860 */  "extrAddI_0",
  /*  861 */  "rolL_rReg",
  /*  862 */  "rolI_rReg",
  /*  863 */  "rolL_rReg_Var_C_64",
  /*  864 */  "rolL_rReg_Var_C_64_0",
  /*  865 */  "rolL_rReg_Var_C0",
  /*  866 */  "rolL_rReg_Var_C0_0",
  /*  867 */  "rolI_rReg_Var_C_32",
  /*  868 */  "rolI_rReg_Var_C_32_0",
  /*  869 */  "rolI_rReg_Var_C0",
  /*  870 */  "rolI_rReg_Var_C0_0",
  /*  871 */  "rorL_rReg",
  /*  872 */  "rorI_rReg",
  /*  873 */  "rorL_rReg_Var_C_64",
  /*  874 */  "rorL_rReg_Var_C_64_0",
  /*  875 */  "rorL_rReg_Var_C0",
  /*  876 */  "rorL_rReg_Var_C0_0",
  /*  877 */  "rorI_rReg_Var_C_32",
  /*  878 */  "rorI_rReg_Var_C_32_0",
  /*  879 */  "rorI_rReg_Var_C0",
  /*  880 */  "rorI_rReg_Var_C0_0",
  /*  881 */  "AddExtI",
  /*  882 */  "AddExtI_0",
  /*  883 */  "SubExtI",
  /*  884 */  "AddExtI_sxth",
  /*  885 */  "AddExtI_sxth_0",
  /*  886 */  "AddExtI_sxtb",
  /*  887 */  "AddExtI_sxtb_0",
  /*  888 */  "AddExtI_uxtb",
  /*  889 */  "AddExtI_uxtb_0",
  /*  890 */  "AddExtL_sxth",
  /*  891 */  "AddExtL_sxth_0",
  /*  892 */  "AddExtL_sxtw",
  /*  893 */  "AddExtL_sxtw_0",
  /*  894 */  "AddExtL_sxtb",
  /*  895 */  "AddExtL_sxtb_0",
  /*  896 */  "AddExtL_uxtb",
  /*  897 */  "AddExtL_uxtb_0",
  /*  898 */  "AddExtI_uxtb_and",
  /*  899 */  "AddExtI_uxtb_and_0",
  /*  900 */  "AddExtI_uxth_and",
  /*  901 */  "AddExtI_uxth_and_0",
  /*  902 */  "AddExtL_uxtb_and",
  /*  903 */  "AddExtL_uxtb_and_0",
  /*  904 */  "AddExtL_uxth_and",
  /*  905 */  "AddExtL_uxth_and_0",
  /*  906 */  "AddExtL_uxtw_and",
  /*  907 */  "AddExtL_uxtw_and_0",
  /*  908 */  "SubExtI_uxtb_and",
  /*  909 */  "SubExtI_uxth_and",
  /*  910 */  "SubExtL_uxtb_and",
  /*  911 */  "SubExtL_uxth_and",
  /*  912 */  "SubExtL_uxtw_and",
  /*  913 */  "AddExtL_sxtb_shift",
  /*  914 */  "AddExtL_sxtb_shift_0",
  /*  915 */  "AddExtL_sxth_shift",
  /*  916 */  "AddExtL_sxth_shift_0",
  /*  917 */  "AddExtL_sxtw_shift",
  /*  918 */  "AddExtL_sxtw_shift_0",
  /*  919 */  "SubExtL_sxtb_shift",
  /*  920 */  "SubExtL_sxth_shift",
  /*  921 */  "SubExtL_sxtw_shift",
  /*  922 */  "AddExtI_sxtb_shift",
  /*  923 */  "AddExtI_sxtb_shift_0",
  /*  924 */  "AddExtI_sxth_shift",
  /*  925 */  "AddExtI_sxth_shift_0",
  /*  926 */  "SubExtI_sxtb_shift",
  /*  927 */  "SubExtI_sxth_shift",
  /*  928 */  "AddExtI_shift",
  /*  929 */  "AddExtI_shift_0",
  /*  930 */  "SubExtI_shift",
  /*  931 */  "AddExtL_uxtb_and_shift",
  /*  932 */  "AddExtL_uxtb_and_shift_0",
  /*  933 */  "AddExtL_uxth_and_shift",
  /*  934 */  "AddExtL_uxth_and_shift_0",
  /*  935 */  "AddExtL_uxtw_and_shift",
  /*  936 */  "AddExtL_uxtw_and_shift_0",
  /*  937 */  "SubExtL_uxtb_and_shift",
  /*  938 */  "SubExtL_uxth_and_shift",
  /*  939 */  "SubExtL_uxtw_and_shift",
  /*  940 */  "AddExtI_uxtb_and_shift",
  /*  941 */  "AddExtI_uxtb_and_shift_0",
  /*  942 */  "AddExtI_uxth_and_shift",
  /*  943 */  "AddExtI_uxth_and_shift_0",
  /*  944 */  "SubExtI_uxtb_and_shift",
  /*  945 */  "SubExtI_uxth_and_shift",
  /*  946 */  "addF_reg_reg",
  /*  947 */  "addD_reg_reg",
  /*  948 */  "subF_reg_reg",
  /*  949 */  "subD_reg_reg",
  /*  950 */  "mulF_reg_reg",
  /*  951 */  "mulD_reg_reg",
  /*  952 */  "maddF_reg_reg",
  /*  953 */  "maddD_reg_reg",
  /*  954 */  "msubF_reg_reg",
  /*  955 */  "msubF_reg_reg_0",
  /*  956 */  "msubD_reg_reg",
  /*  957 */  "msubD_reg_reg_0",
  /*  958 */  "mnaddF_reg_reg",
  /*  959 */  "mnaddF_reg_reg_0",
  /*  960 */  "mnaddD_reg_reg",
  /*  961 */  "mnaddD_reg_reg_0",
  /*  962 */  "mnsubF_reg_reg",
  /*  963 */  "mnsubD_reg_reg",
  /*  964 */  "maxF_reg_reg",
  /*  965 */  "minF_reg_reg",
  /*  966 */  "maxD_reg_reg",
  /*  967 */  "minD_reg_reg",
  /*  968 */  "divF_reg_reg",
  /*  969 */  "divD_reg_reg",
  /*  970 */  "absI_reg",
  /*  971 */  "absL_reg",
  /*  972 */  "sqrtD_reg",
  /*  973 */  "sqrtF_reg",
  /*  974 */  "copySignD_reg",
  /*  975 */  "copySignF_reg",
  /*  976 */  "signumD_reg",
  /*  977 */  "signumF_reg",
  /*  978 */  "andI_reg_reg",
  /*  979 */  "andI_reg_imm",
  /*  980 */  "orI_reg_reg",
  /*  981 */  "orI_reg_imm",
  /*  982 */  "xorI_reg_reg",
  /*  983 */  "xorI_reg_imm",
  /*  984 */  "andL_reg_reg",
  /*  985 */  "andL_reg_imm",
  /*  986 */  "orL_reg_reg",
  /*  987 */  "orL_reg_imm",
  /*  988 */  "xorL_reg_reg",
  /*  989 */  "xorL_reg_imm",
  /*  990 */  "convI2L_reg_reg",
  /*  991 */  "convUI2L_reg_reg",
  /*  992 */  "convL2I_reg",
  /*  993 */  "convI2B",
  /*  994 */  "convP2B",
  /*  995 */  "convD2F_reg",
  /*  996 */  "convF2D_reg",
  /*  997 */  "convF2I_reg_reg",
  /*  998 */  "convF2L_reg_reg",
  /*  999 */  "convI2F_reg_reg",
  /* 1000 */  "convL2F_reg_reg",
  /* 1001 */  "convD2I_reg_reg",
  /* 1002 */  "convD2L_reg_reg",
  /* 1003 */  "convI2D_reg_reg",
  /* 1004 */  "convL2D_reg_reg",
  /* 1005 */  "MoveF2I_reg_stack",
  /* 1006 */  "MoveI2F_reg_stack",
  /* 1007 */  "MoveD2L_reg_stack",
  /* 1008 */  "MoveL2D_reg_stack",
  /* 1009 */  "clearArray_reg_reg",
  /* 1010 */  "clearArray_imm_reg",
  /* 1011 */  "overflowMulI_reg_branch",
  /* 1012 */  "overflowMulL_reg_branch",
  /* 1013 */  "compF3_reg_reg",
  /* 1014 */  "compD3_reg_reg",
  /* 1015 */  "compF3_reg_immF0",
  /* 1016 */  "compD3_reg_immD0",
  /* 1017 */  "cmpLTMask_reg_reg",
  /* 1018 */  "cmpLTMask_reg_zero",
  /* 1019 */  "cmovI_reg_reg_lt",
  /* 1020 */  "minI_rReg",
  /* 1021 */  "cmovI_reg_reg_gt",
  /* 1022 */  "maxI_rReg",
  /* 1023 */  "branch",
  /* 1024 */  "branchCon",
  /* 1025 */  "branchConU",
  /* 1026 */  "cmpI_imm0_branch",
  /* 1027 */  "cmpL_imm0_branch",
  /* 1028 */  "cmpP_imm0_branch",
  /* 1029 */  "cmpN_imm0_branch",
  /* 1030 */  "cmpP_narrowOop_imm0_branch",
  /* 1031 */  "cmpUI_imm0_branch",
  /* 1032 */  "cmpUL_imm0_branch",
  /* 1033 */  "cmpL_branch_sign",
  /* 1034 */  "cmpI_branch_sign",
  /* 1035 */  "cmpL_branch_bit",
  /* 1036 */  "cmpI_branch_bit",
  /* 1037 */  "far_cmpL_branch_sign",
  /* 1038 */  "far_cmpI_branch_sign",
  /* 1039 */  "far_cmpL_branch_bit",
  /* 1040 */  "far_cmpI_branch_bit",
  /* 1041 */  "branchLoopEnd",
  /* 1042 */  "branchLoopEndU",
  /* 1043 */  "safePoint",
  /* 1044 */  "CallStaticJavaDirect",
  /* 1045 */  "CallDynamicJavaDirect",
  /* 1046 */  "CallRuntimeDirect",
  /* 1047 */  "CallLeafDirect",
  /* 1048 */  "CallLeafNoFPDirect",
  /* 1049 */  "TailCalljmpInd",
  /* 1050 */  "TailjmpInd",
  /* 1051 */  "CreateException",
  /* 1052 */  "RethrowException",
  /* 1053 */  "Ret",
  /* 1054 */  "ShouldNotReachHere",
  /* 1055 */  "partialSubtypeCheck",
  /* 1056 */  "string_compareU",
  /* 1057 */  "string_compareL",
  /* 1058 */  "string_compareUL",
  /* 1059 */  "string_compareLU",
  /* 1060 */  "string_indexofUU",
  /* 1061 */  "string_indexofLL",
  /* 1062 */  "string_indexofUL",
  /* 1063 */  "string_indexof_conUU",
  /* 1064 */  "string_indexof_conLL",
  /* 1065 */  "string_indexof_conUL",
  /* 1066 */  "string_indexofU_char",
  /* 1067 */  "string_equalsL",
  /* 1068 */  "string_equalsU",
  /* 1069 */  "array_equalsB",
  /* 1070 */  "array_equalsC",
  /* 1071 */  "has_negatives",
  /* 1072 */  "string_compress",
  /* 1073 */  "string_inflate",
  /* 1074 */  "encode_iso_array",
  /* 1075 */  "loadV4",
  /* 1076 */  "loadV8",
  /* 1077 */  "loadV16",
  /* 1078 */  "storeV4",
  /* 1079 */  "storeV8",
  /* 1080 */  "storeV16",
  /* 1081 */  "replicate8B",
  /* 1082 */  "replicate16B",
  /* 1083 */  "replicate8B_imm",
  /* 1084 */  "replicate16B_imm",
  /* 1085 */  "replicate4S",
  /* 1086 */  "replicate8S",
  /* 1087 */  "replicate4S_imm",
  /* 1088 */  "replicate8S_imm",
  /* 1089 */  "replicate2I",
  /* 1090 */  "replicate4I",
  /* 1091 */  "replicate2I_imm",
  /* 1092 */  "replicate4I_imm",
  /* 1093 */  "replicate2L",
  /* 1094 */  "replicate2L_zero",
  /* 1095 */  "replicate2F",
  /* 1096 */  "replicate4F",
  /* 1097 */  "replicate2D",
  /* 1098 */  "reduce_add2I",
  /* 1099 */  "reduce_add4I",
  /* 1100 */  "reduce_mul2I",
  /* 1101 */  "reduce_mul4I",
  /* 1102 */  "reduce_add2F",
  /* 1103 */  "reduce_add4F",
  /* 1104 */  "reduce_mul2F",
  /* 1105 */  "reduce_mul4F",
  /* 1106 */  "reduce_add2D",
  /* 1107 */  "reduce_mul2D",
  /* 1108 */  "reduce_max2F",
  /* 1109 */  "reduce_max4F",
  /* 1110 */  "reduce_max2D",
  /* 1111 */  "reduce_min2F",
  /* 1112 */  "reduce_min4F",
  /* 1113 */  "reduce_min2D",
  /* 1114 */  "vadd8B",
  /* 1115 */  "vadd16B",
  /* 1116 */  "vadd4S",
  /* 1117 */  "vadd8S",
  /* 1118 */  "vadd2I",
  /* 1119 */  "vadd4I",
  /* 1120 */  "vadd2L",
  /* 1121 */  "vadd2F",
  /* 1122 */  "vadd4F",
  /* 1123 */  "vadd2D",
  /* 1124 */  "vsub8B",
  /* 1125 */  "vsub16B",
  /* 1126 */  "vsub4S",
  /* 1127 */  "vsub8S",
  /* 1128 */  "vsub2I",
  /* 1129 */  "vsub4I",
  /* 1130 */  "vsub2L",
  /* 1131 */  "vsub2F",
  /* 1132 */  "vsub4F",
  /* 1133 */  "vsub2D",
  /* 1134 */  "vmul8B",
  /* 1135 */  "vmul16B",
  /* 1136 */  "vmul4S",
  /* 1137 */  "vmul8S",
  /* 1138 */  "vmul2I",
  /* 1139 */  "vmul4I",
  /* 1140 */  "vmul2F",
  /* 1141 */  "vmul4F",
  /* 1142 */  "vmul2D",
  /* 1143 */  "vmla4S",
  /* 1144 */  "vmla4S_0",
  /* 1145 */  "vmla8S",
  /* 1146 */  "vmla8S_0",
  /* 1147 */  "vmla2I",
  /* 1148 */  "vmla2I_0",
  /* 1149 */  "vmla4I",
  /* 1150 */  "vmla4I_0",
  /* 1151 */  "vmla2F",
  /* 1152 */  "vmla4F",
  /* 1153 */  "vmla2D",
  /* 1154 */  "vmls4S",
  /* 1155 */  "vmls8S",
  /* 1156 */  "vmls2I",
  /* 1157 */  "vmls4I",
  /* 1158 */  "vmls2F",
  /* 1159 */  "vmls2F_0",
  /* 1160 */  "vmls4F",
  /* 1161 */  "vmls4F_0",
  /* 1162 */  "vmls2D",
  /* 1163 */  "vmls2D_0",
  /* 1164 */  "vdiv2F",
  /* 1165 */  "vdiv4F",
  /* 1166 */  "vdiv2D",
  /* 1167 */  "vand8B",
  /* 1168 */  "vand16B",
  /* 1169 */  "vor8B",
  /* 1170 */  "vor16B",
  /* 1171 */  "vxor8B",
  /* 1172 */  "vxor16B",
  /* 1173 */  "vsll8B",
  /* 1174 */  "vsll16B",
  /* 1175 */  "vsra8B",
  /* 1176 */  "vsra16B",
  /* 1177 */  "vsrl8B",
  /* 1178 */  "vsrl16B",
  /* 1179 */  "vsll8B_imm",
  /* 1180 */  "vsll16B_imm",
  /* 1181 */  "vsra8B_imm",
  /* 1182 */  "vsra16B_imm",
  /* 1183 */  "vsrl8B_imm",
  /* 1184 */  "vsrl16B_imm",
  /* 1185 */  "vsll4S",
  /* 1186 */  "vsll8S",
  /* 1187 */  "vsra4S",
  /* 1188 */  "vsra8S",
  /* 1189 */  "vsrl4S",
  /* 1190 */  "vsrl8S",
  /* 1191 */  "vsll4S_imm",
  /* 1192 */  "vsll8S_imm",
  /* 1193 */  "vsra4S_imm",
  /* 1194 */  "vsra8S_imm",
  /* 1195 */  "vsrl4S_imm",
  /* 1196 */  "vsrl8S_imm",
  /* 1197 */  "vsll2I",
  /* 1198 */  "vsll4I",
  /* 1199 */  "vsra2I",
  /* 1200 */  "vsra4I",
  /* 1201 */  "vsrl2I",
  /* 1202 */  "vsrl4I",
  /* 1203 */  "vsll2I_imm",
  /* 1204 */  "vsll4I_imm",
  /* 1205 */  "vsra2I_imm",
  /* 1206 */  "vsra4I_imm",
  /* 1207 */  "vsrl2I_imm",
  /* 1208 */  "vsrl4I_imm",
  /* 1209 */  "vsll2L",
  /* 1210 */  "vsra2L",
  /* 1211 */  "vsrl2L",
  /* 1212 */  "vsll2L_imm",
  /* 1213 */  "vsra2L_imm",
  /* 1214 */  "vsrl2L_imm",
  /* 1215 */  "vmax2F",
  /* 1216 */  "vmax4F",
  /* 1217 */  "vmax2D",
  /* 1218 */  "vmin2F",
  /* 1219 */  "vmin4F",
  /* 1220 */  "vmin2D",
  /* 1221 */  "zLoadP",
  /* 1222 */  "zLoadWeakP",
  /* 1223 */  "zLoadPVolatile",
  /* 1224 */  "zCompareAndSwapP",
  /* 1225 */  "zCompareAndSwapP_0",
  /* 1226 */  "zCompareAndSwapPAcq",
  /* 1227 */  "zCompareAndSwapPAcq_0",
  /* 1228 */  "zCompareAndExchangeP",
  /* 1229 */  "zCompareAndExchangePAcq",
  /* 1230 */  "zGetAndSetP",
  /* 1231 */  "zGetAndSetPAcq",
  /* 1232 */  "loadV",
  /* 1233 */  "storeV",
  /* 1234 */  "vaddB",
  /* 1235 */  "vaddS",
  /* 1236 */  "vaddI",
  /* 1237 */  "vaddL",
  /* 1238 */  "vaddF",
  /* 1239 */  "vaddD",
  /* 1240 */  "vand",
  /* 1241 */  "vor",
  /* 1242 */  "vxor",
  /* 1243 */  "vdivF",
  /* 1244 */  "vdivD",
  /* 1245 */  "vfmlaF",
  /* 1246 */  "vfmlaD",
  /* 1247 */  "vfmlsF",
  /* 1248 */  "vfmlsF_0",
  /* 1249 */  "vfmlsD",
  /* 1250 */  "vfmlsD_0",
  /* 1251 */  "vfnmlaF",
  /* 1252 */  "vfnmlaF_0",
  /* 1253 */  "vfnmlaD",
  /* 1254 */  "vfnmlaD_0",
  /* 1255 */  "vfnmlsF",
  /* 1256 */  "vfnmlsD",
  /* 1257 */  "vmlaS",
  /* 1258 */  "vmlaS_0",
  /* 1259 */  "vmlaI",
  /* 1260 */  "vmlaI_0",
  /* 1261 */  "vmlaL",
  /* 1262 */  "vmlaL_0",
  /* 1263 */  "vmlsS",
  /* 1264 */  "vmlsI",
  /* 1265 */  "vmlsL",
  /* 1266 */  "vmulS",
  /* 1267 */  "vmulI",
  /* 1268 */  "vmulL",
  /* 1269 */  "vmulF",
  /* 1270 */  "vmulD",
  /* 1271 */  "reduce_addI",
  /* 1272 */  "reduce_addL",
  /* 1273 */  "reduce_addF",
  /* 1274 */  "reduce_addD",
  /* 1275 */  "replicateB",
  /* 1276 */  "replicateS",
  /* 1277 */  "replicateI",
  /* 1278 */  "replicateL",
  /* 1279 */  "replicateB_imm8",
  /* 1280 */  "replicateS_imm8",
  /* 1281 */  "replicateI_imm8",
  /* 1282 */  "replicateL_imm8",
  /* 1283 */  "replicateF",
  /* 1284 */  "replicateD",
  /* 1285 */  "vasrB",
  /* 1286 */  "vasrS",
  /* 1287 */  "vasrI",
  /* 1288 */  "vasrL",
  /* 1289 */  "vlslB",
  /* 1290 */  "vlslS",
  /* 1291 */  "vlslI",
  /* 1292 */  "vlslL",
  /* 1293 */  "vlsrB",
  /* 1294 */  "vlsrS",
  /* 1295 */  "vlsrI",
  /* 1296 */  "vlsrL",
  /* 1297 */  "vasrB_imm",
  /* 1298 */  "vasrS_imm",
  /* 1299 */  "vasrI_imm",
  /* 1300 */  "vasrL_imm",
  /* 1301 */  "vlsrB_imm",
  /* 1302 */  "vlsrS_imm",
  /* 1303 */  "vlsrI_imm",
  /* 1304 */  "vlsrL_imm",
  /* 1305 */  "vlslB_imm",
  /* 1306 */  "vlslS_imm",
  /* 1307 */  "vlslI_imm",
  /* 1308 */  "vlslL_imm",
  /* 1309 */  "vsubB",
  /* 1310 */  "vsubS",
  /* 1311 */  "vsubI",
  /* 1312 */  "vsubL",
  /* 1313 */  "vsubF",
  /* 1314 */  "vsubD",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  true,
  /*   69 */  true,
  /*   70 */  true,
  /*   71 */  true,
  /*   72 */  true,
  /*   73 */  true,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  true,
  /*  173 */  true,
  /*  174 */  true,
  /*  175 */  true,
  /*  176 */  true,
  /*  177 */  false,
  /*  178 */  true,
  /*  179 */  true,
  /*  180 */  false,
  /*  181 */  false,
  // last operand
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  // last operand class
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  // last internally defined operand
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  /* 1227 */  false,
  /* 1228 */  false,
  /* 1229 */  false,
  /* 1230 */  false,
  /* 1231 */  false,
  /* 1232 */  false,
  /* 1233 */  false,
  /* 1234 */  false,
  /* 1235 */  false,
  /* 1236 */  false,
  /* 1237 */  false,
  /* 1238 */  false,
  /* 1239 */  false,
  /* 1240 */  false,
  /* 1241 */  false,
  /* 1242 */  false,
  /* 1243 */  false,
  /* 1244 */  false,
  /* 1245 */  false,
  /* 1246 */  false,
  /* 1247 */  false,
  /* 1248 */  false,
  /* 1249 */  false,
  /* 1250 */  false,
  /* 1251 */  false,
  /* 1252 */  false,
  /* 1253 */  false,
  /* 1254 */  false,
  /* 1255 */  false,
  /* 1256 */  false,
  /* 1257 */  false,
  /* 1258 */  false,
  /* 1259 */  false,
  /* 1260 */  false,
  /* 1261 */  false,
  /* 1262 */  false,
  /* 1263 */  false,
  /* 1264 */  false,
  /* 1265 */  false,
  /* 1266 */  false,
  /* 1267 */  false,
  /* 1268 */  false,
  /* 1269 */  false,
  /* 1270 */  false,
  /* 1271 */  false,
  /* 1272 */  false,
  /* 1273 */  false,
  /* 1274 */  false,
  /* 1275 */  false,
  /* 1276 */  false,
  /* 1277 */  false,
  /* 1278 */  false,
  /* 1279 */  false,
  /* 1280 */  false,
  /* 1281 */  false,
  /* 1282 */  false,
  /* 1283 */  false,
  /* 1284 */  false,
  /* 1285 */  false,
  /* 1286 */  false,
  /* 1287 */  false,
  /* 1288 */  false,
  /* 1289 */  false,
  /* 1290 */  false,
  /* 1291 */  false,
  /* 1292 */  false,
  /* 1293 */  false,
  /* 1294 */  false,
  /* 1295 */  false,
  /* 1296 */  false,
  /* 1297 */  false,
  /* 1298 */  false,
  /* 1299 */  false,
  /* 1300 */  false,
  /* 1301 */  false,
  /* 1302 */  false,
  /* 1303 */  false,
  /* 1304 */  false,
  /* 1305 */  false,
  /* 1306 */  false,
  /* 1307 */  false,
  /* 1308 */  false,
  /* 1309 */  false,
  /* 1310 */  false,
  /* 1311 */  false,
  /* 1312 */  false,
  /* 1313 */  false,
  /* 1314 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  1, // Bool: 34
  0, // BoxLock: 35
  0, // ReverseBytesI: 36
  0, // ReverseBytesL: 37
  0, // ReverseBytesUS: 38
  0, // ReverseBytesS: 39
  0, // CProj: 40
  0, // CallDynamicJava: 41
  0, // CallJava: 42
  0, // CallLeaf: 43
  0, // CallLeafNoFP: 44
  0, // CallRuntime: 45
  0, // CallStaticJava: 46
  0, // CastII: 47
  0, // CastLL: 48
  0, // CastX2P: 49
  0, // CastP2X: 50
  0, // CastPP: 51
  0, // Catch: 52
  0, // CatchProj: 53
  0, // CheckCastPP: 54
  0, // ClearArray: 55
  0, // ConstraintCast: 56
  0, // CMoveD: 57
  0, // CMoveVD: 58
  0, // CMoveF: 59
  0, // CMoveVF: 60
  0, // CMoveI: 61
  0, // CMoveL: 62
  0, // CMoveP: 63
  0, // CMoveN: 64
  1, // CmpN: 65
  1, // CmpD: 66
  0, // CmpD3: 67
  1, // CmpF: 68
  0, // CmpF3: 69
  1, // CmpI: 70
  1, // CmpL: 71
  0, // CmpL3: 72
  0, // CmpLTMask: 73
  1, // CmpP: 74
  1, // CmpU: 75
  1, // CmpUL: 76
  0, // CompareAndSwapB: 77
  0, // CompareAndSwapS: 78
  0, // CompareAndSwapI: 79
  0, // CompareAndSwapL: 80
  0, // CompareAndSwapP: 81
  0, // CompareAndSwapN: 82
  0, // WeakCompareAndSwapB: 83
  0, // WeakCompareAndSwapS: 84
  0, // WeakCompareAndSwapI: 85
  0, // WeakCompareAndSwapL: 86
  0, // WeakCompareAndSwapP: 87
  0, // WeakCompareAndSwapN: 88
  0, // CompareAndExchangeB: 89
  0, // CompareAndExchangeS: 90
  0, // CompareAndExchangeI: 91
  0, // CompareAndExchangeL: 92
  0, // CompareAndExchangeP: 93
  0, // CompareAndExchangeN: 94
  0, // GetAndAddB: 95
  0, // GetAndAddS: 96
  0, // GetAndAddI: 97
  0, // GetAndAddL: 98
  0, // GetAndSetB: 99
  0, // GetAndSetS: 100
  0, // GetAndSetI: 101
  0, // GetAndSetL: 102
  0, // GetAndSetP: 103
  0, // GetAndSetN: 104
  0, // Con: 105
  0, // ConN: 106
  0, // ConNKlass: 107
  0, // ConD: 108
  0, // ConF: 109
  0, // ConI: 110
  0, // ConL: 111
  0, // ConP: 112
  0, // Conv2B: 113
  0, // ConvD2F: 114
  0, // ConvD2I: 115
  0, // ConvD2L: 116
  0, // ConvF2D: 117
  0, // ConvF2I: 118
  0, // ConvF2L: 119
  0, // ConvI2D: 120
  0, // ConvI2F: 121
  0, // ConvI2L: 122
  0, // ConvL2D: 123
  0, // ConvL2F: 124
  0, // ConvL2I: 125
  0, // CountedLoop: 126
  0, // CountedLoopEnd: 127
  0, // OuterStripMinedLoop: 128
  0, // OuterStripMinedLoopEnd: 129
  0, // CountLeadingZerosI: 130
  0, // CountLeadingZerosL: 131
  0, // CountTrailingZerosI: 132
  0, // CountTrailingZerosL: 133
  0, // CreateEx: 134
  0, // DecodeN: 135
  0, // DecodeNKlass: 136
  0, // DivD: 137
  0, // DivF: 138
  0, // DivI: 139
  0, // DivL: 140
  0, // DivMod: 141
  0, // DivModI: 142
  0, // DivModL: 143
  0, // EncodeISOArray: 144
  0, // EncodeP: 145
  0, // EncodePKlass: 146
  1, // FastLock: 147
  1, // FastUnlock: 148
  0, // FmaD: 149
  0, // FmaF: 150
  0, // Goto: 151
  0, // Halt: 152
  0, // HasNegatives: 153
  0, // If: 154
  0, // RangeCheck: 155
  0, // IfFalse: 156
  0, // IfTrue: 157
  0, // Initialize: 158
  0, // JProj: 159
  0, // Jump: 160
  0, // JumpProj: 161
  0, // LShiftI: 162
  0, // LShiftL: 163
  0, // LoadB: 164
  0, // LoadUB: 165
  0, // LoadUS: 166
  0, // LoadD: 167
  0, // LoadD_unaligned: 168
  0, // LoadF: 169
  0, // LoadI: 170
  0, // LoadKlass: 171
  0, // LoadNKlass: 172
  0, // LoadL: 173
  0, // LoadL_unaligned: 174
  0, // LoadPLocked: 175
  0, // LoadP: 176
  0, // LoadN: 177
  0, // LoadRange: 178
  0, // LoadS: 179
  0, // Lock: 180
  0, // Loop: 181
  0, // LoopLimit: 182
  0, // Mach: 183
  0, // MachNullCheck: 184
  0, // MachProj: 185
  0, // MaxD: 186
  0, // MaxF: 187
  0, // MaxI: 188
  0, // MaxL: 189
  0, // MemBarAcquire: 190
  0, // LoadFence: 191
  0, // SetVectMaskI: 192
  0, // MemBarAcquireLock: 193
  0, // MemBarCPUOrder: 194
  0, // MemBarRelease: 195
  0, // StoreFence: 196
  0, // MemBarReleaseLock: 197
  0, // MemBarVolatile: 198
  0, // MemBarStoreStore: 199
  0, // MergeMem: 200
  0, // MinD: 201
  0, // MinF: 202
  0, // MinI: 203
  0, // MinL: 204
  0, // ModD: 205
  0, // ModF: 206
  0, // ModI: 207
  0, // ModL: 208
  0, // MoveI2F: 209
  0, // MoveF2I: 210
  0, // MoveL2D: 211
  0, // MoveD2L: 212
  0, // MulD: 213
  0, // MulF: 214
  0, // MulHiL: 215
  0, // MulI: 216
  0, // MulL: 217
  0, // Multi: 218
  0, // NegD: 219
  0, // NegF: 220
  0, // NeverBranch: 221
  0, // OnSpinWait: 222
  0, // Opaque1: 223
  0, // OpaqueLoopInit: 224
  0, // OpaqueLoopStride: 225
  0, // Opaque2: 226
  0, // Opaque3: 227
  0, // Opaque4: 228
  0, // ProfileBoolean: 229
  0, // OrI: 230
  0, // OrL: 231
  1, // OverflowAddI: 232
  1, // OverflowSubI: 233
  1, // OverflowMulI: 234
  1, // OverflowAddL: 235
  1, // OverflowSubL: 236
  1, // OverflowMulL: 237
  0, // PCTable: 238
  0, // Parm: 239
  0, // PartialSubtypeCheck: 240
  0, // Phi: 241
  0, // PopCountI: 242
  0, // PopCountL: 243
  0, // PopCountVI: 244
  0, // PrefetchAllocation: 245
  0, // Proj: 246
  0, // RShiftI: 247
  0, // RShiftL: 248
  0, // Region: 249
  0, // Rethrow: 250
  0, // Return: 251
  0, // Root: 252
  0, // RoundDouble: 253
  0, // RoundDoubleMode: 254
  0, // RoundDoubleModeV: 255
  0, // RoundFloat: 256
  0, // SafePoint: 257
  0, // SafePointScalarObject: 258
  0, // SCMemProj: 259
  0, // CopySignD: 260
  0, // CopySignF: 261
  0, // SignumD: 262
  0, // SignumF: 263
  0, // SqrtD: 264
  0, // SqrtF: 265
  0, // Start: 266
  0, // StartOSR: 267
  0, // StoreB: 268
  0, // StoreC: 269
  0, // StoreCM: 270
  0, // StorePConditional: 271
  0, // StoreIConditional: 272
  0, // StoreLConditional: 273
  0, // StoreD: 274
  0, // StoreF: 275
  0, // StoreI: 276
  0, // StoreL: 277
  0, // StoreP: 278
  0, // StoreN: 279
  0, // StoreNKlass: 280
  0, // StrComp: 281
  0, // StrCompressedCopy: 282
  0, // StrEquals: 283
  0, // StrIndexOf: 284
  0, // StrIndexOfChar: 285
  0, // StrInflatedCopy: 286
  0, // SubD: 287
  0, // SubF: 288
  0, // SubI: 289
  0, // SubL: 290
  0, // TailCall: 291
  0, // TailJump: 292
  0, // ThreadLocal: 293
  0, // Unlock: 294
  0, // URShiftI: 295
  0, // URShiftL: 296
  0, // XorI: 297
  0, // XorL: 298
  0, // Vector: 299
  0, // AddVB: 300
  0, // AddVS: 301
  0, // AddVI: 302
  0, // AddReductionVI: 303
  0, // AddVL: 304
  0, // AddReductionVL: 305
  0, // AddVF: 306
  0, // AddReductionVF: 307
  0, // AddVD: 308
  0, // AddReductionVD: 309
  0, // SubVB: 310
  0, // SubVS: 311
  0, // SubVI: 312
  0, // SubVL: 313
  0, // SubVF: 314
  0, // SubVD: 315
  0, // MulVB: 316
  0, // MulVS: 317
  0, // MulVI: 318
  0, // MulReductionVI: 319
  0, // MulVL: 320
  0, // MulReductionVL: 321
  0, // MulVF: 322
  0, // MulReductionVF: 323
  0, // MulVD: 324
  0, // MulReductionVD: 325
  0, // FmaVD: 326
  0, // FmaVF: 327
  0, // DivVF: 328
  0, // DivVD: 329
  0, // AbsVB: 330
  0, // AbsVS: 331
  0, // AbsVI: 332
  0, // AbsVL: 333
  0, // AbsVF: 334
  0, // AbsVD: 335
  0, // NegVF: 336
  0, // NegVD: 337
  0, // SqrtVD: 338
  0, // SqrtVF: 339
  0, // LShiftCntV: 340
  0, // RShiftCntV: 341
  0, // LShiftVB: 342
  0, // LShiftVS: 343
  0, // LShiftVI: 344
  0, // LShiftVL: 345
  0, // RShiftVB: 346
  0, // RShiftVS: 347
  0, // RShiftVI: 348
  0, // RShiftVL: 349
  0, // URShiftVB: 350
  0, // URShiftVS: 351
  0, // URShiftVI: 352
  0, // URShiftVL: 353
  0, // AndV: 354
  0, // OrV: 355
  0, // XorV: 356
  0, // MinV: 357
  0, // MaxV: 358
  0, // MinReductionV: 359
  0, // MaxReductionV: 360
  0, // LoadVector: 361
  0, // StoreVector: 362
  0, // Pack: 363
  0, // PackB: 364
  0, // PackS: 365
  0, // PackI: 366
  0, // PackL: 367
  0, // PackF: 368
  0, // PackD: 369
  0, // Pack2L: 370
  0, // Pack2D: 371
  0, // ReplicateB: 372
  0, // ReplicateS: 373
  0, // ReplicateI: 374
  0, // ReplicateL: 375
  0, // ReplicateF: 376
  0, // ReplicateD: 377
  0, // Extract: 378
  0, // ExtractB: 379
  0, // ExtractUB: 380
  0, // ExtractC: 381
  0, // ExtractS: 382
  0, // ExtractI: 383
  0, // ExtractL: 384
  0, // ExtractF: 385
  0, // ExtractD: 386
  0, // Digit: 387
  0, // LowerCase: 388
  0, // UpperCase: 389
  0 // no trailing comma // Whitespace: 390
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R18",
  "R18_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V16_L",
  "V16_M",
  "V16_N",
  "V16_O",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V17_L",
  "V17_M",
  "V17_N",
  "V17_O",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V18_L",
  "V18_M",
  "V18_N",
  "V18_O",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V19_L",
  "V19_M",
  "V19_N",
  "V19_O",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V20_L",
  "V20_M",
  "V20_N",
  "V20_O",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V21_L",
  "V21_M",
  "V21_N",
  "V21_O",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V22_L",
  "V22_M",
  "V22_N",
  "V22_O",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V23_L",
  "V23_M",
  "V23_N",
  "V23_O",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V24_L",
  "V24_M",
  "V24_N",
  "V24_O",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V25_L",
  "V25_M",
  "V25_N",
  "V25_O",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V26_L",
  "V26_M",
  "V26_N",
  "V26_O",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V27_L",
  "V27_M",
  "V27_N",
  "V27_O",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V28_L",
  "V28_M",
  "V28_N",
  "V28_O",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V29_L",
  "V29_M",
  "V29_N",
  "V29_O",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V30_L",
  "V30_M",
  "V30_N",
  "V30_O",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V31_L",
  "V31_M",
  "V31_N",
  "V31_O",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V0_L",
  "V0_M",
  "V0_N",
  "V0_O",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V1_L",
  "V1_M",
  "V1_N",
  "V1_O",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V2_L",
  "V2_M",
  "V2_N",
  "V2_O",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V3_L",
  "V3_M",
  "V3_N",
  "V3_O",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V4_L",
  "V4_M",
  "V4_N",
  "V4_O",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V5_L",
  "V5_M",
  "V5_N",
  "V5_O",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V6_L",
  "V6_M",
  "V6_N",
  "V6_O",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V7_L",
  "V7_M",
  "V7_N",
  "V7_O",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V8_L",
  "V8_M",
  "V8_N",
  "V8_O",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V9_L",
  "V9_M",
  "V9_N",
  "V9_O",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V10_L",
  "V10_M",
  "V10_N",
  "V10_O",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V11_L",
  "V11_M",
  "V11_N",
  "V11_O",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V12_L",
  "V12_M",
  "V12_N",
  "V12_O",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V13_L",
  "V13_M",
  "V13_N",
  "V13_O",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V14_L",
  "V14_M",
  "V14_N",
  "V14_O",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "V15_L",
  "V15_M",
  "V15_N",
  "V15_O",
  "P0",
  "P1",
  "P2",
  "P3",
  "P4",
  "P5",
  "P6",
  "P7",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r18_tls->as_VMReg()        ,
	r18_tls->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	r8->as_VMReg()         ,
	r8->as_VMReg()->next() ,
	r9->as_VMReg()         ,
	r9->as_VMReg()->next() ,
	v16->as_VMReg()          ,
	v16->as_VMReg()->next()  ,
	v16->as_VMReg()->next(2) ,
	v16->as_VMReg()->next(3) ,
	v16->as_VMReg()->next(4) ,
	v16->as_VMReg()->next(5) ,
	v16->as_VMReg()->next(6) ,
	v16->as_VMReg()->next(7) ,
	v17->as_VMReg()          ,
	v17->as_VMReg()->next()  ,
	v17->as_VMReg()->next(2) ,
	v17->as_VMReg()->next(3) ,
	v17->as_VMReg()->next(4) ,
	v17->as_VMReg()->next(5) ,
	v17->as_VMReg()->next(6) ,
	v17->as_VMReg()->next(7) ,
	v18->as_VMReg()          ,
	v18->as_VMReg()->next()  ,
	v18->as_VMReg()->next(2) ,
	v18->as_VMReg()->next(3) ,
	v18->as_VMReg()->next(4) ,
	v18->as_VMReg()->next(5) ,
	v18->as_VMReg()->next(6) ,
	v18->as_VMReg()->next(7) ,
	v19->as_VMReg()          ,
	v19->as_VMReg()->next()  ,
	v19->as_VMReg()->next(2) ,
	v19->as_VMReg()->next(3) ,
	v19->as_VMReg()->next(4) ,
	v19->as_VMReg()->next(5) ,
	v19->as_VMReg()->next(6) ,
	v19->as_VMReg()->next(7) ,
	v20->as_VMReg()          ,
	v20->as_VMReg()->next()  ,
	v20->as_VMReg()->next(2) ,
	v20->as_VMReg()->next(3) ,
	v20->as_VMReg()->next(4) ,
	v20->as_VMReg()->next(5) ,
	v20->as_VMReg()->next(6) ,
	v20->as_VMReg()->next(7) ,
	v21->as_VMReg()          ,
	v21->as_VMReg()->next()  ,
	v21->as_VMReg()->next(2) ,
	v21->as_VMReg()->next(3) ,
	v21->as_VMReg()->next(4) ,
	v21->as_VMReg()->next(5) ,
	v21->as_VMReg()->next(6) ,
	v21->as_VMReg()->next(7) ,
	v22->as_VMReg()          ,
	v22->as_VMReg()->next()  ,
	v22->as_VMReg()->next(2) ,
	v22->as_VMReg()->next(3) ,
	v22->as_VMReg()->next(4) ,
	v22->as_VMReg()->next(5) ,
	v22->as_VMReg()->next(6) ,
	v22->as_VMReg()->next(7) ,
	v23->as_VMReg()          ,
	v23->as_VMReg()->next()  ,
	v23->as_VMReg()->next(2) ,
	v23->as_VMReg()->next(3) ,
	v23->as_VMReg()->next(4) ,
	v23->as_VMReg()->next(5) ,
	v23->as_VMReg()->next(6) ,
	v23->as_VMReg()->next(7) ,
	v24->as_VMReg()          ,
	v24->as_VMReg()->next()  ,
	v24->as_VMReg()->next(2) ,
	v24->as_VMReg()->next(3) ,
	v24->as_VMReg()->next(4) ,
	v24->as_VMReg()->next(5) ,
	v24->as_VMReg()->next(6) ,
	v24->as_VMReg()->next(7) ,
	v25->as_VMReg()          ,
	v25->as_VMReg()->next()  ,
	v25->as_VMReg()->next(2) ,
	v25->as_VMReg()->next(3) ,
	v25->as_VMReg()->next(4) ,
	v25->as_VMReg()->next(5) ,
	v25->as_VMReg()->next(6) ,
	v25->as_VMReg()->next(7) ,
	v26->as_VMReg()          ,
	v26->as_VMReg()->next()  ,
	v26->as_VMReg()->next(2) ,
	v26->as_VMReg()->next(3) ,
	v26->as_VMReg()->next(4) ,
	v26->as_VMReg()->next(5) ,
	v26->as_VMReg()->next(6) ,
	v26->as_VMReg()->next(7) ,
	v27->as_VMReg()          ,
	v27->as_VMReg()->next()  ,
	v27->as_VMReg()->next(2) ,
	v27->as_VMReg()->next(3) ,
	v27->as_VMReg()->next(4) ,
	v27->as_VMReg()->next(5) ,
	v27->as_VMReg()->next(6) ,
	v27->as_VMReg()->next(7) ,
	v28->as_VMReg()          ,
	v28->as_VMReg()->next()  ,
	v28->as_VMReg()->next(2) ,
	v28->as_VMReg()->next(3) ,
	v28->as_VMReg()->next(4) ,
	v28->as_VMReg()->next(5) ,
	v28->as_VMReg()->next(6) ,
	v28->as_VMReg()->next(7) ,
	v29->as_VMReg()          ,
	v29->as_VMReg()->next()  ,
	v29->as_VMReg()->next(2) ,
	v29->as_VMReg()->next(3) ,
	v29->as_VMReg()->next(4) ,
	v29->as_VMReg()->next(5) ,
	v29->as_VMReg()->next(6) ,
	v29->as_VMReg()->next(7) ,
	v30->as_VMReg()          ,
	v30->as_VMReg()->next()  ,
	v30->as_VMReg()->next(2) ,
	v30->as_VMReg()->next(3) ,
	v30->as_VMReg()->next(4) ,
	v30->as_VMReg()->next(5) ,
	v30->as_VMReg()->next(6) ,
	v30->as_VMReg()->next(7) ,
	v31->as_VMReg()          ,
	v31->as_VMReg()->next()  ,
	v31->as_VMReg()->next(2) ,
	v31->as_VMReg()->next(3) ,
	v31->as_VMReg()->next(4) ,
	v31->as_VMReg()->next(5) ,
	v31->as_VMReg()->next(6) ,
	v31->as_VMReg()->next(7) ,
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v0->as_VMReg()->next(4) ,
	v0->as_VMReg()->next(5) ,
	v0->as_VMReg()->next(6) ,
	v0->as_VMReg()->next(7) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v1->as_VMReg()->next(4) ,
	v1->as_VMReg()->next(5) ,
	v1->as_VMReg()->next(6) ,
	v1->as_VMReg()->next(7) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v2->as_VMReg()->next(4) ,
	v2->as_VMReg()->next(5) ,
	v2->as_VMReg()->next(6) ,
	v2->as_VMReg()->next(7) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v3->as_VMReg()->next(4) ,
	v3->as_VMReg()->next(5) ,
	v3->as_VMReg()->next(6) ,
	v3->as_VMReg()->next(7) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v4->as_VMReg()->next(4) ,
	v4->as_VMReg()->next(5) ,
	v4->as_VMReg()->next(6) ,
	v4->as_VMReg()->next(7) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v5->as_VMReg()->next(4) ,
	v5->as_VMReg()->next(5) ,
	v5->as_VMReg()->next(6) ,
	v5->as_VMReg()->next(7) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v6->as_VMReg()->next(4) ,
	v6->as_VMReg()->next(5) ,
	v6->as_VMReg()->next(6) ,
	v6->as_VMReg()->next(7) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v7->as_VMReg()->next(4) ,
	v7->as_VMReg()->next(5) ,
	v7->as_VMReg()->next(6) ,
	v7->as_VMReg()->next(7) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v8->as_VMReg()->next(4) ,
	v8->as_VMReg()->next(5) ,
	v8->as_VMReg()->next(6) ,
	v8->as_VMReg()->next(7) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v9->as_VMReg()->next(4) ,
	v9->as_VMReg()->next(5) ,
	v9->as_VMReg()->next(6) ,
	v9->as_VMReg()->next(7) ,
	v10->as_VMReg()          ,
	v10->as_VMReg()->next()  ,
	v10->as_VMReg()->next(2) ,
	v10->as_VMReg()->next(3) ,
	v10->as_VMReg()->next(4) ,
	v10->as_VMReg()->next(5) ,
	v10->as_VMReg()->next(6) ,
	v10->as_VMReg()->next(7) ,
	v11->as_VMReg()          ,
	v11->as_VMReg()->next()  ,
	v11->as_VMReg()->next(2) ,
	v11->as_VMReg()->next(3) ,
	v11->as_VMReg()->next(4) ,
	v11->as_VMReg()->next(5) ,
	v11->as_VMReg()->next(6) ,
	v11->as_VMReg()->next(7) ,
	v12->as_VMReg()          ,
	v12->as_VMReg()->next()  ,
	v12->as_VMReg()->next(2) ,
	v12->as_VMReg()->next(3) ,
	v12->as_VMReg()->next(4) ,
	v12->as_VMReg()->next(5) ,
	v12->as_VMReg()->next(6) ,
	v12->as_VMReg()->next(7) ,
	v13->as_VMReg()          ,
	v13->as_VMReg()->next()  ,
	v13->as_VMReg()->next(2) ,
	v13->as_VMReg()->next(3) ,
	v13->as_VMReg()->next(4) ,
	v13->as_VMReg()->next(5) ,
	v13->as_VMReg()->next(6) ,
	v13->as_VMReg()->next(7) ,
	v14->as_VMReg()          ,
	v14->as_VMReg()->next()  ,
	v14->as_VMReg()->next(2) ,
	v14->as_VMReg()->next(3) ,
	v14->as_VMReg()->next(4) ,
	v14->as_VMReg()->next(5) ,
	v14->as_VMReg()->next(6) ,
	v14->as_VMReg()->next(7) ,
	v15->as_VMReg()          ,
	v15->as_VMReg()->next()  ,
	v15->as_VMReg()->next(2) ,
	v15->as_VMReg()->next(3) ,
	v15->as_VMReg()->next(4) ,
	v15->as_VMReg()->next(5) ,
	v15->as_VMReg()->next(6) ,
	v15->as_VMReg()->next(7) ,
	p0->as_VMReg(),
	p1->as_VMReg(),
	p2->as_VMReg(),
	p3->as_VMReg(),
	p4->as_VMReg(),
	p5->as_VMReg(),
	p6->as_VMReg(),
	p7->as_VMReg(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x10',  // V16_L
  (unsigned char)'\x10',  // V16_M
  (unsigned char)'\x10',  // V16_N
  (unsigned char)'\x10',  // V16_O
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x11',  // V17_L
  (unsigned char)'\x11',  // V17_M
  (unsigned char)'\x11',  // V17_N
  (unsigned char)'\x11',  // V17_O
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x12',  // V18_L
  (unsigned char)'\x12',  // V18_M
  (unsigned char)'\x12',  // V18_N
  (unsigned char)'\x12',  // V18_O
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x13',  // V19_L
  (unsigned char)'\x13',  // V19_M
  (unsigned char)'\x13',  // V19_N
  (unsigned char)'\x13',  // V19_O
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x14',  // V20_L
  (unsigned char)'\x14',  // V20_M
  (unsigned char)'\x14',  // V20_N
  (unsigned char)'\x14',  // V20_O
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x15',  // V21_L
  (unsigned char)'\x15',  // V21_M
  (unsigned char)'\x15',  // V21_N
  (unsigned char)'\x15',  // V21_O
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x16',  // V22_L
  (unsigned char)'\x16',  // V22_M
  (unsigned char)'\x16',  // V22_N
  (unsigned char)'\x16',  // V22_O
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x17',  // V23_L
  (unsigned char)'\x17',  // V23_M
  (unsigned char)'\x17',  // V23_N
  (unsigned char)'\x17',  // V23_O
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x18',  // V24_L
  (unsigned char)'\x18',  // V24_M
  (unsigned char)'\x18',  // V24_N
  (unsigned char)'\x18',  // V24_O
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x19',  // V25_L
  (unsigned char)'\x19',  // V25_M
  (unsigned char)'\x19',  // V25_N
  (unsigned char)'\x19',  // V25_O
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1A',  // V26_L
  (unsigned char)'\x1A',  // V26_M
  (unsigned char)'\x1A',  // V26_N
  (unsigned char)'\x1A',  // V26_O
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1B',  // V27_L
  (unsigned char)'\x1B',  // V27_M
  (unsigned char)'\x1B',  // V27_N
  (unsigned char)'\x1B',  // V27_O
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1C',  // V28_L
  (unsigned char)'\x1C',  // V28_M
  (unsigned char)'\x1C',  // V28_N
  (unsigned char)'\x1C',  // V28_O
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1D',  // V29_L
  (unsigned char)'\x1D',  // V29_M
  (unsigned char)'\x1D',  // V29_N
  (unsigned char)'\x1D',  // V29_O
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1E',  // V30_L
  (unsigned char)'\x1E',  // V30_M
  (unsigned char)'\x1E',  // V30_N
  (unsigned char)'\x1E',  // V30_O
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x1F',  // V31_L
  (unsigned char)'\x1F',  // V31_M
  (unsigned char)'\x1F',  // V31_N
  (unsigned char)'\x1F',  // V31_O
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x0',  // V0_L
  (unsigned char)'\x0',  // V0_M
  (unsigned char)'\x0',  // V0_N
  (unsigned char)'\x0',  // V0_O
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x1',  // V1_L
  (unsigned char)'\x1',  // V1_M
  (unsigned char)'\x1',  // V1_N
  (unsigned char)'\x1',  // V1_O
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x2',  // V2_L
  (unsigned char)'\x2',  // V2_M
  (unsigned char)'\x2',  // V2_N
  (unsigned char)'\x2',  // V2_O
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x3',  // V3_L
  (unsigned char)'\x3',  // V3_M
  (unsigned char)'\x3',  // V3_N
  (unsigned char)'\x3',  // V3_O
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x4',  // V4_L
  (unsigned char)'\x4',  // V4_M
  (unsigned char)'\x4',  // V4_N
  (unsigned char)'\x4',  // V4_O
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x5',  // V5_L
  (unsigned char)'\x5',  // V5_M
  (unsigned char)'\x5',  // V5_N
  (unsigned char)'\x5',  // V5_O
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x6',  // V6_L
  (unsigned char)'\x6',  // V6_M
  (unsigned char)'\x6',  // V6_N
  (unsigned char)'\x6',  // V6_O
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x7',  // V7_L
  (unsigned char)'\x7',  // V7_M
  (unsigned char)'\x7',  // V7_N
  (unsigned char)'\x7',  // V7_O
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x8',  // V8_L
  (unsigned char)'\x8',  // V8_M
  (unsigned char)'\x8',  // V8_N
  (unsigned char)'\x8',  // V8_O
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\x9',  // V9_L
  (unsigned char)'\x9',  // V9_M
  (unsigned char)'\x9',  // V9_N
  (unsigned char)'\x9',  // V9_O
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xA',  // V10_L
  (unsigned char)'\xA',  // V10_M
  (unsigned char)'\xA',  // V10_N
  (unsigned char)'\xA',  // V10_O
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xB',  // V11_L
  (unsigned char)'\xB',  // V11_M
  (unsigned char)'\xB',  // V11_N
  (unsigned char)'\xB',  // V11_O
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xC',  // V12_L
  (unsigned char)'\xC',  // V12_M
  (unsigned char)'\xC',  // V12_N
  (unsigned char)'\xC',  // V12_O
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xD',  // V13_L
  (unsigned char)'\xD',  // V13_M
  (unsigned char)'\xD',  // V13_N
  (unsigned char)'\xD',  // V13_O
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xE',  // V14_L
  (unsigned char)'\xE',  // V14_M
  (unsigned char)'\xE',  // V14_N
  (unsigned char)'\xE',  // V14_O
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\xF',  // V15_L
  (unsigned char)'\xF',  // V15_M
  (unsigned char)'\xF',  // V15_N
  (unsigned char)'\xF',  // V15_O
  (unsigned char)'\x0',  // P0
  (unsigned char)'\x1',  // P1
  (unsigned char)'\x2',  // P2
  (unsigned char)'\x3',  // P3
  (unsigned char)'\x4',  // P4
  (unsigned char)'\x5',  // P5
  (unsigned char)'\x6',  // P6
  (unsigned char)'\x7',  // P7
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegL_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegL_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegN_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegN_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegN_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORA_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *vRegD_V4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V4_REG_mask();
}

const RegMask *vRegD_V5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V5_REG_mask();
}

const RegMask *vRegD_V6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V6_REG_mask();
}

const RegMask *vRegD_V7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V7_REG_mask();
}

const RegMask *vRegD_V8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V8_REG_mask();
}

const RegMask *vRegD_V9Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V9_REG_mask();
}

const RegMask *vRegD_V10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V10_REG_mask();
}

const RegMask *vRegD_V11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V11_REG_mask();
}

const RegMask *vRegD_V12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V12_REG_mask();
}

const RegMask *vRegD_V13Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V13_REG_mask();
}

const RegMask *vRegD_V14Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V14_REG_mask();
}

const RegMask *vRegD_V15Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V15_REG_mask();
}

const RegMask *vRegD_V16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V16_REG_mask();
}

const RegMask *vRegD_V17Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V17_REG_mask();
}

const RegMask *vRegD_V18Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V18_REG_mask();
}

const RegMask *vRegD_V19Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V19_REG_mask();
}

const RegMask *vRegD_V20Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V20_REG_mask();
}

const RegMask *vRegD_V21Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V21_REG_mask();
}

const RegMask *vRegD_V22Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V22_REG_mask();
}

const RegMask *vRegD_V23Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V23_REG_mask();
}

const RegMask *vRegD_V24Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V24_REG_mask();
}

const RegMask *vRegD_V25Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V25_REG_mask();
}

const RegMask *vRegD_V26Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V26_REG_mask();
}

const RegMask *vRegD_V27Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V27_REG_mask();
}

const RegMask *vRegD_V28Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V28_REG_mask();
}

const RegMask *vRegD_V29Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V29_REG_mask();
}

const RegMask *vRegD_V30Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V30_REG_mask();
}

const RegMask *vRegD_V31Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V31_REG_mask();
}

const RegMask *pRegGovOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &GOV_PR_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *interpreter_method_oop_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *vmemA_indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *vmemA_indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version() {
  cmpL_branch_signNode *node = new cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version() {
  cmpI_branch_signNode *node = new cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version() {
  cmpL_branch_bitNode *node = new cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version() {
  cmpI_branch_bitNode *node = new cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone();
  }
  // Do not increment node index counter, since node reuses my index
  Compile* C = Compile::current();
  C->set_unique(C->unique() - 1);
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadConPollPageNode::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchallocNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int get_and_addIAcqNode::reloc() const {
  return 1;
}

int get_and_addI_no_resAcqNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int smaddLNode::reloc() const {
  return 2;
}

int smaddL_1Node::reloc() const {
  return 2;
}

int smaddL_0Node::reloc() const {
  return 2;
}

int smaddL_2Node::reloc() const {
  return 2;
}

int smsubLNode::reloc() const {
  return 2;
}

int smsubL_0Node::reloc() const {
  return 2;
}

int smnegLNode::reloc() const {
  return 2;
}

int smnegL_0Node::reloc() const {
  return 2;
}

int smnegL_1Node::reloc() const {
  return 2;
}

int smnegL_2Node::reloc() const {
  return 2;
}

int divINode::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int ubfizwINode::reloc() const {
  return 1;
}

int ubfizwIConvI2LNode::reloc() const {
  return 1;
}

int ubfizIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxth_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int SubExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_shift_0Node::reloc() const {
  return 1;
}

int SubExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int SubExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int mnsubF_reg_regNode::reloc() const {
  return 1;
}

int mnsubD_reg_regNode::reloc() const {
  return 1;
}

int absI_regNode::reloc() const {
  return 1;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int replicate8BNode::reloc() const {
  return 1;
}

int replicate16BNode::reloc() const {
  return 1;
}

int replicate4SNode::reloc() const {
  return 1;
}

int replicate8SNode::reloc() const {
  return 1;
}

int replicate2INode::reloc() const {
  return 1;
}

int replicate4INode::reloc() const {
  return 1;
}

int reduce_add2INode::reloc() const {
  return 1;
}

int reduce_add4INode::reloc() const {
  return 1;
}

int reduce_mul2INode::reloc() const {
  return 1;
}

int reduce_mul4INode::reloc() const {
  return 1;
}

int vshiftcnt8BNode::reloc() const {
  return 1;
}

int vshiftcnt8B_0Node::reloc() const {
  return 1;
}

int vshiftcnt16BNode::reloc() const {
  return 1;
}

int vshiftcnt16B_0Node::reloc() const {
  return 1;
}

int zLoadPNode::reloc() const {
  return 1;
}

int zLoadWeakPNode::reloc() const {
  return 1;
}

int loadVNode::reloc() const {
  return 1;
}

int storeVNode::reloc() const {
  return 2;
}

int reduce_addINode::reloc() const {
  return 1;
}

int replicateBNode::reloc() const {
  return 1;
}

int replicateSNode::reloc() const {
  return 1;
}

int replicateINode::reloc() const {
  return 1;
}

int vshiftcntBNode::reloc() const {
  return 1;
}

int vshiftcntB_0Node::reloc() const {
  return 1;
}

int vshiftcntSNode::reloc() const {
  return 1;
}

int vshiftcntS_0Node::reloc() const {
  return 1;
}

int vshiftcntINode::reloc() const {
  return 1;
}

int vshiftcntI_0Node::reloc() const {
  return 1;
}

int vshiftcntLNode::reloc() const {
  return 1;
}

int vshiftcntL_0Node::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2992 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 12757 "ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3000 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 12774 "ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3016 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 12791 "ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3016 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 12808 "ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3024 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 12825 "ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3032 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 12842 "ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3048 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 12859 "ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3048 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 12876 "ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3064 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 12893 "ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3072 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 12910 "ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3064 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 12928 "ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3080 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 12945 "ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3064 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 12962 "ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3080 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 12979 "ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3064 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 12996 "ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3080 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 13013 "ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3064 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13030 "ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3088 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13047 "ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3096 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13064 "ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3536 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    uint32_t con = (uint32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 13086 "ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3547 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t con = (uint64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 13108 "ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3558 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con, /*immediate*/true);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
        if (! __ is_valid_AArch64_address(con) ||
            con < (address)(uintptr_t)os::vm_page_size()) {
          __ mov(dst_reg, con);
        } else {
          uint64_t offset;
          __ adrp(dst_reg, con, offset);
          __ add(dst_reg, dst_reg, offset);
        }
      }
    }
  
#line 13145 "ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3584 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 13162 "ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3590 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (uint64_t)1);
  
#line 13179 "ad_aarch64.cpp"
  }
}

void loadConPollPageNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    address page = (address)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t off;
    __ adrp(dst_reg, Address(page, relocInfo::poll_type), off);
    assert(off == 0, "assumed offset == 0");
  
#line 13199 "ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3605 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 13215 "ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3610 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 13239 "ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3623 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 13256 "ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3629 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 13280 "ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 7687 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 13296 "ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 7705 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 13312 "ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 7706 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13321 "ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 7718 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 13336 "ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 7735 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 13352 "ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 7736 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 13361 "ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3136 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13378 "ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3144 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ membar(Assembler::StoreStore);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13397 "ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3128 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13415 "ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3136 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13433 "ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3153 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 13451 "ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3161 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 13469 "ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3169 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13487 "ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3177 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13505 "ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3185 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 13531 "ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3201 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 13549 "ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3185 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 13575 "ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3201 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 13593 "ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3169 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13611 "ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3169 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(R27_enc);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13629 "ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3209 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13647 "ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3217 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 13665 "ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3169 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 13683 "ad_aarch64.cpp"
  }
}

void prefetchallocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 3515 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 13713 "ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3274 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 13731 "ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3274 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 13749 "ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3286 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 13765 "ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3286 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 13781 "ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3291 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 13799 "ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3305 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 13815 "ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3310 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 13831 "ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3298 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 13849 "ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3320 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 13865 "ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3320 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 13882 "ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3325 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 13898 "ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3325 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 13914 "ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3320 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 13930 "ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3330 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 13947 "ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3336 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 13964 "ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3251 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 13981 "ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3256 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 13998 "ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3261 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 14015 "ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3342 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
        MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 14041 "ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3342 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
        MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 14067 "ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3261 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 14084 "ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3356 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 14106 "ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3366 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 14128 "ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8321 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 14144 "ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8334 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 14160 "ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8347 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 14176 "ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8361 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 14193 "ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8377 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 14209 "ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8389 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 14225 "ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8402 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 14242 "ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8416 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 14259 "ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8438 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 14280 "ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8459 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 14302 "ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8482 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 14322 "ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8502 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 14344 "ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8523 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 14360 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8536 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 14376 "ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8550 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 14393 "ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8565 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 14409 "ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8578 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 14425 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8591 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 14441 "ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 14458 "ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8617 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 14474 "ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8629 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 14490 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8643 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 14506 "ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8657 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
  
#line 14523 "ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8674 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 14541 "ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8689 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 14559 "ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8704 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14575 "ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8720 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14591 "ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8735 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 14609 "ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8748 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14625 "ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8760 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 14643 "ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8774 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 14661 "ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8792 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 14679 "ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8807 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 14701 "ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castLLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3378 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch1, Address(base, disp));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ ldaxr(dst_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch1, Address(base, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        __ lea(rscratch1, Address(base, disp));
        __ lea(rscratch1, Address(rscratch1, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      }
    }
  
#line 14793 "ad_aarch64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3407 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register src_reg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* newval */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch2, Address(base, disp));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ stlxr(rscratch1, src_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch2, Address(base, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        __ lea(rscratch2, Address(base, disp));
        __ lea(rscratch2, Address(rscratch2, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      }
    }
    __ cmpw(rscratch1, zr);
  
#line 14836 "ad_aarch64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3474 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14857 "ad_aarch64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3482 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14878 "ad_aarch64.cpp"
  }
}

void compareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3461 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14899 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 14909 "ad_aarch64.cpp"
  }
}

void compareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3453 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14930 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 14940 "ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3445 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14961 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 14971 "ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3437 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 14992 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15002 "ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3437 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15023 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15033 "ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3445 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15054 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15064 "ad_aarch64.cpp"
  }
}

void compareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3498 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15085 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15095 "ad_aarch64.cpp"
  }
}

void compareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3490 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15116 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15126 "ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3482 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15147 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15157 "ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3474 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15178 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15188 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3474 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15209 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15219 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3482 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 15240 "ad_aarch64.cpp"
  }
  {

#line 3507 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 15250 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9223 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15272 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9239 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15294 "ad_aarch64.cpp"
  }
}

void compareAndExchangeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9255 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15315 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9270 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15336 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9285 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15357 "ad_aarch64.cpp"
  }
}

void compareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9301 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15378 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9317 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15400 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9334 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15422 "ad_aarch64.cpp"
  }
}

void compareAndExchangeIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9352 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15443 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9368 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15464 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15485 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 9401 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 15506 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9417 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15527 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9434 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15548 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9451 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15569 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9468 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15590 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9485 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15611 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9503 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15632 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9521 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15653 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9539 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15674 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9557 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15695 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9575 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15716 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15737 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 9611 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 15758 "ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9627 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15775 "ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15792 "ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9647 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15809 "ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15826 "ad_aarch64.cpp"
  }
}

void get_and_setIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9669 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15843 "ad_aarch64.cpp"
  }
}

void get_and_setLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9680 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15860 "ad_aarch64.cpp"
  }
}

void get_and_setNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15877 "ad_aarch64.cpp"
  }
}

void get_and_setPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 9702 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15894 "ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9713 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15911 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9724 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15928 "ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9734 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15945 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9745 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15962 "ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9755 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15979 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9766 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 15996 "ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9776 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16013 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9787 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16030 "ad_aarch64.cpp"
  }
}

void get_and_addLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16047 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9809 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16064 "ad_aarch64.cpp"
  }
}

void get_and_addLiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9820 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16081 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9831 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16098 "ad_aarch64.cpp"
  }
}

void get_and_addIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9842 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16115 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9853 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16132 "ad_aarch64.cpp"
  }
}

void get_and_addIiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9864 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16149 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 9875 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 16166 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 16185 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9915 "src/hotspot/cpu/aarch64/aarch64.ad"

    int32_t con = (int32_t)opnd_array(2)->constantL();
     if (con < 0) {
      __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -con);
    } else {
      __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, con);
    }
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 16209 "ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9948 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16231 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9964 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16253 "ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16275 "ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10005 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16297 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10021 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16319 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10037 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16341 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10058 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16366 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10077 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16391 "ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10096 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16413 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10112 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16435 "ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10130 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16457 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10146 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16479 "ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10162 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16501 "ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10178 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16523 "ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10194 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16545 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10210 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16567 "ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10228 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16589 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10244 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16611 "ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10260 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16633 "ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10276 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16655 "ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10292 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16677 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10308 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16699 "ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10326 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16721 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10342 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16743 "ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10358 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16765 "ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10374 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 16787 "ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10391 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 16810 "ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10409 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 16833 "ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10427 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 16856 "ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10445 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 16879 "ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10474 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 16898 "ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3644 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 16924 "ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3644 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 16950 "ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10518 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 16969 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10533 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 16988 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 10548 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::lsl(opnd_array(3)->constant())));
  
#line 17008 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 10563 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::sxtw(opnd_array(3)->constant())));
  
#line 17028 "ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 10578 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN2(32, (int)((-opnd_array(2)->constant()) & 63)));
  
#line 17047 "ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3658 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 17073 "ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10612 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17092 "ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3658 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 17118 "ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10643 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17137 "ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3644 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 17163 "ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10675 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17182 "ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3658 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 17208 "ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10707 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 17226 "ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10723 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 17244 "ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17263 "ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17282 "ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 17301 "ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10771 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17320 "ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10787 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17339 "ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10804 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17360 "ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10804 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 17381 "ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10820 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17402 "ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10838 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17423 "ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10838 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 17444 "ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10854 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17465 "ad_aarch64.cpp"
  }
}

void smaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10872 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17486 "ad_aarch64.cpp"
  }
}

void smaddL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10872 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 17507 "ad_aarch64.cpp"
  }
}

void smaddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10872 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17528 "ad_aarch64.cpp"
  }
}

void smaddL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10872 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 17549 "ad_aarch64.cpp"
  }
}

void smsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10888 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17570 "ad_aarch64.cpp"
  }
}

void smsubL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10888 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 17591 "ad_aarch64.cpp"
  }
}

void smnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10905 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 17611 "ad_aarch64.cpp"
  }
}

void smnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10905 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 17631 "ad_aarch64.cpp"
  }
}

void smnegL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10905 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 17651 "ad_aarch64.cpp"
  }
}

void smnegL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10905 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17671 "ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3672 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 17691 "ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3680 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 17711 "ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3688 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 17731 "ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3696 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 17751 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10973 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17770 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 17789 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11005 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17808 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11021 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 17827 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11037 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17846 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11053 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 17865 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11074 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17884 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11090 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 17903 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11106 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17922 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11122 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 17941 "ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11138 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 17960 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11154 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17979 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11170 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 17998 "ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11192 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 18018 "ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11211 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 18038 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11230 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18059 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11230 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18080 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11249 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18101 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11249 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18122 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11268 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18143 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11268 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18164 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11287 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18185 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11287 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18206 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11306 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18227 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11306 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18248 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11325 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 18269 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 11325 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 18290 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18313 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 18336 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11364 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18359 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11364 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 18382 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18405 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 18428 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11404 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18451 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11404 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 18474 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11424 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 18497 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11424 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 18520 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11444 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 18543 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11444 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 18566 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18589 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 18612 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 18635 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18658 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11484 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18681 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11484 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 18704 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11484 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 18727 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11484 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18750 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11504 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18773 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11504 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 18796 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11504 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 18819 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11504 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 18842 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11524 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18865 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11524 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 18888 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11524 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 18911 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11524 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 18934 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 18957 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 18980 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 19003 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 19026 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11564 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 19049 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11564 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 19072 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11564 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 19095 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11564 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 19118 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11584 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19141 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11584 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19164 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19187 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19210 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11624 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19233 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11624 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19256 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11644 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19279 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11644 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19302 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11664 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 19325 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11664 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 19348 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 11684 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 19371 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11684 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 19394 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11705 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19416 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11705 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19438 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11726 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19460 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11726 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19482 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11747 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19504 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11747 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19526 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11768 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19548 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11768 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19570 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11789 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 19592 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11789 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 19614 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11810 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 19636 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11810 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 19658 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11831 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19680 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11831 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19702 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11852 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19724 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11852 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19746 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11873 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19768 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11873 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19790 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11894 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19812 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11894 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 19834 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11915 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 19856 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11915 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 19878 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11936 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 19900 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11936 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 19922 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11957 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 19944 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11957 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 19966 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11978 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 19988 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11978 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20010 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 11999 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20032 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11999 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20054 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12020 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20076 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12020 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20098 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12041 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 20120 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12041 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 20142 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12062 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 20164 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12062 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 20186 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12083 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20208 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12083 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20230 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20252 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20274 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12125 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20296 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12125 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20318 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12146 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20340 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12146 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20362 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12167 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 20384 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12167 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 20406 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12188 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 20428 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12188 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 20450 "ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12209 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20472 "ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12230 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20494 "ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12251 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20516 "ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12272 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20538 "ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12293 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 20560 "ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 12314 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 20582 "ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 12336 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 20606 "ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 12359 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 20630 "ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 12382 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 20654 "ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 12405 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 20678 "ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 12430 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 20700 "ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 12450 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 63;
    intptr_t mask = opnd_array(3)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 20722 "ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 12474 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 20744 "ad_aarch64.cpp"
  }
}

void ubfizwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12497 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20766 "ad_aarch64.cpp"
  }
}

void ubfizLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12519 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20788 "ad_aarch64.cpp"
  }
}

void ubfizwIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12541 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20810 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12563 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20832 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12585 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20854 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2IxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12606 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 20876 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LAndINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// msk
  {
    MacroAssembler _masm(&cbuf);

#line 12622 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, exact_log2(opnd_array(2)->constant()+ 1));
  
#line 20893 "ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12640 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 20913 "ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12640 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 20933 "ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 20953 "ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 20973 "ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12676 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 20993 "ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12676 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 21013 "ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12694 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 21033 "ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 12694 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 21053 "ad_aarch64.cpp"
  }
}

void rolL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 12712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            rscratch1);
    
#line 21072 "ad_aarch64.cpp"
  }
}

void rolI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 12730 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            rscratch1);
    
#line 21091 "ad_aarch64.cpp"
  }
}

void rorL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 12792 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    
#line 21109 "ad_aarch64.cpp"
  }
}

void rorI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 12809 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    
#line 21127 "ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12871 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 21145 "ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12871 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 21163 "ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12886 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 21181 "ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12901 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 21201 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12901 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 21221 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12916 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 21241 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12916 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 21261 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12931 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21281 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12931 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 21301 "ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12946 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 21321 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12946 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 21341 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12961 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 21361 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12961 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 21381 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12976 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 21401 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12976 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 21421 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 12991 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21441 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 12991 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 21461 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13006 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21480 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13006 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 21499 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13021 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 21518 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13021 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 21537 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13036 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21556 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13036 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 21575 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13051 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 21594 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13051 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 21613 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13066 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 21632 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13066 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 21651 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13081 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21670 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13096 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 21689 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13111 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 21708 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13126 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 21727 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 13141 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 21746 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13157 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 21767 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13157 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 21788 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13172 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 21809 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13172 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 21830 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13187 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 21851 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13187 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(4)->constant()));
   
#line 21872 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13202 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 21893 "ad_aarch64.cpp"
  }
}

void SubExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13217 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 21914 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13232 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 21935 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13247 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 21956 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13247 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 21977 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13262 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 21998 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13262 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 22019 "ad_aarch64.cpp"
  }
}

void SubExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13277 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 22040 "ad_aarch64.cpp"
  }
}

void SubExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    MacroAssembler _masm(&cbuf);

#line 13292 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 22061 "ad_aarch64.cpp"
  }
}

void AddExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13307 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 22080 "ad_aarch64.cpp"
  }
}

void AddExtI_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13307 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(2)->constant()));
   
#line 22099 "ad_aarch64.cpp"
  }
}

void SubExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13322 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 22118 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13337 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 22138 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13337 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 22158 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13352 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 22178 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13352 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 22198 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13367 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 22218 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13367 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw, (opnd_array(3)->constant()));
   
#line 22238 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13382 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 22258 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13397 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 22278 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13412 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 22298 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13427 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 22318 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13427 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 22338 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13442 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 22358 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 13442 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 22378 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13457 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 22398 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 13472 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 22418 "ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13493 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22437 "ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13508 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22456 "ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13523 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22475 "ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13538 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22494 "ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22513 "ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13568 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22532 "ad_aarch64.cpp"
  }
}

void maddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13584 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22553 "ad_aarch64.cpp"
  }
}

void maddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13601 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22574 "ad_aarch64.cpp"
  }
}

void msubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13619 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22595 "ad_aarch64.cpp"
  }
}

void msubF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13619 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22616 "ad_aarch64.cpp"
  }
}

void msubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22637 "ad_aarch64.cpp"
  }
}

void msubD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22658 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13655 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22679 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13655 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22700 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13673 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22721 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13673 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22742 "ad_aarch64.cpp"
  }
}

void mnsubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13690 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22763 "ad_aarch64.cpp"
  }
}

void mnsubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13707 "src/hotspot/cpu/aarch64/aarch64.ad"

  // n.b. insn name should be fnmsubd
    __ fnmsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22785 "ad_aarch64.cpp"
  }
}

void maxF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13724 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22804 "ad_aarch64.cpp"
  }
}

void minF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13738 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22823 "ad_aarch64.cpp"
  }
}

void maxD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13752 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22842 "ad_aarch64.cpp"
  }
}

void minD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13766 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22861 "ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13782 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22880 "ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13797 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22899 "ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13812 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 22916 "ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13826 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 22933 "ad_aarch64.cpp"
  }
}

void absI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13844 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 22950 "ad_aarch64.cpp"
  }
}

void absL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 22967 "ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13873 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 22984 "ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13886 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23001 "ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13899 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23018 "ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13912 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23035 "ad_aarch64.cpp"
  }
}

void copySignD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 13924 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                  zero = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* zero */);
    __ fnegd(dst, zero);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 23059 "ad_aarch64.cpp"
  }
}

void copySignF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 13939 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ movi(dst, __ T2S, 0x80, 24);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 23081 "ad_aarch64.cpp"
  }
}

void signumD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 13953 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgtd(dst, src, zero); // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushrd(dst, dst, 1);     // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 23111 "ad_aarch64.cpp"
  }
}

void signumF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 13974 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgts(dst, src, zero);    // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushr(dst, __ T2S, dst, 1); // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 23141 "ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14005 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23160 "ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14020 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 23179 "ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14037 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23198 "ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14052 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 23217 "ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14069 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23236 "ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14084 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 23255 "ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14102 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23274 "ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14117 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constantL()));
  
#line 23293 "ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14134 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23312 "ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14149 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 23331 "ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14166 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 23350 "ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14181 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 23369 "ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14196 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 23385 "ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 14209 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 23402 "ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14222 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23418 "ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14239 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 23435 "ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14257 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 23452 "ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14271 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23468 "ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14284 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23484 "ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14297 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23500 "ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14310 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23516 "ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23532 "ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14336 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23548 "ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14349 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23564 "ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14362 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23580 "ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14375 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23596 "ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14388 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23612 "ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14407 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23628 "ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14425 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23644 "ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14443 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23660 "ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14461 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23676 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14479 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23692 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14497 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23708 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14515 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23724 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14533 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 23740 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14551 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23756 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14569 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 23772 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14587 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 23788 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14605 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 23804 "ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 14624 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 23825 "ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 14645 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (uint64_t)opnd_array(1)->constantL());
  
#line 23842 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14661 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 23859 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14674 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 23876 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14687 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 23893 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14700 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 23910 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14713 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 23927 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14726 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 23944 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 23961 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14752 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 23978 "ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    MacroAssembler _masm(&cbuf);

#line 14765 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 23995 "ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    MacroAssembler _masm(&cbuf);

#line 14778 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 24012 "ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14795 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 24033 "ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 14817 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 24056 "ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 14839 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 24078 "ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 14863 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 24102 "ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3706 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 24121 "ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 24144 "ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 24167 "ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3724 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 24187 "ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3706 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 24206 "ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 24229 "ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 24252 "ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3724 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 24272 "ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3732 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 24291 "ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3739 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 24318 "ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3739 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 24345 "ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3754 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 24365 "ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3732 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 24384 "ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3739 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 24411 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3739 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 24438 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3754 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 24458 "ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3762 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 24477 "ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3769 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 24496 "ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3776 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 24514 "ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3782 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 24532 "ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15174 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 24549 "ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15188 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 24566 "ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15203 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 24583 "ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15217 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 24600 "ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15235 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 24626 "ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 15263 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 24652 "ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 15290 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 24677 "ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 15317 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 24702 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 15344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 24721 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 15362 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 24738 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15379 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 24759 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15410 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 24780 "ad_aarch64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3788 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 24797 "ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3794 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 24816 "ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3800 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 24835 "ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15501 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 24859 "ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15518 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 24883 "ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15535 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 24907 "ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15552 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 24931 "ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15569 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 24955 "ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15586 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 24979 "ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15603 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 25003 "ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15623 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 25025 "ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15639 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 25047 "ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15656 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 25070 "ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15673 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 25093 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15690 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 25115 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15705 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 25137 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15721 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 25160 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 15737 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 25183 "ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 15755 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 25201 "ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 15768 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 25219 "ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 15779 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 25237 "ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 15790 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 25255 "ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3794 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 25274 "ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3800 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 25293 "ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3941 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label cas_failed;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markOop from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    // Always do locking in runtime.
    if (EmitSync & 0x01) {
      __ cmp(oop, zr);
      return;
    }

    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_enter(box, oop, disp_hdr, tmp, true, cont);
    }

    // Check for existing monitor
    if ((EmitSync & 0x02) == 0) {
      __ tbnz(disp_hdr, exact_log2(markOopDesc::monitor_value), object_has_monitor);
    }

    // Set tmp to be (markOop of object | UNLOCK_VALUE).
    __ orr(tmp, disp_hdr, markOopDesc::unlocked_value);

    // Initialize the box. (Must happen before we update the object mark!)
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // Compare object markOop with an unlocked value (tmp) and if
    // equal exchange the stack address of our box with object markOop.
    // On failure disp_hdr contains the possibly locked markOop.
    __ cmpxchg(oop, tmp, box, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, disp_hdr);
    __ br(Assembler::EQ, cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // If the compare-and-exchange succeeded, then we found an unlocked
    // object, will have now locked it will continue at label cont

    __ bind(cas_failed);
    // We did not see an unlocked object so try the fast recursive case.

    // Check if the owner is self by comparing the value in the
    // markOop of object (disp_hdr) with the stack pointer.
    __ mov(rscratch1, sp);
    __ sub(disp_hdr, disp_hdr, rscratch1);
    __ mov(tmp, (address) (~(os::vm_page_size()-1) | (uintptr_t)markOopDesc::lock_mask_in_place));
    // If condition is true we are cont and hence we can store 0 as the
    // displaced header in the box, which indicates that it is a recursive lock.
    __ ands(tmp/*==0?*/, disp_hdr, tmp);   // Sets flags for result
    __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    if ((EmitSync & 0x02) == 0) {
      __ b(cont);

      // Handle existing monitor.
      __ bind(object_has_monitor);
      // The object's monitor m is unlocked iff m->owner == NULL,
      // otherwise m->owner may contain a thread or a stack address.
      //
      // Try to CAS m->owner from NULL to current thread.
      __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markOopDesc::monitor_value));
    __ cmpxchg(tmp, zr, rthread, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, noreg); // Sets flags for result

      // Store a non-null value into the box to avoid looking like a re-entrant
      // lock. The fast-path monitor unlock code checks for
      // markOopDesc::monitor_value so use markOopDesc::unused_mark which has the
      // relevant bit set, and also matches ObjectSynchronizer::slow_enter.
      __ mov(tmp, (address)markOopDesc::unused_mark());
      __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));
    }

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 25394 "ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 4028 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Always do locking in runtime.
    if (EmitSync & 0x01) {
      __ cmp(oop, zr); // Oop can't be 0 here => always false.
      return;
    }

    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_exit(oop, tmp, cont);
    }

    // Find the lock address and load the displaced header from the stack.
    __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // If the displaced header is 0, we have a recursive unlock.
    __ cmp(disp_hdr, zr);
    __ br(Assembler::EQ, cont);

    // Handle existing monitor.
    if ((EmitSync & 0x02) == 0) {
      __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
      __ tbnz(disp_hdr, exact_log2(markOopDesc::monitor_value), object_has_monitor);
    }

    // Check if it is still a light weight lock, this is is true if we
    // see the stack address of the basicLock in the markOop of the
    // object.

    __ cmpxchg(oop, box, disp_hdr, Assembler::xword, /*acquire*/ false,
               /*release*/ true, /*weak*/ false, tmp);
    __ b(cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    if ((EmitSync & 0x02) == 0) {
      __ bind(object_has_monitor);
      __ add(tmp, tmp, -markOopDesc::monitor_value); // monitor
      __ ldr(rscratch1, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
      __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
      __ eor(rscratch1, rscratch1, rthread); // Will be 0 if we are the owner.
      __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if there are 0 recursions
      __ cmp(rscratch1, zr); // Sets flags for result
      __ br(Assembler::NE, cont);

      __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
      __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
      __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
      __ cmp(rscratch1, zr); // Sets flags for result
      __ cbnz(rscratch1, cont);
      // need a release store here
      __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
      __ stlr(zr, tmp); // set unowned
    }

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 25478 "ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 15885 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 25494 "ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3824 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      call = __ trampoline_call(Address(addr, rspec), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }
    if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      // Only non uncommon_trap calls need to reinitialize ptrue.
      if (uncommon_trap_request() == 0) {
        __ reinitialize_ptrue();
      }
    }
  
#line 25541 "ad_aarch64.cpp"
  }
  {

#line 3872 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 25553 "ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3860 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    int method_index = resolved_method_index(cbuf);
    address call = __ ic_call((address)opnd_array(1)->method(), method_index);
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    } else if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 25576 "ad_aarch64.cpp"
  }
  {

#line 3872 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 25588 "ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3880 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 25629 "ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3880 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 25670 "ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3880 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 25711 "ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3925 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 25729 "ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3931 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 25751 "ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3910 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 25780 "ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3915 "src/hotspot/cpu/aarch64/aarch64.ad"

    MacroAssembler _masm(&cbuf);
#ifdef ASSERT
    if (UseSVE > 0 && Compile::current()->max_vector_size() >= 16) {
      __ verify_ptrue();
    }
#endif
    __ ret(lr);
  
#line 25801 "ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 16065 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (is_reachable()) {
      __ dpcs1(0xdead + 1);
    }
  
#line 25819 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3807 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 25848 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3807 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 25878 "ad_aarch64.cpp"
  }
}

void string_compareUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    MacroAssembler _masm(&cbuf);

#line 16120 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::UU);
  
#line 25901 "ad_aarch64.cpp"
  }
}

void string_compareLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    MacroAssembler _masm(&cbuf);

#line 16138 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::LL);
  
#line 25923 "ad_aarch64.cpp"
  }
}

void string_compareULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    MacroAssembler _masm(&cbuf);

#line 16157 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), StrIntrinsicNode::UL);
  
#line 25946 "ad_aarch64.cpp"
  }
}

void string_compareLUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    MacroAssembler _masm(&cbuf);

#line 16177 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc),StrIntrinsicNode::LU);
  
#line 25969 "ad_aarch64.cpp"
  }
}

void string_indexofUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp0
  unsigned idx12 = idx11 + opnd_array(11)->num_edges(); 	// vtmp1
  {
    MacroAssembler _masm(&cbuf);

#line 16200 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 26001 "ad_aarch64.cpp"
  }
}

void string_indexofLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp0
  unsigned idx12 = idx11 + opnd_array(11)->num_edges(); 	// vtmp1
  {
    MacroAssembler _masm(&cbuf);

#line 16224 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 26033 "ad_aarch64.cpp"
  }
}

void string_indexofULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp0
  unsigned idx12 = idx11 + opnd_array(11)->num_edges(); 	// vtmp1
  {
    MacroAssembler _masm(&cbuf);

#line 16248 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 26065 "ad_aarch64.cpp"
  }
}

void string_indexof_conUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 16270 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 26093 "ad_aarch64.cpp"
  }
}

void string_indexof_conLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 16292 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 26121 "ad_aarch64.cpp"
  }
}

void string_indexof_conULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 16314 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 26149 "ad_aarch64.cpp"
  }
}

void string_indexofU_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    MacroAssembler _masm(&cbuf);

#line 16335 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 26172 "ad_aarch64.cpp"
  }
}

void string_equalsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 16351 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 1);
  
#line 26192 "ad_aarch64.cpp"
  }
}

void string_equalsUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 16367 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 2);
  
#line 26212 "ad_aarch64.cpp"
  }
}

void array_equalsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// vtmp0
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// vtmp3
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// vtmp4
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp5
  unsigned idx12 = idx11 + opnd_array(11)->num_edges(); 	// vtmp6
  unsigned idx13 = idx12 + opnd_array(12)->num_edges(); 	// vtmp7
  {
    MacroAssembler _masm(&cbuf);

#line 16388 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 1);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26246 "ad_aarch64.cpp"
  }
}

void array_equalsCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// vtmp0
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// vtmp3
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// vtmp4
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp5
  unsigned idx12 = idx11 + opnd_array(11)->num_edges(); 	// vtmp6
  unsigned idx13 = idx12 + opnd_array(12)->num_edges(); 	// vtmp7
  {
    MacroAssembler _masm(&cbuf);

#line 16413 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 2);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26280 "ad_aarch64.cpp"
  }
}

void has_negativesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// len
  {
    MacroAssembler _masm(&cbuf);

#line 16430 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ has_negatives(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* len */, opnd_array(0)->as_Register(ra_,this)/* result */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26301 "ad_aarch64.cpp"
  }
}

void string_compressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// vtmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// vtmp5
  {
    MacroAssembler _masm(&cbuf);

#line 16451 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ char_array_compress(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* vtmp0 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* vtmp1 */,
                           opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* vtmp2 */, opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp3 */,
                           opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp4 */, opnd_array(9)->as_FloatRegister(ra_,this,idx9)/* vtmp5 */,
                           opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 26329 "ad_aarch64.cpp"
  }
}

void string_inflateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp0
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// vtmp1
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp2
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp3
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// vtmp4
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// vtmp5
  unsigned idx11 = idx10 + opnd_array(10)->num_edges(); 	// vtmp6
  {
    MacroAssembler _masm(&cbuf);

#line 16472 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ byte_array_inflate(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                                        opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* vtmp0 */, opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* vtmp1 */,
                                        opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp2 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26361 "ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    MacroAssembler _masm(&cbuf);

#line 16495 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(0)->as_Register(ra_,this)/* result */, as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                        as_FloatRegister(V2_enc), as_FloatRegister(V3_enc),
                        as_FloatRegister(V4_enc), as_FloatRegister(V5_enc));
  
#line 26382 "ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3104 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26412 "ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3112 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26429 "ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3120 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26446 "ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3225 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26464 "ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3233 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26482 "ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3241 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 26500 "ad_aarch64.cpp"
  }
}

void replicate8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16598 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26516 "ad_aarch64.cpp"
  }
}

void replicate16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16610 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26532 "ad_aarch64.cpp"
  }
}

void replicate8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16623 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(1)->constant()& 0xff);
  
#line 26548 "ad_aarch64.cpp"
  }
}

void replicate16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16635 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(1)->constant()& 0xff);
  
#line 26564 "ad_aarch64.cpp"
  }
}

void replicate4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16648 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26580 "ad_aarch64.cpp"
  }
}

void replicate8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16660 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26596 "ad_aarch64.cpp"
  }
}

void replicate4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16673 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(1)->constant()& 0xffff);
  
#line 26612 "ad_aarch64.cpp"
  }
}

void replicate8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16685 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(1)->constant()& 0xffff);
  
#line 26628 "ad_aarch64.cpp"
  }
}

void replicate2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16697 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26644 "ad_aarch64.cpp"
  }
}

void replicate4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16709 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26660 "ad_aarch64.cpp"
  }
}

void replicate2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16721 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(1)->constant());
  
#line 26676 "ad_aarch64.cpp"
  }
}

void replicate4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 16733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(1)->constant());
  
#line 26692 "ad_aarch64.cpp"
  }
}

void replicate2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16745 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26708 "ad_aarch64.cpp"
  }
}

void replicate2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 16757 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 26726 "ad_aarch64.cpp"
  }
}

void replicate2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16771 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26743 "ad_aarch64.cpp"
  }
}

void replicate4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16784 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26760 "ad_aarch64.cpp"
  }
}

void replicate2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 16797 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26777 "ad_aarch64.cpp"
  }
}

void reduce_add2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 16816 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ S, 0);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ S, 1);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
  
#line 26799 "ad_aarch64.cpp"
  }
}

void reduce_add4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 16834 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 26821 "ad_aarch64.cpp"
  }
}

void reduce_mul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 16853 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 26843 "ad_aarch64.cpp"
  }
}

void reduce_mul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 16874 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 26870 "ad_aarch64.cpp"
  }
}

void reduce_add2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 16896 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 26894 "ad_aarch64.cpp"
  }
}

void reduce_add4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 16920 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 2);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 3);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 26926 "ad_aarch64.cpp"
  }
}

void reduce_mul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 16948 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 26950 "ad_aarch64.cpp"
  }
}

void reduce_mul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 16972 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 2);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 3);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 26982 "ad_aarch64.cpp"
  }
}

void reduce_add2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17000 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27006 "ad_aarch64.cpp"
  }
}

void reduce_mul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17020 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27030 "ad_aarch64.cpp"
  }
}

void reduce_max2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17039 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27051 "ad_aarch64.cpp"
  }
}

void reduce_max4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17054 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 27070 "ad_aarch64.cpp"
  }
}

void reduce_max2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17069 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27091 "ad_aarch64.cpp"
  }
}

void reduce_min2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17085 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27112 "ad_aarch64.cpp"
  }
}

void reduce_min4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17100 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 27131 "ad_aarch64.cpp"
  }
}

void reduce_min2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 17115 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), 0, 1);
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 27152 "ad_aarch64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17134 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27171 "ad_aarch64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17148 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27190 "ad_aarch64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17163 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27209 "ad_aarch64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17177 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27228 "ad_aarch64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17191 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27247 "ad_aarch64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17205 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27266 "ad_aarch64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17219 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27285 "ad_aarch64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17233 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27304 "ad_aarch64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17247 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27323 "ad_aarch64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17260 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27342 "ad_aarch64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17277 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27361 "ad_aarch64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17291 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27380 "ad_aarch64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17306 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27399 "ad_aarch64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17320 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27418 "ad_aarch64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17334 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27437 "ad_aarch64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17348 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27456 "ad_aarch64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17362 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27475 "ad_aarch64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17376 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27494 "ad_aarch64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17390 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27513 "ad_aarch64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17404 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27532 "ad_aarch64.cpp"
  }
}

void vmul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17421 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27551 "ad_aarch64.cpp"
  }
}

void vmul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17435 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27570 "ad_aarch64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17450 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27589 "ad_aarch64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27608 "ad_aarch64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17478 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27627 "ad_aarch64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17492 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27646 "ad_aarch64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17506 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27665 "ad_aarch64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17520 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27684 "ad_aarch64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17534 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27703 "ad_aarch64.cpp"
  }
}

void vmla4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17551 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27723 "ad_aarch64.cpp"
  }
}

void vmla4S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17551 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27743 "ad_aarch64.cpp"
  }
}

void vmla8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17565 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27763 "ad_aarch64.cpp"
  }
}

void vmla8S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17565 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27783 "ad_aarch64.cpp"
  }
}

void vmla2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17579 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27803 "ad_aarch64.cpp"
  }
}

void vmla2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17579 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27823 "ad_aarch64.cpp"
  }
}

void vmla4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27843 "ad_aarch64.cpp"
  }
}

void vmla4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 17593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27863 "ad_aarch64.cpp"
  }
}

void vmla2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17607 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27883 "ad_aarch64.cpp"
  }
}

void vmla4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17621 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27903 "ad_aarch64.cpp"
  }
}

void vmla2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17635 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27923 "ad_aarch64.cpp"
  }
}

void vmls4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17652 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27943 "ad_aarch64.cpp"
  }
}

void vmls8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17666 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27963 "ad_aarch64.cpp"
  }
}

void vmls2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17680 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 27983 "ad_aarch64.cpp"
  }
}

void vmls4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17694 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28003 "ad_aarch64.cpp"
  }
}

void vmls2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17709 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28023 "ad_aarch64.cpp"
  }
}

void vmls2F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17709 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28043 "ad_aarch64.cpp"
  }
}

void vmls4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17724 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28063 "ad_aarch64.cpp"
  }
}

void vmls4F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17724 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28083 "ad_aarch64.cpp"
  }
}

void vmls2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28103 "ad_aarch64.cpp"
  }
}

void vmls2D_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 28123 "ad_aarch64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17755 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28142 "ad_aarch64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17769 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28161 "ad_aarch64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 17783 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28180 "ad_aarch64.cpp"
  }
}

void vsqrt2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28196 "ad_aarch64.cpp"
  }
}

void vsqrt4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17809 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28212 "ad_aarch64.cpp"
  }
}

void vsqrt2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17820 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28229 "ad_aarch64.cpp"
  }
}

void vabs8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17836 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28245 "ad_aarch64.cpp"
  }
}

void vabs16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17848 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28261 "ad_aarch64.cpp"
  }
}

void vabs4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17860 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28277 "ad_aarch64.cpp"
  }
}

void vabs8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17872 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28293 "ad_aarch64.cpp"
  }
}

void vabs2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17884 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28309 "ad_aarch64.cpp"
  }
}

void vabs4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17896 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28325 "ad_aarch64.cpp"
  }
}

void vabs2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17908 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28341 "ad_aarch64.cpp"
  }
}

void vabs2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17920 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28358 "ad_aarch64.cpp"
  }
}

void vabs4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17933 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28375 "ad_aarch64.cpp"
  }
}

void vabs2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17946 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28392 "ad_aarch64.cpp"
  }
}

void vneg2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17961 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28409 "ad_aarch64.cpp"
  }
}

void vneg4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17974 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28426 "ad_aarch64.cpp"
  }
}

void vneg2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 17987 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28443 "ad_aarch64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18003 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28462 "ad_aarch64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18017 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28481 "ad_aarch64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18034 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28500 "ad_aarch64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18048 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28519 "ad_aarch64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18065 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28538 "ad_aarch64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18079 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28557 "ad_aarch64.cpp"
  }
}

void vshiftcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 18093 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 28573 "ad_aarch64.cpp"
  }
}

void vshiftcnt8B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 18093 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 28589 "ad_aarch64.cpp"
  }
}

void vshiftcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 18104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 28605 "ad_aarch64.cpp"
  }
}

void vshiftcnt16B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 18104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 28621 "ad_aarch64.cpp"
  }
}

void vsll8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18116 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 28640 "ad_aarch64.cpp"
  }
}

void vsll16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18129 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 28659 "ad_aarch64.cpp"
  }
}

void vsra8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18166 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28681 "ad_aarch64.cpp"
  }
}

void vsra16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18183 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28703 "ad_aarch64.cpp"
  }
}

void vsrl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18201 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28725 "ad_aarch64.cpp"
  }
}

void vsrl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18218 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28747 "ad_aarch64.cpp"
  }
}

void vsll8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18234 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 28772 "ad_aarch64.cpp"
  }
}

void vsll16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18253 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 28797 "ad_aarch64.cpp"
  }
}

void vsra8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18273 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 28817 "ad_aarch64.cpp"
  }
}

void vsra16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18287 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 28837 "ad_aarch64.cpp"
  }
}

void vsrl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18302 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 28862 "ad_aarch64.cpp"
  }
}

void vsrl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18321 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 28887 "ad_aarch64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18341 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 28906 "ad_aarch64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18354 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 28925 "ad_aarch64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18370 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28947 "ad_aarch64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18387 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28969 "ad_aarch64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18405 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 28991 "ad_aarch64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18422 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29013 "ad_aarch64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18438 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 29038 "ad_aarch64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18457 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 29063 "ad_aarch64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18477 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 29083 "ad_aarch64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18491 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 29103 "ad_aarch64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18506 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 29128 "ad_aarch64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18525 "src/hotspot/cpu/aarch64/aarch64.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 29153 "ad_aarch64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 29172 "ad_aarch64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18557 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 29191 "ad_aarch64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18572 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29213 "ad_aarch64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18589 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29235 "ad_aarch64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18606 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29257 "ad_aarch64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18623 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29279 "ad_aarch64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18638 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 29298 "ad_aarch64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18651 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 29317 "ad_aarch64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18664 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29336 "ad_aarch64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18677 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29355 "ad_aarch64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18690 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29374 "ad_aarch64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18703 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29393 "ad_aarch64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18716 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 29412 "ad_aarch64.cpp"
  }
}

void vsra2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18731 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29434 "ad_aarch64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 18748 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 29456 "ad_aarch64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18763 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 29475 "ad_aarch64.cpp"
  }
}

void vsra2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18776 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29494 "ad_aarch64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 18789 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 29513 "ad_aarch64.cpp"
  }
}

void vmax2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18803 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29532 "ad_aarch64.cpp"
  }
}

void vmax4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18817 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29551 "ad_aarch64.cpp"
  }
}

void vmax2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18831 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29570 "ad_aarch64.cpp"
  }
}

void vmin2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18845 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29589 "ad_aarch64.cpp"
  }
}

void vmin4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18859 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29608 "ad_aarch64.cpp"
  }
}

void vmin2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 18873 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29627 "ad_aarch64.cpp"
  }
}

void vpopcount4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 18889 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
     __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
               as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
     __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
               as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 29648 "ad_aarch64.cpp"
  }
}

void vpopcount2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 18908 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
     __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
               as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
     __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
               as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 29669 "ad_aarch64.cpp"
  }
}

void zLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 60 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    if (barrier_data() != ZLoadBarrierElided) {
      z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, false /* weak */);
    }
  
#line 29690 "ad_aarch64.cpp"
  }
}

void zLoadWeakPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 82 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, true /* weak */);
  
#line 29709 "ad_aarch64.cpp"
  }
}

void zLoadPVolatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 102 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ ldar(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    if (barrier_data() != ZLoadBarrierElided) {
      z_load_barrier(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, false /* weak */);
    }
  
#line 29729 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 123 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 29762 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapP_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 123 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 29795 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 155 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 29828 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcq_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 155 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 29861 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 185 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 29892 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    MacroAssembler _masm(&cbuf);

#line 213 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 29923 "ad_aarch64.cpp"
  }
}

void zGetAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    MacroAssembler _masm(&cbuf);

#line 241 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchg(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    if (barrier_data() != ZLoadBarrierElided) {
      z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, false /* weak */);
    }
  
#line 29944 "ad_aarch64.cpp"
  }
}

void zGetAndSetPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    MacroAssembler _masm(&cbuf);

#line 260 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchgal(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    if (barrier_data() != ZLoadBarrierElided) {
      z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, false /* weak */);
    }
  
#line 29965 "ad_aarch64.cpp"
  }
}

void loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 186 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStoreA_predicate(MacroAssembler(&cbuf), false, dst_reg, ptrue,
                         vector_element_basic_type(this), opnd_array(1)->opcode(),
                         as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29984 "ad_aarch64.cpp"
  }
}

void storeVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 200 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStoreA_predicate(MacroAssembler(&cbuf), true, src_reg, ptrue,
                         vector_element_basic_type(this, opnd_array(2)), opnd_array(1)->opcode(),
                         as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 30004 "ad_aarch64.cpp"
  }
}

void vaddBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 216 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30023 "ad_aarch64.cpp"
  }
}

void vaddSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 229 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30042 "ad_aarch64.cpp"
  }
}

void vaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 242 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30061 "ad_aarch64.cpp"
  }
}

void vaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 255 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30080 "ad_aarch64.cpp"
  }
}

void vaddFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 268 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30099 "ad_aarch64.cpp"
  }
}

void vaddDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 281 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30118 "ad_aarch64.cpp"
  }
}

void vandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 296 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30137 "ad_aarch64.cpp"
  }
}

void vorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 311 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30156 "ad_aarch64.cpp"
  }
}

void vxorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 326 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30175 "ad_aarch64.cpp"
  }
}

void vdivFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 341 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30193 "ad_aarch64.cpp"
  }
}

void vdivDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 353 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30211 "ad_aarch64.cpp"
  }
}

void vfmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 368 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30230 "ad_aarch64.cpp"
  }
}

void vfmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 381 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30249 "ad_aarch64.cpp"
  }
}

void vfmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 398 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30268 "ad_aarch64.cpp"
  }
}

void vfmlsF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 398 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30287 "ad_aarch64.cpp"
  }
}

void vfmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 413 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30306 "ad_aarch64.cpp"
  }
}

void vfmlsD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 413 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30325 "ad_aarch64.cpp"
  }
}

void vfnmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 430 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30344 "ad_aarch64.cpp"
  }
}

void vfnmlaF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 430 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30363 "ad_aarch64.cpp"
  }
}

void vfnmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 445 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30382 "ad_aarch64.cpp"
  }
}

void vfnmlaD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 445 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30401 "ad_aarch64.cpp"
  }
}

void vfnmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 460 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30420 "ad_aarch64.cpp"
  }
}

void vfnmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 473 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30439 "ad_aarch64.cpp"
  }
}

void vmlaSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 489 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30458 "ad_aarch64.cpp"
  }
}

void vmlaS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    MacroAssembler _masm(&cbuf);

#line 489 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 30477 "ad_aarch64.cpp"
  }
}

void vmlaINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 503 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30496 "ad_aarch64.cpp"
  }
}

void vmlaI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    MacroAssembler _masm(&cbuf);

#line 503 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 30515 "ad_aarch64.cpp"
  }
}

void vmlaLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 517 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30534 "ad_aarch64.cpp"
  }
}

void vmlaL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    MacroAssembler _masm(&cbuf);

#line 517 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 30553 "ad_aarch64.cpp"
  }
}

void vmlsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 533 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30572 "ad_aarch64.cpp"
  }
}

void vmlsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 547 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30591 "ad_aarch64.cpp"
  }
}

void vmlsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 561 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 30610 "ad_aarch64.cpp"
  }
}

void vmulSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 576 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30628 "ad_aarch64.cpp"
  }
}

void vmulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 588 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30646 "ad_aarch64.cpp"
  }
}

void vmulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 600 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30664 "ad_aarch64.cpp"
  }
}

void vmulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 612 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30683 "ad_aarch64.cpp"
  }
}

void vmulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 625 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30702 "ad_aarch64.cpp"
  }
}

void vnegFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 640 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30719 "ad_aarch64.cpp"
  }
}

void vnegDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 652 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30736 "ad_aarch64.cpp"
  }
}

void vpopcountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 665 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

     __ sve_cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30752 "ad_aarch64.cpp"
  }
}

void reduce_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 682 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 30774 "ad_aarch64.cpp"
  }
}

void reduce_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 700 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, 0);
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 30796 "ad_aarch64.cpp"
  }
}

void reduce_addFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 714 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30814 "ad_aarch64.cpp"
  }
}

void reduce_addDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 726 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30832 "ad_aarch64.cpp"
  }
}

void replicateBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 740 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30848 "ad_aarch64.cpp"
  }
}

void replicateSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 751 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30864 "ad_aarch64.cpp"
  }
}

void replicateINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 762 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30880 "ad_aarch64.cpp"
  }
}

void replicateLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 773 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30896 "ad_aarch64.cpp"
  }
}

void replicateB_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 785 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, opnd_array(1)->constant());
  
#line 30912 "ad_aarch64.cpp"
  }
}

void replicateS_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 796 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, opnd_array(1)->constant());
  
#line 30928 "ad_aarch64.cpp"
  }
}

void replicateI_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 807 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, opnd_array(1)->constant());
  
#line 30944 "ad_aarch64.cpp"
  }
}

void replicateL_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 818 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, opnd_array(1)->constantL());
  
#line 30960 "ad_aarch64.cpp"
  }
}

void replicateFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 830 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30977 "ad_aarch64.cpp"
  }
}

void replicateDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 842 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30994 "ad_aarch64.cpp"
  }
}

void vasrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 856 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31012 "ad_aarch64.cpp"
  }
}

void vasrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 868 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31030 "ad_aarch64.cpp"
  }
}

void vasrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 880 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31048 "ad_aarch64.cpp"
  }
}

void vasrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 892 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31066 "ad_aarch64.cpp"
  }
}

void vlslBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 904 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31084 "ad_aarch64.cpp"
  }
}

void vlslSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 916 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31102 "ad_aarch64.cpp"
  }
}

void vlslINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 928 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31120 "ad_aarch64.cpp"
  }
}

void vlslLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 940 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31138 "ad_aarch64.cpp"
  }
}

void vlsrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 952 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31156 "ad_aarch64.cpp"
  }
}

void vlsrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 964 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31174 "ad_aarch64.cpp"
  }
}

void vlsrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 976 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31192 "ad_aarch64.cpp"
  }
}

void vlsrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 988 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 31210 "ad_aarch64.cpp"
  }
}

void vasrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1000 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) con = 7;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31235 "ad_aarch64.cpp"
  }
}

void vasrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1019 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) con = 15;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31260 "ad_aarch64.cpp"
  }
}

void vasrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1038 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31284 "ad_aarch64.cpp"
  }
}

void vasrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1056 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31308 "ad_aarch64.cpp"
  }
}

void vlsrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1074 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31337 "ad_aarch64.cpp"
  }
}

void vlsrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1097 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31366 "ad_aarch64.cpp"
  }
}

void vlsrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1120 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31390 "ad_aarch64.cpp"
  }
}

void vlsrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1138 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31414 "ad_aarch64.cpp"
  }
}

void vlslB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1156 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31438 "ad_aarch64.cpp"
  }
}

void vlslS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1174 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31462 "ad_aarch64.cpp"
  }
}

void vlslI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1192 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31481 "ad_aarch64.cpp"
  }
}

void vlslL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 1205 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 31500 "ad_aarch64.cpp"
  }
}

void vshiftcntBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1219 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31516 "ad_aarch64.cpp"
  }
}

void vshiftcntB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1219 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31532 "ad_aarch64.cpp"
  }
}

void vshiftcntSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1232 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31548 "ad_aarch64.cpp"
  }
}

void vshiftcntS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1232 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31564 "ad_aarch64.cpp"
  }
}

void vshiftcntINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1244 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31580 "ad_aarch64.cpp"
  }
}

void vshiftcntI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1244 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31596 "ad_aarch64.cpp"
  }
}

void vshiftcntLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1256 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31612 "ad_aarch64.cpp"
  }
}

void vshiftcntL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 1256 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 31628 "ad_aarch64.cpp"
  }
}

void vsqrtFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1269 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31645 "ad_aarch64.cpp"
  }
}

void vsqrtDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1281 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31662 "ad_aarch64.cpp"
  }
}

void vsubBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1295 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31681 "ad_aarch64.cpp"
  }
}

void vsubSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1308 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31700 "ad_aarch64.cpp"
  }
}

void vsubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1321 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31719 "ad_aarch64.cpp"
  }
}

void vsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1334 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31738 "ad_aarch64.cpp"
  }
}

void vsubFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1347 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31757 "ad_aarch64.cpp"
  }
}

void vsubDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1360 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 31776 "ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchallocNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadWeakPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPVolatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapP_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcq_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    false,  // CMoveVD
    true ,  // CMoveF
    false,  // CMoveVF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapB
    true ,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // WeakCompareAndSwapB
    true ,  // WeakCompareAndSwapS
    true ,  // WeakCompareAndSwapI
    true ,  // WeakCompareAndSwapL
    true ,  // WeakCompareAndSwapP
    true ,  // WeakCompareAndSwapN
    true ,  // CompareAndExchangeB
    true ,  // CompareAndExchangeS
    true ,  // CompareAndExchangeI
    true ,  // CompareAndExchangeL
    true ,  // CompareAndExchangeP
    true ,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // FmaD
    true ,  // FmaF
    true ,  // Goto
    true ,  // Halt
    true ,  // HasNegatives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    true ,  // MaxD
    true ,  // MaxF
    true ,  // MaxI
    false,  // MaxL
    true ,  // MemBarAcquire
    true ,  // LoadFence
    false,  // SetVectMaskI
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinD
    true ,  // MinF
    true ,  // MinI
    false,  // MinL
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // Opaque2
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PopCountVI
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    false,  // RoundDouble
    false,  // RoundDoubleMode
    false,  // RoundDoubleModeV
    false,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // SCMemProj
    true ,  // CopySignD
    true ,  // CopySignF
    true ,  // SignumD
    true ,  // SignumF
    true ,  // SqrtD
    true ,  // SqrtF
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrCompressedCopy
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // StrIndexOfChar
    true ,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddReductionVI
    true ,  // AddVL
    true ,  // AddReductionVL
    true ,  // AddVF
    true ,  // AddReductionVF
    true ,  // AddVD
    true ,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulReductionVI
    true ,  // MulVL
    false,  // MulReductionVL
    true ,  // MulVF
    true ,  // MulReductionVF
    true ,  // MulVD
    true ,  // MulReductionVD
    true ,  // FmaVD
    true ,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    true ,  // AbsVB
    true ,  // AbsVS
    true ,  // AbsVI
    true ,  // AbsVL
    true ,  // AbsVF
    true ,  // AbsVD
    true ,  // NegVF
    true ,  // NegVD
    true ,  // SqrtVD
    true ,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // OrV
    true ,  // XorV
    true ,  // MinV
    true ,  // MaxV
    true ,  // MinReductionV
    true ,  // MaxReductionV
    true ,  // LoadVector
    true ,  // StoreVector
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false   // Whitespace
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::in_preserve_stack_slots() { return 4; }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 4218 "src/hotspot/cpu/aarch64/aarch64.ad"

    // No difference between ingoing/outgoing just pass false
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 32351 "ad_aarch64.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 4224 "src/hotspot/cpu/aarch64/aarch64.ad"

    // This is obviously always outgoing
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, NULL, length);
  
#line 32362 "ad_aarch64.cpp"

}

OptoRegPair Matcher::return_value(uint ideal_reg, bool is_outgoing) {

#line 4231 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 32398 "ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg, bool is_outgoing) {

#line 4231 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 32434 "ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(R12_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
